@@ -1,7 +1,7 @@
 /*
  * acsolver.h - AC solver class definitions
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: acsolver.h,v 1.6 2005/06/02 18:17:49 raimi Exp $
+ * $Id: acsolver.h,v 1.7 2007/12/28 20:08:46 ela Exp $
  *
  */
 
@@ -37,7 +37,7 @@ class acsolver : public nasolver<complex>
   acsolver (char *);
   acsolver (acsolver &);
   ~acsolver ();
-  void solve (void);
+  int  solve (void);
   void solve_noise (void);
   static void calc (acsolver *);
   void init (void);
