@@ -1,7 +1,7 @@
 /*
  * analysis.cpp - analysis class implementation
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: analysis.cpp,v 1.10 2006/01/30 07:45:34 raimi Exp $
+ * $Id: analysis.cpp,v 1.12 2007/12/30 13:05:16 ela Exp $
  *
  */
 
@@ -47,6 +47,7 @@ analysis::analysis () : object () {
   actions = NULL;
   type = ANALYSIS_UNKNOWN;
   runs = 0;
+  progress = true;
 }
 
 // Constructor creates a named instance of the analysis class.
@@ -57,6 +58,7 @@ analysis::analysis (char * n) : object (n) {
   actions = NULL;
   type = ANALYSIS_UNKNOWN;
   runs = 0;
+  progress = true;
 }
 
 // Destructor deletes the analysis class object.
@@ -73,6 +75,7 @@ analysis::analysis (analysis & a) : object (a) {
   actions = a.actions ? new ptrlist<analysis> (*a.actions) : NULL;
   type = a.type;
   runs = a.runs;
+  progress = a.progress;
 }
 
 /* This function adds the given analysis to the actions being
@@ -91,7 +94,7 @@ void analysis::delAnalysis (analysis * a) {
 /* The following function creates a sweep object depending on the
    analysis's properties.  Supported sweep types are: linear,
    logarithmic, lists and constants. */
-sweep * analysis::createSweep (char * n) {
+sweep * analysis::createSweep (const char * n) {
   sweep * swp = NULL;
   // get type of sweep
   char * type = getPropertyString ("Type");
@@ -131,7 +134,7 @@ sweep * analysis::createSweep (char * n) {
 
 /* Saves the given variable into the dataset.  Creates the dataset
    vector if necessary. */
-void analysis::saveVariable (char * n, complex z, vector * f) {
+void analysis::saveVariable (const char * n, complex z, vector * f) {
   vector * d;
   if ((d = data->findVariable (n)) == NULL) {
     d = new vector (n);
