@@ -1,7 +1,7 @@
 /*
  * analysis.h - analysis class definitions
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: analysis.h,v 1.10 2006/01/30 07:45:34 raimi Exp $
+ * $Id: analysis.h,v 1.14 2007/12/30 13:05:16 ela Exp $
  *
  */
 
@@ -54,7 +54,9 @@ class analysis : public object
   analysis (char *);
   analysis (analysis &);
   ~analysis ();
-  virtual void solve (void) { }
+  virtual int solve (void) { return 0; }
+  virtual int initialize (void) { return 0; }
+  virtual int cleanup (void) { return 0; }
   dataset * getData (void) { return data; }
   void setData (dataset * d) { data = d; }
   net * getNet (void) { return subnet; }
@@ -67,8 +69,10 @@ class analysis : public object
   void delAnalysis (analysis *);
   int  getType (void) { return type; }
   void setType (int t) { type = t; }
-  sweep * createSweep (char *);
-  void saveVariable (char *, complex, vector *);
+  sweep * createSweep (const char *);
+  void saveVariable (const char *, complex, vector *);
+  bool getProgress (void) { return progress; }
+  void setProgress (int p) { progress = p; }
 
  protected:
   int runs;
@@ -77,6 +81,7 @@ class analysis : public object
   dataset * data;
   environment * env;
   ptrlist<analysis> * actions;
+  bool progress;
 };
 
 #endif /* __ANALYSIS_H__ */
