@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: applications.h,v 1.18 2007/05/24 16:40:30 ela Exp $
+ * $Id: applications.h,v 1.27 2007/12/21 23:04:37 ela Exp $
  *
  */
 
@@ -221,9 +221,12 @@ struct application_t eqn::applications[] = {
   { "arg", TAG_MATRIX,  evaluate::arg_m,  1, { TAG_MATRIX } },
   { "arg", TAG_MATVEC,  evaluate::arg_mv, 1, { TAG_MATVEC } },
 
-  { "unwrap", TAG_VECTOR,  evaluate::unwrap_v_1, 1, { TAG_VECTOR  } },
+  { "unwrap", TAG_VECTOR,  evaluate::unwrap_v_1, 1,
+    { TAG_VECTOR  } },
   { "unwrap", TAG_VECTOR,  evaluate::unwrap_v_2, 2,
     { TAG_VECTOR, TAG_DOUBLE } },
+  { "unwrap", TAG_VECTOR,  evaluate::unwrap_v_3, 3,
+    { TAG_VECTOR, TAG_DOUBLE, TAG_DOUBLE } },
 
   { "deg2rad", TAG_DOUBLE,  evaluate::deg2rad_d, 1, { TAG_DOUBLE  } },
   { "deg2rad", TAG_DOUBLE,  evaluate::deg2rad_c, 1, { TAG_COMPLEX } },
@@ -232,9 +235,11 @@ struct application_t eqn::applications[] = {
   { "rad2deg", TAG_DOUBLE,  evaluate::rad2deg_c, 1, { TAG_COMPLEX } },
   { "rad2deg", TAG_VECTOR,  evaluate::rad2deg_v, 1, { TAG_VECTOR  } },
 
-  { "dB", TAG_DOUBLE,  evaluate::dB_d, 1, { TAG_DOUBLE  } },
-  { "dB", TAG_DOUBLE,  evaluate::dB_c, 1, { TAG_COMPLEX } },
-  { "dB", TAG_VECTOR,  evaluate::dB_v, 1, { TAG_VECTOR  } },
+  { "dB", TAG_DOUBLE, evaluate::dB_d,  1, { TAG_DOUBLE  } },
+  { "dB", TAG_DOUBLE, evaluate::dB_c,  1, { TAG_COMPLEX } },
+  { "dB", TAG_VECTOR, evaluate::dB_v,  1, { TAG_VECTOR  } },
+  { "dB", TAG_MATRIX, evaluate::dB_m,  1, { TAG_MATRIX  } },
+  { "dB", TAG_MATVEC, evaluate::dB_mv, 1, { TAG_MATVEC  } },
 
   { "sqrt", TAG_COMPLEX, evaluate::sqrt_d, 1, { TAG_DOUBLE } },
   { "sqrt", TAG_COMPLEX, evaluate::sqrt_c, 1, { TAG_COMPLEX } },
@@ -574,6 +579,10 @@ struct application_t eqn::applications[] = {
   { "Mu",     TAG_VECTOR,  evaluate::mu1_mv,    1, { TAG_MATVEC } },
   { "Mu2",    TAG_DOUBLE,  evaluate::mu2_m,     1, { TAG_MATRIX } },
   { "Mu2",    TAG_VECTOR,  evaluate::mu2_mv,    1, { TAG_MATVEC } },
+  { "StabFactor",  TAG_DOUBLE,  evaluate::rollet_m,  1, { TAG_MATRIX } },
+  { "StabFactor",  TAG_VECTOR,  evaluate::rollet_mv, 1, { TAG_MATVEC } },
+  { "StabMeasure", TAG_DOUBLE,  evaluate::b1_m,      1, { TAG_MATRIX } },
+  { "StabMeasure", TAG_VECTOR,  evaluate::b1_mv,     1, { TAG_MATVEC } },
 
   { "linspace", TAG_VECTOR, evaluate::linspace, 3,
     { TAG_DOUBLE, TAG_DOUBLE, TAG_DOUBLE } },
@@ -805,8 +814,53 @@ struct application_t eqn::applications[] = {
   { "kbd", TAG_VECTOR, evaluate::kbd_d_d, 2, { TAG_DOUBLE, TAG_DOUBLE } },
   { "kbd", TAG_VECTOR, evaluate::kbd_d,   1, { TAG_DOUBLE } },
 
-  { "?:", TAG_DOUBLE, evaluate::ifthenelse_d_d, 3,
-    { TAG_BOOLEAN, TAG_DOUBLE | TAG_COMPLEX, TAG_DOUBLE | TAG_COMPLEX } },
+  { "?:", TAG_BOOLEAN, evaluate::ifthenelse_b_b, 3,
+    { TAG_BOOLEAN, TAG_BOOLEAN, TAG_BOOLEAN } },
+  { "?:", TAG_DOUBLE,  evaluate::ifthenelse_d_d, 3,
+    { TAG_BOOLEAN, TAG_DOUBLE,  TAG_DOUBLE } },
+  { "?:", TAG_DOUBLE,  evaluate::ifthenelse_d_b, 3,
+    { TAG_BOOLEAN, TAG_DOUBLE,  TAG_BOOLEAN } },
+  { "?:", TAG_DOUBLE,  evaluate::ifthenelse_b_d, 3,
+    { TAG_BOOLEAN, TAG_BOOLEAN, TAG_DOUBLE } },
+  { "?:", TAG_COMPLEX, evaluate::ifthenelse_c_c, 3,
+    { TAG_BOOLEAN, TAG_DOUBLE,  TAG_COMPLEX } },
+  { "?:", TAG_COMPLEX, evaluate::ifthenelse_c_c, 3,
+    { TAG_BOOLEAN, TAG_BOOLEAN, TAG_COMPLEX } },
+  { "?:", TAG_COMPLEX, evaluate::ifthenelse_c_c, 3,
+    { TAG_BOOLEAN, TAG_COMPLEX, TAG_DOUBLE } },
+  { "?:", TAG_COMPLEX, evaluate::ifthenelse_c_c, 3,
+    { TAG_BOOLEAN, TAG_COMPLEX, TAG_BOOLEAN } },
+  { "?:", TAG_COMPLEX, evaluate::ifthenelse_c_c, 3,
+    { TAG_BOOLEAN, TAG_COMPLEX, TAG_COMPLEX } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_MATRIX,  TAG_MATRIX } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_BOOLEAN, TAG_MATRIX } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_DOUBLE,  TAG_MATRIX } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_COMPLEX, TAG_MATRIX } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_MATRIX,  TAG_BOOLEAN } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_MATRIX,  TAG_DOUBLE } },
+  { "?:", TAG_MATRIX,  evaluate::ifthenelse_m_m, 3,
+    { TAG_BOOLEAN, TAG_MATRIX,  TAG_COMPLEX } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_VECTOR,  TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_BOOLEAN, TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_DOUBLE,  TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_COMPLEX, TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_VECTOR,  TAG_BOOLEAN } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_VECTOR,  TAG_DOUBLE } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v, 3,
+    { TAG_BOOLEAN, TAG_VECTOR,  TAG_COMPLEX } },
+
   { "<=", TAG_BOOLEAN, evaluate::lessorequal_d_d, 2,
     { TAG_DOUBLE, TAG_DOUBLE } },
   { ">=", TAG_BOOLEAN, evaluate::greaterorequal_d_d, 2,
@@ -823,12 +877,18 @@ struct application_t eqn::applications[] = {
   { "!=", TAG_BOOLEAN, evaluate::notequal_b_b, 2,
     { TAG_BOOLEAN, TAG_BOOLEAN } },
 
+  { "random",  TAG_DOUBLE, evaluate::rand,    0, { TAG_UNKNOWN } },
+  { "srandom", TAG_DOUBLE, evaluate::srand_d, 1, { TAG_DOUBLE  } },
+
+  { "vector", TAG_VECTOR, evaluate::vector_x, -1, { TAG_UNKNOWN } },
+  { "matrix", TAG_MATRIX, evaluate::matrix_x, -1, { TAG_UNKNOWN } },
+
   { NULL, 0, NULL, 0, { 0 } /* end of list */ }
 };
 
 // Converts a TAG_XXX value into a unique string.
-char * checker::tag2key (int tag) {
-  char * key = "";
+const char * checker::tag2key (int tag) {
+  const char * key = "";
   if (tag == TAG_RANGE)
     key = "R";
   else switch (tag & ~TAG_RANGE) {
