@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component.h,v 1.44 2007/05/13 12:21:43 ela Exp $
+ * $Id: component.h,v 1.48 2007/12/18 21:15:47 ela Exp $
  *
  */
 
@@ -62,6 +62,8 @@
 #include "iac.h"
 #include "vexp.h"
 #include "iexp.h"
+#include "vfile.h"
+#include "ifile.h"
 #include "vam.h"
 #include "vpm.h"
 #include "phaseshifter.h"
@@ -127,5 +129,7 @@
 
 #include "verilog/hicumL2p1.core.h"
 #include "verilog/HBT_X.core.h"
+#include "verilog/mod_amp.core.h"
+#include "verilog/hic2_full.core.h"
 
 #endif /* __COMPONENT_H__ */
