@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component_id.h,v 1.40 2007/05/13 12:21:43 ela Exp $
+ * $Id: component_id.h,v 1.45 2007/12/18 21:15:47 ela Exp $
  *
  */
 
@@ -63,6 +63,8 @@ enum circuit_type {
   CIR_IAC,
   CIR_VEXP,
   CIR_IEXP,
+  CIR_VFILE,
+  CIR_IFILE,
   CIR_VAM,
   CIR_VPM,
   CIR_PHASESHIFTER,
@@ -130,7 +132,10 @@ enum circuit_type {
 
   // verilog devices
   CIR_HBT_X,
-  CIR_hicumL2p1
+  CIR_hicumL2p1,
+  CIR_hicumL2p2,
+  CIR_mod_amp,
+  CIR_hic2_full
 };
 
 #endif /* __COMPONENT_ID_H__ */
