@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: bjt.cpp,v 1.43 2006/05/12 14:32:10 raimi Exp $
+ * $Id: bjt.cpp,v 1.46 2006/12/10 20:42:07 raimi Exp $
  *
  */
 
@@ -58,6 +58,7 @@ bjt::bjt () : circuit (4) {
 }
 
 void bjt::calcSP (nr_double_t frequency) {
+  // build admittance matrix and convert it to S-parameter matrix
   setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
@@ -69,11 +70,11 @@ matrix bjt::calcMatrixY (nr_double_t frequency) {
   nr_double_t Cbci = getOperatingPoint ("Cbci");
   nr_double_t gbc  = getOperatingPoint ("gmu");
   nr_double_t Ccs  = getOperatingPoint ("Ccs");
-#if NEWSGP && 0
-  nr_double_t gmfr = getOperatingPoint ("gmf");
+#if NEWSGP
+  nr_double_t gm   = getOperatingPoint ("gmf");
   nr_double_t gmr  = getOperatingPoint ("gmr");
 #else
-  nr_double_t gmfr = getOperatingPoint ("gm");
+  nr_double_t gm   = getOperatingPoint ("gm");
   nr_double_t go   = getOperatingPoint ("go");
 #endif
   nr_double_t Ptf  = getPropertyDouble ("Ptf");
@@ -84,24 +85,31 @@ matrix bjt::calcMatrixY (nr_double_t frequency) {
   complex Ybc = rect (gbc, 2.0 * M_PI * frequency * Cbci);
   complex Ycs = rect (0.0, 2.0 * M_PI * frequency * Ccs);
 
-  // compute influence of excess pase
-  nr_double_t phase = rad (Ptf) * Tf * 2 * M_PI * frequency;
-  complex gmf = polar (gmfr, -phase);
+  // admittance matrix entries for "transcapacitance"
+  complex Ybebc = rect (0.0, 2.0 * M_PI * frequency * dQbedUbc);
 
-  // build admittance matrix and convert it to S-parameter matrix
+  // compute influence of excess phase
+  nr_double_t phase = rad (Ptf) * Tf * 2 * M_PI * frequency;
+#if NEWSGP
+  complex gmf = polar (gm, -phase);
+#else
+  complex gmf = polar (gm + go, -phase) - go;
+#endif
+
+  // build admittance matrix
   matrix y (4);
-#if NEWSGP && 0
+#if NEWSGP
   // for some reason this small signal equivalent can't be used
-  y.set (NODE_B, NODE_B, Ybc + Ybe);
-  y.set (NODE_B, NODE_C, -Ybc);
+  y.set (NODE_B, NODE_B, Ybc + Ybe + Ybebc);
+  y.set (NODE_B, NODE_C, -Ybc - Ybebc);
   y.set (NODE_B, NODE_E, -Ybe);
   y.set (NODE_B, NODE_S, 0);
-  y.set (NODE_C, NODE_B, -Ybc + gmf - gmr);
-  y.set (NODE_C, NODE_C, Ybc + gmr + Ycs);
+  y.set (NODE_C, NODE_B, -Ybc + gmf + gmr);
+  y.set (NODE_C, NODE_C, Ybc - gmr + Ycs);
   y.set (NODE_C, NODE_E, -gmf);
   y.set (NODE_C, NODE_S, -Ycs);
-  y.set (NODE_E, NODE_B, -Ybe - gmf + gmr);
-  y.set (NODE_E, NODE_C, -gmr);
+  y.set (NODE_E, NODE_B, -Ybe - gmf - gmr - Ybebc);
+  y.set (NODE_E, NODE_C, gmr + Ybebc);
   y.set (NODE_E, NODE_E, Ybe + gmf);
   y.set (NODE_E, NODE_S, 0);
   y.set (NODE_S, NODE_B, 0);
@@ -109,16 +117,16 @@ matrix bjt::calcMatrixY (nr_double_t frequency) {
   y.set (NODE_S, NODE_E, 0);
   y.set (NODE_S, NODE_S, Ycs);
 #else /* !NEWSGP */
-  y.set (NODE_B, NODE_B, Ybc + Ybe);
-  y.set (NODE_B, NODE_C, -Ybc);
+  y.set (NODE_B, NODE_B, Ybc + Ybe + Ybebc);
+  y.set (NODE_B, NODE_C, -Ybc - Ybebc);
   y.set (NODE_B, NODE_E, -Ybe);
   y.set (NODE_B, NODE_S, 0);
   y.set (NODE_C, NODE_B, -Ybc + gmf);
   y.set (NODE_C, NODE_C, Ybc + Ycs + go);
   y.set (NODE_C, NODE_E, -gmf - go);
   y.set (NODE_C, NODE_S, -Ycs);
-  y.set (NODE_E, NODE_B, -Ybe - gmf);
-  y.set (NODE_E, NODE_C, -go);
+  y.set (NODE_E, NODE_B, -Ybe - gmf - Ybebc);
+  y.set (NODE_E, NODE_C, -go + Ybebc);
   y.set (NODE_E, NODE_E, Ybe + gmf + go);
   y.set (NODE_E, NODE_S, 0);
   y.set (NODE_S, NODE_B, 0);
@@ -226,6 +234,14 @@ void bjt::initModel (void) {
     logprint (LOG_ERROR, "WARNING: Unphysical model parameter Nr = %g in "
 	      "BJT `%s'\n", Nr, getName ());
   }
+  if (Ne < 1.0) {
+    logprint (LOG_ERROR, "WARNING: Unphysical model parameter Ne = %g in "
+	      "BJT `%s'\n", Ne, getName ());
+  }
+  if (Nc < 1.0) {
+    logprint (LOG_ERROR, "WARNING: Unphysical model parameter Nc = %g in "
+	      "BJT `%s'\n", Nc, getName ());
+  }
 
   // compute Cje, Cjc and Cjs temperature and area dependencies
   nr_double_t Cje = getPropertyDouble ("Cje");
@@ -264,6 +280,9 @@ void bjt::initModel (void) {
 
 void bjt::initDC (void) {
 
+  // no transient analysis
+  doTR = false;
+
   // allocate MNA matrices
   allocMatrixMNA ();
 
@@ -343,6 +362,8 @@ void bjt::restartDC (void) {
   UbcPrev = real (getV (NODE_B) - getV (NODE_C)) * pol;
 }
 
+#define cexState 6 // extra excess phase state
+
 void bjt::calcDC (void) {
 
   // fetch device model parameters
@@ -441,16 +462,24 @@ void bjt::calcDC (void) {
   dQbdUbe = Q1 * (Qb * Var + gif * Ikf / Sqrt);
   dQbdUbc = Q1 * (Qb * Vaf + gir * Ikr / Sqrt);
 
+  // during transient analysis only
+  if (doTR) {
+    // calculate excess phase influence
+    If /= Qb;
+    excessPhase (cexState, If, gif);
+    If *= Qb;
+  }
+
   // compute transfer current
   It = (If - Ir) / Qb;
 
   // compute forward and backward transconductance
-  gitf = (gif - If * dQbdUbe / Qb) / Qb;
-  gitr = (gir - Ir * dQbdUbc / Qb) / Qb;
+  gitf = (+gif - It * dQbdUbe) / Qb;
+  gitr = (-gir - It * dQbdUbc) / Qb;
 
   // compute old SPICE values
-  go = (gir + It * dQbdUbc) / Qb;
-  gm = (gif - It * dQbdUbe) / Qb - go;
+  go = -gitr;
+  gm = +gitf - go;
   setOperatingPoint ("gm", gm);
   setOperatingPoint ("go", go);
 
@@ -475,7 +504,7 @@ void bjt::calcDC (void) {
   IeqB = Ibe - Ube * gbe;
   IeqC = Ibc - Ubc * gbc;
 #if NEWSGP
-  IeqE = It - gitf * Ube + gitr * Ubc;
+  IeqE = It - Ube * gitf - Ubc * gitr;
 #else
   IeqE = It - Ube * gm - Uce * go;
 #endif
@@ -491,12 +520,12 @@ void bjt::calcDC (void) {
   setY (NODE_B, NODE_C, -gbc);
   setY (NODE_B, NODE_E, -gbe);
   setY (NODE_B, NODE_S, 0);
-  setY (NODE_C, NODE_B, -gbc + gitf - gitr);
-  setY (NODE_C, NODE_C, gbc + gitr);
+  setY (NODE_C, NODE_B, -gbc + gitf + gitr);
+  setY (NODE_C, NODE_C, gbc - gitr);
   setY (NODE_C, NODE_E, -gitf);
   setY (NODE_C, NODE_S, 0);
-  setY (NODE_E, NODE_B, -gbe - gitf + gitr);
-  setY (NODE_E, NODE_C, -gitr);
+  setY (NODE_E, NODE_B, -gbe - gitf - gitr);
+  setY (NODE_E, NODE_C, gitr);
   setY (NODE_E, NODE_E, gbe + gitf);
   setY (NODE_E, NODE_S, 0);
   setY (NODE_S, NODE_B, 0);
@@ -576,12 +605,15 @@ void bjt::calcOperatingPoints (void) {
 
   // diffusion capacitance of base-emitter diode
   if (If != 0.0) {
-    nr_double_t e, Tff, dTffdUbe;
+    nr_double_t e, Tff, dTffdUbe, dTffdUbc, a;
+    a = 1 / (1 + Itf / If);
     e = 2 * exp (MIN (Ubc * Vtf, 709));
-    Tff = Tf * (1 + Xtf * sqr (If / (If + Itf)) * e);
-    dTffdUbe = Tf * Xtf * 2 * gif * If * Itf / cubic (If + Itf) * e;
+    Tff = Tf * (1 + Xtf * sqr (a) * e);
+    dTffdUbe = Tf * Xtf * 2 * gif * Itf * cubic (a) / sqr (If) * e;
     Cbe += (If * dTffdUbe + Tff * (gif - If / Qb * dQbdUbe)) / Qb;
     Qbe += If * Tff / Qb;
+    dTffdUbc = Tf * Xtf * Vtf * sqr (a) * e;
+    dQbedUbc = If / Qb * (dTffdUbc - Tff / Qb * dQbdUbc);
   }
 
   // depletion and diffusion capacitance of base-collector diode
@@ -666,8 +698,9 @@ void bjt::calcNoiseAC (nr_double_t frequency) {
 #define cbxState 1 // external base-collector current state
 
 void bjt::initTR (void) {
-  setStates (6);
+  setStates (7);
   initDC ();
+  doTR = true;
 
   // handle external base-collector capacitance appropriately
   processCbcx ();
@@ -699,8 +732,42 @@ void bjt::calcTR (nr_double_t t) {
     }
   }
 
-  // TODO: excess phase
+  // usual capacitances
   transientCapacitance (qbeState, NODE_B, NODE_E, Cbe, Ube, Qbe);
   transientCapacitance (qbcState, NODE_B, NODE_C, Cbci, Ubc, Qbci);
   transientCapacitance (qcsState, NODE_S, NODE_C, Ccs, Ucs, Qcs);
+
+  // trans-capacitances
+  transientCapacitanceC (NODE_B, NODE_E, NODE_B, NODE_C, dQbedUbc, Ubc);
+}
+
+void bjt::excessPhase (int istate, nr_double_t& i, nr_double_t& g) {
+
+  // fetch device properties
+  nr_double_t Ptf = getPropertyDouble ("Ptf");
+  nr_double_t Tf = getPropertyDouble ("Tf");
+  nr_double_t td = rad (Ptf) * Tf;
+
+  // return if nothing todo
+  if (td == 0.0) return;
+
+  // fill-in current history during initialization
+  if (getMode () & MODE_INIT) fillState (istate, i);
+
+  // calculate current coefficients C1, C2 and C3
+  nr_double_t * delta = getDelta ();
+  nr_double_t c3, c2, c1, dn, ra;
+  c1 = delta[0] / td;
+  c2 = 3 * c1;
+  c1 = c2 * c1;
+  dn = 1 + c1 + c2;
+  c1 = c1 / dn;
+  ra = delta[0] / delta[1];
+  c2 = (1 + ra + c2) / dn;
+  c3 = ra / dn;
+
+  // update and save current, update transconductance
+  i = i * c1 + getState (istate, 1) * c2 - getState (istate, 2) * c3;
+  setState (istate, i);
+  g = g * c1;
 }
