@@ -2,7 +2,7 @@
  * cpwline.cpp - coplanar waveguide line class implementation
  *
  * Copyright (C) 2004, 2005 Vincent Habchi, F5RCS <10.50@free.fr>
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.
  *
- * $Id: cpwline.cpp,v 1.13 2005/06/02 18:17:55 raimi Exp $
+ * $Id: cpwline.cpp,v 1.17 2006/01/30 07:45:35 raimi Exp $
  *
  */
 
@@ -57,8 +57,12 @@
 # define isinf(x)  (!_finite(x) && !_isnan(x))
 # endif
 #endif
+#if defined (__SVR4) && defined (__sun)
+# define isinf(x) (!finite(x) && (x) == (x)) 
+#endif
 
 cpwline::cpwline () : circuit (2) {
+  Zl = Er = 0;
   type = CIR_CPWLINE;
 }
 
@@ -68,12 +72,12 @@ cpwline::cpwline () : circuit (2) {
 void cpwline::ellipke (nr_double_t arg, nr_double_t &k, nr_double_t &e) {
   int iMax = 16;
   if (arg == 1.0) {
-    k = DBL_MAX / DBL_MIN; // infinite
+    k = NR_INF; // infinite
     e = 0;
   }
   else if (isinf (arg) && arg < 0) {
     k = 0;
-    e = DBL_MAX / DBL_MIN; // infinite
+    e = NR_INF; // infinite
   }
   else {
     nr_double_t a, b, c, f, s, fk = 1, fe = 1, t, da = arg;
@@ -95,7 +99,7 @@ void cpwline::ellipke (nr_double_t arg, nr_double_t &k, nr_double_t &e) {
       a = t;
       f *= 2;
       s += f * c * c;
-      if (c / a < 1e-16) break;
+      if (c / a < NR_EPSI) break;
     }
     if (i >= iMax) {
       k = 0; e = 0;
@@ -271,6 +275,14 @@ void cpwline::calcAB (nr_double_t f, nr_double_t& zl, nr_double_t& al,
 
   al  = ac + ad;
   bt *= sr_er_f * f;
+
+  Er = sqr (sr_er_f);
+  Zl = zl;
+}
+
+void cpwline::saveCharacteristics (nr_double_t) {
+  setCharacteristic ("Zl", Zl);
+  setCharacteristic ("Er", Er);
 }
 
 void cpwline::calcSP (nr_double_t frequency) {
