@@ -15,10 +15,10 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
- * $Id: msvia.cpp,v 1.5 2005/02/03 20:40:20 raimi Exp $
+ * $Id: msvia.cpp,v 1.9 2005/06/02 18:17:56 raimi Exp $
  *
  */
 
@@ -50,11 +50,10 @@ msvia::msvia () : circuit (2) {
 
 void msvia::calcNoiseSP (nr_double_t) {
   // calculate noise correlation matrix
-  nr_double_t r = real (Z);
   nr_double_t T = getPropertyDouble ("Temp");
-  nr_double_t f = kelvin (T) * 4.0 * r * z0 / sqr (2.0 * z0 + r) / T0;
-  setN (1, 1, +f); setN (2, 2, +f);
-  setN (1, 2, -f); setN (2, 1, -f);
+  nr_double_t f = kelvin (T) * 4.0 * real (Z) * z0 / norm (4.0 * z0 + Z) / T0;
+  setN (NODE_1, NODE_1, +f); setN (NODE_2, NODE_2, +f);
+  setN (NODE_1, NODE_2, -f); setN (NODE_2, NODE_1, -f);
 }
 
 void msvia::initSP (void) {
@@ -66,10 +65,10 @@ void msvia::calcSP (nr_double_t frequency) {
   // calculate s-parameters
   Z = calcImpedance (frequency);
   complex z = Z / z0;
-  setS (1, 1, z / (z + 2));
-  setS (2, 2, z / (z + 2));
-  setS (1, 2, 2 / (z + 2));
-  setS (2, 1, 2 / (z + 2));
+  setS (NODE_1, NODE_1, z / (z + 2));
+  setS (NODE_2, NODE_2, z / (z + 2));
+  setS (NODE_1, NODE_2, 2 / (z + 2));
+  setS (NODE_2, NODE_1, 2 / (z + 2));
 }
 
 complex msvia::calcImpedance (nr_double_t frequency) {
@@ -87,7 +86,7 @@ complex msvia::calcImpedance (nr_double_t frequency) {
   }
 
   // create Z-parameter
-  nr_double_t fs  = M_PI * MU0 * rho * sqr (t);
+  nr_double_t fs  = M_PI * MU0 * sqr (t) / rho;
   nr_double_t res = R * sqrt (1 + frequency * fs);
   nr_double_t a   = sqrt (sqr (r) + sqr (h));
   nr_double_t ind = MU0 * (h * log ((h + a) / r) + 1.5 * (r - a));
@@ -101,7 +100,7 @@ nr_double_t msvia::calcResistance (void) {
   nr_double_t t   = subst->getPropertyDouble ("t");
   nr_double_t rho = subst->getPropertyDouble ("rho");
   nr_double_t r   = getPropertyDouble ("D") / 2;
-  nr_double_t v   = M_PI * (sqr (r) - sqr (r - t)) * h;
+  nr_double_t v   = h / M_PI / (sqr (r) - sqr (r - t));
   return R = rho * v;
 }
 
@@ -113,8 +112,8 @@ void msvia::initDC (void) {
     nr_double_t g = 1.0 / r;
     setVoltageSources (0);
     allocMatrixMNA ();
-    setY (1, 1, +g); setY (2, 2, +g);
-    setY (1, 2, -g); setY (2, 1, -g);
+    setY (NODE_1, NODE_1, +g); setY (NODE_2, NODE_2, +g);
+    setY (NODE_1, NODE_2, -g); setY (NODE_2, NODE_1, -g);
   }
   // for zero resistances create a zero voltage source
   else {
@@ -122,27 +121,27 @@ void msvia::initDC (void) {
     setInternalVoltageSource (1);
     allocMatrixMNA ();
     clearY ();
-    voltageSource (1, 1, 2);
+    voltageSource (VSRC_1, NODE_1, NODE_2);
   }
 }
 
 void msvia::initAC (void) {
   setVoltageSources (0);
   allocMatrixMNA ();
-  initSP ();
+  R = calcResistance ();
 }
 
 void msvia::calcAC (nr_double_t frequency) {
   complex y = 1 / calcImpedance (frequency);
-  setY (1, 1, +y); setY (2, 2, +y);
-  setY (1, 2, -y); setY (2, 1, -y);
+  setY (NODE_1, NODE_1, +y); setY (NODE_2, NODE_2, +y);
+  setY (NODE_1, NODE_2, -y); setY (NODE_2, NODE_1, -y);
 }
 
 void msvia::calcNoiseAC (nr_double_t) {
   // calculate noise current correlation matrix
-  nr_double_t r = real (Z);
+  nr_double_t y = real (1 / Z);
   nr_double_t T = getPropertyDouble ("Temp");
-  nr_double_t f = kelvin (T) / T0 * 4.0 / r;
-  setN (1, 1, +f); setN (2, 2, +f);
-  setN (1, 2, -f); setN (2, 1, -f);
+  nr_double_t f = kelvin (T) / T0 * 4.0 * y;
+  setN (NODE_1, NODE_1, +f); setN (NODE_2, NODE_2, +f);
+  setN (NODE_1, NODE_2, -f); setN (NODE_2, NODE_1, -f);
 }
