@@ -1,7 +1,7 @@
 /*
  * csv_producer.h - the CSV producer definitions
  *
- * Copyright (C) 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: csv_producer.h,v 1.2 2006/03/07 11:13:54 raimi Exp $
+ * $Id: csv_producer.h,v 1.4 2007/09/16 16:49:41 ela Exp $
  *
  */
 
@@ -35,9 +35,8 @@
 /* Externalize variables. */
 extern dataset * qucs_data;
 extern FILE * csv_out;
-extern char * csv_var;
 
 /* Available functions of the producers. */
-void csv_producer (char * variable, char * sep = ";");
+void csv_producer (char * variable, const char * sep = ";");
 
 #endif /* __CSV_PRODUCER_H__ */
