@@ -1,7 +1,7 @@
 /*
  * dataset.cpp - dataset class implementation
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: dataset.cpp,v 1.22 2006/09/04 08:05:39 raimi Exp $
+ * $Id: dataset.cpp,v 1.24 2007/09/16 16:49:38 ela Exp $
  *
  */
 
@@ -41,6 +41,7 @@
 #include "dataset.h"
 #include "check_dataset.h"
 #include "check_touchstone.h"
+#include "check_csv.h"
 #include "check_citi.h"
 #include "check_zvr.h"
 #include "check_mdl.h"
@@ -275,7 +276,7 @@ int dataset::isVariable (vector * var) {
 /* The function goes through the list of dependencies in the dataset
    and returns the vector specified by the given name.  Otherwise the
    function returns NULL. */
-vector * dataset::findDependency (char * n) {
+vector * dataset::findDependency (const char * n) {
   for (vector * v = dependencies; v != NULL; v = (vector *) v->getNext ()) {
     if (!strcmp (v->getName (), n))
       return v;
@@ -286,7 +287,7 @@ vector * dataset::findDependency (char * n) {
 /* The function goes through the list of variables in the dataset and
    returns the vector specified by the given name.  If there is no
    such variable registered the function returns NULL. */
-vector * dataset::findVariable (char * n) {
+vector * dataset::findVariable (const char * n) {
   for (vector * v = variables; v != NULL; v = (vector *) v->getNext ()) {
     if (!strcmp (v->getName (), n))
       return v;
@@ -456,6 +457,31 @@ dataset * dataset::load_touchstone (const char * file) {
   return touchstone_result;
 }
 
+/* This static function read a full dataset from the given CSV file
+   and returns it.  On failure the function emits appropriate error
+   messages and returns NULL. */
+dataset * dataset::load_csv (const char * file) {
+  FILE * f;
+  if ((f = fopen (file, "r")) == NULL) {
+    logprint (LOG_ERROR, "error loading `%s': %s\n", file, strerror (errno));
+    return NULL;
+  }
+  csv_in = f;
+  csv_restart (csv_in);
+  if (csv_parse () != 0) {
+    fclose (f);
+    return NULL;
+  }
+  if (csv_check () != 0) {
+    fclose (f);
+    return NULL;
+  }
+  fclose (f);
+  csv_lex_destroy ();
+  csv_result->setFile (file);
+  return csv_result;
+}
+
 /* The function read a full dataset from the given CITIfile and
    returns it.  On failure the function emits appropriate error
    messages and returns NULL. */
