@@ -1,7 +1,7 @@
 /*
  * dataset.h - dataset class definitions
  *
- * Copyright (C) 2003, 2004, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: dataset.h,v 1.13 2006/08/21 08:10:30 raimi Exp $
+ * $Id: dataset.h,v 1.15 2007/09/16 16:49:38 ela Exp $
  *
  */
 
@@ -53,8 +53,8 @@ class dataset : public object
   void printData (vector *, FILE *);
   void printDependency (vector *, FILE *);
   void printVariable (vector *, FILE *);
-  vector * findDependency (char *);
-  vector * findVariable (char *);
+  vector * findDependency (const char *);
+  vector * findVariable (const char *);
   vector * getDependencies (void) { return dependencies; }
   vector * getVariables (void) { return variables; }
   int isDependency (vector *);
@@ -62,6 +62,7 @@ class dataset : public object
   vector * findOrigin (char *);
   static dataset * load (const char *);
   static dataset * load_touchstone (const char *);
+  static dataset * load_csv (const char *);
   static dataset * load_citi (const char *);
   static dataset * load_zvr (const char *);
   static dataset * load_mdl (const char *);
