@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: differentiate.cpp,v 1.9 2007/05/24 16:40:30 ela Exp $
+ * $Id: differentiate.cpp,v 1.11 2007/09/16 16:49:38 ela Exp $
  *
  */
 
@@ -159,6 +159,7 @@ node * differentiate::minus_reduce (node * f0, node * f1) {
     delete f0; delete f1;
     retCon (0);
   } else if (isZero (f0)) {
+    delete f0;
     return minus_reduce (f1);
   } else if (isZero (f1)) {
     delete f1;
@@ -193,11 +194,13 @@ node * differentiate::times_reduce (node * f0, node * f1) {
     delete f0;
     return f1;
   } else if (isNeg (f0)) {
+    delete f0;
     return minus_reduce (f1);
   } else if (isOne (f1)) {
     delete f1;
     return f0;
   } else if (isNeg (f1)) {
+    delete f1;
     return minus_reduce (f0);
   } else if (isConst (f0) && isConst (f1)) {
     nr_double_t t = D(f0) * D(f1);
@@ -241,6 +244,7 @@ node * differentiate::over_reduce (node * f0, node * f1) {
     delete f1;
     return f0;
   } else if (isNeg (f1)) {
+    delete f1;
     return minus_reduce (f0);
   } else {
     retApp2 ("/", f0, f1);
@@ -267,7 +271,7 @@ node * differentiate::power (application * app, char * derivative) {
     node * ln = ln_reduce (f0->recreate());
     node * t2 = times_reduce (d1, ln);
     node * t3 = times_reduce (f1->recreate(), d0);
-    node * t4 = over_reduce (t3, f0);
+    node * t4 = over_reduce (t3, f0->recreate());
     node * t5 = plus_reduce (t2, t4);
     return times_reduce (t1, t5);
   }
@@ -349,7 +353,7 @@ node * differentiate::sqrt_reduce (node * f0) {
   retApp1 ("sqrt", f0);
 }
 
-node * differentiate::app_reduce (char * func, node * d0, node * f0) {
+node * differentiate::app_reduce (const char * func, node * d0, node * f0) {
   if (isOne (d0)) {
     delete d0;
     retApp1 (func, f0);
