@@ -1,7 +1,7 @@
 /*
  * eqnsys.cpp - equation system solver class implementation
  *
- * Copyright (C) 2004, 2005 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: eqnsys.cpp,v 1.36 2006/03/29 08:02:03 raimi Exp $
+ * $Id: eqnsys.cpp,v 1.39 2007/03/24 17:07:29 ela Exp $
  *
  */
 
@@ -58,8 +58,9 @@ using namespace qucs;
 // Constructor creates an unnamed instance of the eqnsys class.
 template <class nr_type_t>
 eqnsys<nr_type_t>::eqnsys () {
-  A = NULL;
+  A = V = NULL;
   B = X = NULL;
+  S = E = NULL;
   T = R = NULL;
   nPvt = NULL;
   cMap = rMap = NULL;
@@ -74,6 +75,9 @@ eqnsys<nr_type_t>::~eqnsys () {
   if (R != NULL) delete R;
   if (T != NULL) delete T;
   if (B != NULL) delete B;
+  if (S != NULL) delete S;
+  if (E != NULL) delete E;
+  if (V != NULL) delete V;
   if (rMap != NULL) delete[] rMap;
   if (cMap != NULL) delete[] cMap;
   if (nPvt != NULL) delete[] nPvt;
@@ -84,6 +88,8 @@ eqnsys<nr_type_t>::~eqnsys () {
 template <class nr_type_t>
 eqnsys<nr_type_t>::eqnsys (eqnsys & e) {
   A = e.A;
+  V = NULL;
+  S = E = NULL;
   T = R = NULL;
   B = e.B ? new tvector<nr_type_t> (*(e.B)) : NULL;
   cMap = rMap = NULL;
@@ -168,6 +174,12 @@ void eqnsys<nr_type_t>::solve (void) {
   case ALGO_QR_DECOMPOSITION_LS:
     solve_qr_ls ();
     break;
+  case ALGO_SV_DECOMPOSITION:
+    solve_svd ();
+    break;
+  case ALGO_QR_DECOMPOSITION_2:
+    solve_qrh ();
+    break;
   }
 #if DEBUG && 0
   logprint (LOG_STATUS, "NOTIFY: %dx%d eqnsys solved in %ld seconds\n",
@@ -181,6 +193,10 @@ void eqnsys<nr_type_t>::solve_inverse (void) {
   *X = inverse (*A) * *B;
 }
 
+#define A_ (*A)
+#define X_ (*X)
+#define B_ (*B)
+
 /* The function solves the equation system applying Gaussian
    elimination with full column pivoting only (no row pivoting). */
 template <class nr_type_t>
@@ -193,8 +209,8 @@ void eqnsys<nr_type_t>::solve_gauss (void) {
   for (i = 0; i < N; i++) {
     // find maximum column value for pivoting
     for (MaxPivot = 0, pivot = r = i; r < N; r++) {
-      if (abs (A->get (r, i)) > MaxPivot) {
-	MaxPivot = abs (A->get (r, i));
+      if (abs (A_(r, i)) > MaxPivot) {
+	MaxPivot = abs (A_(r, i));
 	pivot = r;
       }
     }
@@ -206,22 +222,17 @@ void eqnsys<nr_type_t>::solve_gauss (void) {
     }
     // compute new rows and columns
     for (r = i + 1; r < N; r++) {
-      f = A->get (r, i) / A->get (i, i);
-      for (c = i + 1; c < N; c++) {
-	A->set (r, c, A->get (r, c) - f * A->get (i, c));
-      }
-      B->set (r, B->get (r) - f * B->get (i));
+      f = A_(r, i) / A_(i, i);
+      for (c = i + 1; c < N; c++) A_(r, c) -= f * A_(i, c);
+      B_(r) -= f * B_(i);
     }
   }
 
   // backward substitution
   for (i = N - 1; i >= 0; i--) {
-    f = B->get (i);
-    for (c = i + 1; c < N; c++) {
-      f -= A->get (i, c) * X->get (c);
-    }
-    f /= A->get (i, i);
-    X->set (i, f);
+    f = B_(i);
+    for (c = i + 1; c < N; c++) f -= A_(i, c) * X_(c);
+    X_(i) = f / A_(i, i);
   }
 }
 
@@ -238,8 +249,8 @@ void eqnsys<nr_type_t>::solve_gauss_jordan (void) {
   for (i = 0; i < N; i++) {
     // find maximum column value for pivoting
     for (MaxPivot = 0, pivot = r = i; r < N; r++) {
-      if (abs (A->get (r, i)) > MaxPivot) {
-	MaxPivot = abs (A->get (r, i));
+      if (abs (A_(r, i)) > MaxPivot) {
+	MaxPivot = abs (A_(r, i));
 	pivot = r;
       }
     }
@@ -251,20 +262,16 @@ void eqnsys<nr_type_t>::solve_gauss_jordan (void) {
     }
 
     // compute current row
-    f = A->get (i, i);
-    for (c = i + 1; c < N; c++) {
-      A->set (i, c, A->get (i, c) / f);
-    }
-    B->set (i, B->get (i) / f);
+    f = A_(i, i);
+    for (c = i + 1; c < N; c++) A_(i, c) /= f;
+    B_(i) /= f;
 
     // compute new rows and columns
     for (r = 0; r < N; r++) {
       if (r != i) {
-	f = A->get (r, i);
-        for (c = i + 1; c < N; c++) {
-          A->set (r, c, A->get (r, c) - f * A->get (i, c));
-        }
-        B->set (r, B->get (r) - f * B->get (i));
+	f = A_(r, i);
+        for (c = i + 1; c < N; c++) A_(r, c) -= f * A_(i, c);
+        B_(r) -= f * B_(i);
       }
     }
   }
@@ -273,16 +280,12 @@ void eqnsys<nr_type_t>::solve_gauss_jordan (void) {
   *X = *B;
 }
 
-#define A_ (*A)
-#define X_ (*X)
-#define B_ (*B)
-
 #define LU_FAILURE 0
 #define VIRTUAL_RES(txt,i) {					  \
   qucs::exception * e = new qucs::exception (EXCEPTION_SINGULAR); \
   e->setText (txt);						  \
   e->setData (rMap[i]);						  \
-  A->set (i, i, NR_TINY); /* virtual resistance to ground */	  \
+  A_(i, i) = NR_TINY; /* virtual resistance to ground */	  \
   throw_exception (e); }
 
 /* The function uses LU decomposition and the appropriate forward and
@@ -538,10 +541,10 @@ void eqnsys<nr_type_t>::solve_iterative (void) {
 
   // normalize the equation system to have ones on its diagonal
   for (r = 0; r < N; r++) {
-    f = A->get (r, r);
+    f = A_(r, r);
     assert (f != 0); // singular matrix
-    for (c = 0; c < N; c++) A->set (r, c, A->get (r, c) / f);
-    B->set (r, B->get (r) / f);
+    for (c = 0; c < N; c++) A_(r, c) /= f;
+    B_(r) /= f;
   }
 
   // the current X vector is a good initial guess for the iteration
@@ -555,20 +558,20 @@ void eqnsys<nr_type_t>::solve_iterative (void) {
       for (f = 0, c = 0; c < N; c++) {
 	if (algo == ALGO_GAUSS_SEIDEL) {
 	  // Gauss-Seidel
-	  if (c < r)      f += A->get (r, c) * X->get (c);
-	  else if (c > r) f += A->get (r, c) * Xprev->get (c);
+	  if (c < r)      f += A_(r, c) * X_(c);
+	  else if (c > r) f += A_(r, c) * Xprev->get (c);
 	}
 	else {
 	  // Jacobi
-	  if (c != r) f += A->get (r, c) * Xprev->get (c);
+	  if (c != r) f += A_(r, c) * Xprev->get (c);
 	}
       }
-      X->set (r, B->get (r) - f);
+      X_(r) = B_(r) - f;
     }
     // check for convergence
     for (conv = 1, r = 0; r < N; r++) {
-      diff = abs (X->get (r) - Xprev->get (r));
-      if (diff >= abstol + reltol * abs (X->get (r))) {
+      diff = abs (X_(r) - Xprev->get (r));
+      if (diff >= abstol + reltol * abs (X_(r))) {
 	conv = 0;
 	break;
       }
@@ -627,10 +630,10 @@ void eqnsys<nr_type_t>::solve_sor (void) {
 
   // normalize the equation system to have ones on its diagonal
   for (r = 0; r < N; r++) {
-    f = A->get (r, r);
+    f = A_(r, r);
     assert (f != 0); // singular matrix
-    for (c = 0; c < N; c++) A->set (r, c, A->get (r, c) / f);
-    B->set (r, B->get (r) / f);
+    for (c = 0; c < N; c++) A_(r, c) /= f;
+    B_(r) /= f;
   }
 
   // the current X vector is a good initial guess for the iteration
@@ -642,19 +645,19 @@ void eqnsys<nr_type_t>::solve_sor (void) {
     // compute new solution vector
     for (r = 0; r < N; r++) {
       for (f = 0, c = 0; c < N; c++) {
-	if (c < r)      f += A->get (r, c) * X->get (c);
-	else if (c > r) f += A->get (r, c) * Xprev->get (c);
+	if (c < r)      f += A_(r, c) * X_(c);
+	else if (c > r) f += A_(r, c) * Xprev->get (c);
       }
-      X->set (r, (1 - l) * Xprev->get (r) + l * (B->get (r) - f));
+      X_(r) = (1 - l) * Xprev->get (r) + l * (B_(r) - f);
     }
     // check for convergence
     for (s = 0, d = 0, conv = 1, r = 0; r < N; r++) {
-      diff = abs (X->get (r) - Xprev->get (r));
-      if (diff >= abstol + reltol * abs (X->get (r))) {
+      diff = abs (X_(r) - Xprev->get (r));
+      if (diff >= abstol + reltol * abs (X_(r))) {
 	conv = 0;
 	break;
       }
-      d += diff; s += abs (X->get (r));
+      d += diff; s += abs (X_(r));
       if (!finite (diff)) { error++; break; }
     }
     if (!error) {
@@ -699,7 +702,7 @@ nr_double_t eqnsys<nr_type_t>::convergence_criteria (void) {
   nr_double_t f = 0;
   for (int r = 0; r < A->getCols (); r++) {
     for (int c = 0; c < A->getCols (); c++) {
-      if (r != c) f += norm (A->get (r, c) / A->get (r, r));
+      if (r != c) f += norm (A_(r, c) / A_(r, r));
     }
   }
   return sqrt (f);
@@ -727,7 +730,7 @@ void eqnsys<nr_type_t>::ensure_diagonal_MNA (void) {
     restart = exchanged = 0;
     /* search for zero diagonals with lone pairs */
     for (i = begin; i < N; i++) {
-      if (A->get (i, i) == 0) {
+      if (A_(i, i) == 0) {
 	pairs = countPairs (i, pivot1, pivot2);
 	if (pairs == 1) { /* lone pair found, substitute rows */
 	  A->exchangeRows (i, pivot1);
@@ -744,7 +747,7 @@ void eqnsys<nr_type_t>::ensure_diagonal_MNA (void) {
     /* all lone pairs are gone, look for zero diagonals with multiple pairs */
     if (restart) {
       for (i = begin; !exchanged && i < N; i++) {
-	if (A->get (i, i) == 0) {
+	if (A_(i, i) == 0) {
 	  pairs = countPairs (i, pivot1, pivot2);
 	  A->exchangeRows (i, pivot1);
 	  B->exchangeRows (i, pivot1);
@@ -762,11 +765,11 @@ template <class nr_type_t>
 int eqnsys<nr_type_t>::countPairs (int i, int& r1, int& r2) {
   int pairs = 0;
   for (int r = 0; r < N; r++) {
-    if (fabs (real (A->get (r, i))) == 1.0) {
+    if (fabs (real (A_(r, i))) == 1.0) {
       r1 = r;
       pairs++;
       for (r++; r < N; r++) {
-	if (fabs (real (A->get (r, i))) == 1.0) {
+	if (fabs (real (A_(r, i))) == 1.0) {
 	  r2 = r;
 	  if (++pairs >= 2) return pairs;
 	}
@@ -786,9 +789,9 @@ void eqnsys<nr_type_t>::preconditioner (void) {
   for (int i = 0; i < N; i++) {
     // find maximum column value for pivoting
     for (MaxPivot = 0, pivot = i, r = 0; r < N; r++) {
-      if (abs (A->get (r, i)) > MaxPivot && 
-	  abs (A->get (i, r)) >= abs (A->get (r, r))) {
-        MaxPivot = abs (A->get (r, i));
+      if (abs (A_(r, i)) > MaxPivot && 
+	  abs (A_(i, r)) >= abs (A_(r, r))) {
+        MaxPivot = abs (A_(r, i));
         pivot = r;
       }
     }
@@ -803,18 +806,24 @@ void eqnsys<nr_type_t>::preconditioner (void) {
 #define R_ (*R)
 #define T_ (*T)
 
-/* This function uses QR decomposition using householder
+/* This function uses the QR decomposition using householder
+   transformations in order to solve the given equation system. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::solve_qrh (void) {
+  factorize_qrh ();
+  substitute_qrh ();
+}
+
+/* This function uses the QR decomposition using householder
    transformations in order to solve the given equation system. */
 template <class nr_type_t>
 void eqnsys<nr_type_t>::solve_qr (void) {
   factorize_qr_householder ();
   substitute_qr_householder ();
-  //factorize_qrh ();
-  //substitute_qrh ();
 }
 
-/* The function uses QR decomposition using householder
-   transformations in order to solve the given under-determinded
+/* The function uses the QR decomposition using householder
+   transformations in order to solve the given under-determined
    equation system in its minimum norm (least square) sense. */
 template <class nr_type_t>
 void eqnsys<nr_type_t>::solve_qr_ls (void) {
@@ -823,36 +832,44 @@ void eqnsys<nr_type_t>::solve_qr_ls (void) {
   substitute_qr_householder_ls ();
 }
 
+/* Helper function for the euclidian norm calculators. */
+static void
+euclidian_update (nr_double_t a, nr_double_t& n, nr_double_t& scale) {
+  nr_double_t x, ax;
+  if ((x = a) != 0) {
+    ax = fabs (x);
+    if (scale < ax) {
+      x = scale / ax;
+      n = 1 + n * x * x;
+      scale = ax;
+    }
+    else {
+      x = ax / scale;
+      n += x * x;
+    }
+  }
+}
+
 /* The following function computes the euclidian norm of the given
    column vector of the matrix A starting from the given row. */
 template <class nr_type_t>
-nr_double_t eqnsys<nr_type_t>::euclidianCol (int c, int r) {
-  nr_double_t scale = 0, n = 1, x, ax;
+nr_double_t eqnsys<nr_type_t>::euclidian_c (int c, int r) {
+  nr_double_t scale = 0, n = 1;
   for (int i = r; i < N; i++) {
-    if ((x = real (A_(i, c))) != 0) {
-      ax = fabs (x);
-      if (scale < ax) {
-	x = scale / ax;
-	n = 1 + n * x * x;
-	scale = ax;
-      }
-      else {
-	x = ax / scale;
-	n += x * x;
-      }
-    }
-    if ((x = imag (A_(i, c))) != 0) {
-      ax = fabs (x);
-      if (scale < ax) {
-	x = scale / ax;
-	n = 1 + n * x * x;
-	scale = ax;
-      }
-      else {
-	x = ax / scale;
-	n += x * x;
-      }
-    }
+    euclidian_update (real (A_(i, c)), n, scale);
+    euclidian_update (imag (A_(i, c)), n, scale);
+  }
+  return scale * sqrt (n);
+}
+
+/* The following function computes the euclidian norm of the given
+   row vector of the matrix A starting from the given column. */
+template <class nr_type_t>
+nr_double_t eqnsys<nr_type_t>::euclidian_r (int r, int c) {
+  nr_double_t scale = 0, n = 1;
+  for (int i = c; i < N; i++) {
+    euclidian_update (real (A_(r, i)), n, scale);
+    euclidian_update (imag (A_(r, i)), n, scale);
   }
   return scale * sqrt (n);
 }
@@ -872,7 +889,7 @@ void eqnsys<nr_type_t>::factorize_qrh (void) {
 
   for (c = 0; c < N; c++) {
     // compute column norms and save in work array
-    nPvt[c] = euclidianCol (c);
+    nPvt[c] = euclidian_c (c);
     cMap[c] = c; // initialize permutation vector
   }
 
@@ -894,12 +911,11 @@ void eqnsys<nr_type_t>::factorize_qrh (void) {
 
     // compute householder vector
     if (c < N) {
-      nr_type_t a, b, l;
-      s = euclidianCol (c, c + 1);
+      nr_type_t a, b;
+      s = euclidian_c (c, c + 1);
       a = A_(c, c);
-      l = a != 0 ? sign (a) : nr_type_t (1);
-      b = - l * xhypot (a, s); // Wj
-      t = xhypot (s, a - b);   // || Vi - Wi ||
+      b = -sign (a) * xhypot (a, s); // Wj
+      t = xhypot (s, a - b);         // || Vi - Wi ||
       R_(c) = b;
       // householder vector entries Ui
       A_(c, c) = (a - b) / t;
@@ -917,7 +933,7 @@ void eqnsys<nr_type_t>::factorize_qrh (void) {
 
     // update norms of remaining columns too
     for (r = c + 1; r < N; r++) {
-      nPvt[r] = euclidianCol (r, c + 1);
+      nPvt[r] = euclidian_c (r, c + 1);
     }
   }
 }
@@ -926,19 +942,18 @@ void eqnsys<nr_type_t>::factorize_qrh (void) {
    orthonormal matrix Q and the upper triangular matrix R.  The
    original matrix is replaced by the householder vectors in the lower
    triangular and the upper triangular R matrix (including the
-   diagonal).  The householder vectors are normalized to have in its
-   first position. */
+   diagonal).  The householder vectors are normalized to have one in
+   their first position. */
 template <class nr_type_t>
 void eqnsys<nr_type_t>::factorize_qr_householder (void) {
-  int c, r, k, pivot;
-  nr_type_t f, t;
+  int c, r, pivot;
   nr_double_t s, MaxPivot;
 
   if (T) delete T; T = new tvector<nr_type_t> (N);
 
   for (c = 0; c < N; c++) {
     // compute column norms and save in work array
-    nPvt[c] = euclidianCol (c);
+    nPvt[c] = euclidian_c (c);
     cMap[c] = c; // initialize permutation vector
   }
 
@@ -946,51 +961,29 @@ void eqnsys<nr_type_t>::factorize_qr_householder (void) {
 
     // put column with largest norm into pivot position
     MaxPivot = nPvt[c]; pivot = c;
-    for (r = c + 1; r < N; r++) {
+    for (r = c + 1; r < N; r++)
       if ((s = nPvt[r]) > MaxPivot) {
 	pivot = r;
 	MaxPivot = s;
       }
-    }
     if (pivot != c) {
       A->exchangeCols (pivot, c);
       Swap (int, cMap[pivot], cMap[c]);
       Swap (nr_double_t, nPvt[pivot], nPvt[c]);
     }
 
-    // compute householder vector
-    {
-      nr_type_t a, b, l;
-      s = euclidianCol (c, c + 1);
-      if (s == 0) {
-	t = T_(c) = 0;
-      } else {
-	a = A_(c, c);
-	l = a != 0 ? sign (a) : nr_type_t (1);
-	b = - l * xhypot (a, s); // Wj
-	t = T_(c) = (b - a) / b;
-	// householder vector entries Ui
-	for (f = a - b, r = c + 1; r < N; r++) A_(r, c) /= f;
-	A_(c, c) = b;
-      }
-    }
-
-    // apply householder transformation to remaining columns
-    if (t != 0) for (r = c + 1; r < N; r++) {
-      for (f = A_(c, r), k = c + 1; k < N; k++)
-	f += conj (A_(k, c)) * A_(k, r);
-      A_(c, r) -= t * f;
-      for (k = c + 1; k < N; k++) A_(k, r) -= t * f * A_(k, c);
-    }
+    // compute and apply householder vector
+    T_(c) = householder_left (c);
 
     // update norms of remaining columns too
     for (r = c + 1; r < N; r++) {
       if ((s = nPvt[r]) > 0) {
 	nr_double_t y = 0;
-	t = A_(c, r) / s;
-	if (norm (t) < 1) y = s * sqrt (1 - norm (t));
+	nr_double_t t = norm (A_(c, r) / s);
+	if (t < 1)
+	  y = s * sqrt (1 - t);
 	if (fabs (y / s) < NR_TINY)
-	  nPvt[r] = euclidianCol (r, c + 1);
+	  nPvt[r] = euclidian_c (r, c + 1);
 	else
 	  nPvt[r] = y;
       }
@@ -1032,13 +1025,13 @@ void eqnsys<nr_type_t>::substitute_qr_householder (void) {
   nr_type_t f;
 
   // form the new right hand side Q'B
-  for (c = 0; c < N - 1; c++) {
+  for (c = 0; c < N; c++) {
     if (T_(c) != 0) {
-      // scalar product u_k^T * B
+      // scalar product u' * B
       for (f = B_(c), r = c + 1; r < N; r++) f += conj (A_(r, c)) * B_(r);
-      B_(c) -= T_(c) * f;
-      // z - 2 * f * u_k
-      for (r = c + 1; r < N; r++) B_(r) -= T_(c) * f * A_(r, c);
+      // z - T * f * u
+      f *= conj (T_(c)); B_(c) -= f;
+      for (r = c + 1; r < N; r++) B_(r) -= f * A_(r, c);
     }
   }
 
@@ -1071,16 +1064,426 @@ void eqnsys<nr_type_t>::substitute_qr_householder_ls (void) {
   }
 
   // compute the least square solution QX
-  for (c = N - 2; c >= 0; c--) {
+  for (c = N - 1; c >= 0; c--) {
     if (T_(c) != 0) {
-      // scalar product u_k^T * B
+      // scalar product u' * B
       for (f = B_(c), r = c + 1; r < N; r++) f += conj (A_(r, c)) * B_(r);
-      B_(c) -= T_(c) * f;
-      // z - 2 * f * u_k
-      for (r = c + 1; r < N; r++) B_(r) -= T_(c) * f * A_(r, c);
+      // z - T * f * u_k
+      f *= T_(c); B_(c) -= f;
+      for (r = c + 1; r < N; r++) B_(r) -= f * A_(r, c);
     }
   }
 
   // permute solution vector
   for (r = 0; r < N; r++) X_(cMap[r]) = B_(r);
 }
+
+#define sign_(a) (real (a) < 0 ? -1 : 1)
+
+/* The function creates the left-hand householder vector for a given
+   column which eliminates the column except the first element.  The
+   householder vector is normalized to have one in the first position.
+   The diagonal element is replaced by the applied householder vector
+   and the vector itself is located in the free matrix positions.  The
+   function returns the normalization factor. */
+template <class nr_type_t>
+nr_type_t eqnsys<nr_type_t>::householder_create_left (int c) {
+  nr_type_t a, b, t;
+  nr_double_t s, g;
+  s = euclidian_c (c, c + 1);
+  if (s == 0 && imag (A_(c, c)) == 0) {
+    // no reflection necessary
+    t = 0;
+  }
+  else {
+    // calculate householder reflection
+    a = A_(c, c);
+    g = sign_(a) * xhypot (a, s);
+    b = a + g;
+    t = b / g;
+    // store householder vector
+    for (int r = c + 1; r < N; r++) A_(r, c) /= b;
+    A_(c, c) = -g;
+  }
+  return t;
+}
+
+/* The function computes a Householder vector to zero-out the matrix
+   entries in the given column, stores it in the annihilated vector
+   space (in a packed form) and applies the transformation to the
+   remaining right-hand columns. */
+template <class nr_type_t>
+nr_type_t eqnsys<nr_type_t>::householder_left (int c) {
+  // compute householder vector
+  nr_type_t t = householder_create_left (c);
+  // apply householder transformation to remaining columns if necessary
+  if (t != 0) {
+    householder_apply_left (c, t);
+  }
+  return t;
+}
+
+/* The function computes a Householder vector to zero-out the matrix
+   entries in the given row, stores it in the annihilated vector space
+   (in a packed form) and applies the transformation to the remaining
+   downward rows. */
+template <class nr_type_t>
+nr_type_t eqnsys<nr_type_t>::householder_right (int r) {
+  // compute householder vector
+  nr_type_t t = householder_create_right (r);
+  // apply householder transformation to remaining rows if necessary
+  if (t != 0) {
+    householder_apply_right (r, t);
+  }
+  return t;
+}
+
+/* The function creates the right-hand householder vector for a given
+   row which eliminates the row except the first element.  The
+   householder vector is normalized to have one in the first position.
+   The super-diagonal element is replaced by the applied householder
+   vector and the vector itself is located in the free matrix
+   positions.  The function returns the normalization factor. */
+template <class nr_type_t>
+nr_type_t eqnsys<nr_type_t>::householder_create_right (int r) {
+  nr_type_t a, b, t;
+  nr_double_t s, g;
+  s = euclidian_r (r, r + 2);
+  if (s == 0 && imag (A_(r, r + 1)) == 0) {
+    // no reflection necessary
+    t = 0;
+  }
+  else {
+    // calculate householder reflection
+    a = A_(r, r + 1);
+    g = sign_(a) * xhypot (a, s);
+    b = a + g;
+    t = b / g;
+    // store householder vector
+    for (int c = r + 2; c < N; c++) A_(r, c) /= b;
+    A_(r, r + 1) = -g;
+  }
+  return t;
+}
+
+/* Applies the householder vector stored in the given column to the
+   right-hand columns using the given normalization factor. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::householder_apply_left (int c, nr_type_t t) {
+  nr_type_t f;
+  int k, r;
+  // apply the householder vector to each right-hand column
+  for (r = c + 1; r < N; r++) {
+    // calculate f = u' * A (a scalar product)
+    f = A_(c, r);
+    for (k = c + 1; k < N; k++) f += conj (A_(k, c)) * A_(k, r);
+    // calculate A -= T * f * u
+    f *= conj (t); A_(c, r) -= f;
+    for (k = c + 1; k < N; k++) A_(k, r) -= f * A_(k, c);
+  }
+}
+
+/* Applies the householder vector stored in the given row to the
+   downward rows using the given normalization factor. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::householder_apply_right (int r, nr_type_t t) {
+  nr_type_t f;
+  int k, c;
+  // apply the householder vector to each downward row
+  for (c = r + 1; c < N; c++) {
+    // calculate f = u' * A (a scalar product)
+    f = A_(c, r + 1);
+    for (k = r + 2; k < N; k++) f += conj (A_(r, k)) * A_(c, k);
+    // calculate A -= T * f * u
+    f *= conj (t); A_(c, r + 1) -= f;
+    for (k = r + 2; k < N; k++) A_(c, k) -= f * A_(r, k);
+  }
+}
+
+// Some helper defines for SVD.
+#define V_ (*V)
+#define S_ (*S)
+#define E_ (*E)
+#define U_ (*A)
+
+/* The function does exactly the same as householder_apply_right()
+   except that it applies the householder transformations to another
+   matrix. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::householder_apply_right_extern (int r, nr_type_t t) {
+  nr_type_t f;
+  int k, c;
+  // apply the householder vector to each downward row
+  for (c = r + 1; c < N; c++) {
+    // calculate f = u' * A (a scalar product)
+    f = V_(c, r + 1);
+    for (k = r + 2; k < N; k++) f += conj (A_(r, k)) * V_(c, k);
+    // calculate A -= T * f * u
+    f *= conj (t); V_(c, r + 1) -= f;
+    for (k = r + 2; k < N; k++) V_(c, k) -= f * A_(r, k);
+  }
+}
+
+/* This function solves the equation system AX = B using the singular
+   value decomposition (Golub-Reinsch-SVD). */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::solve_svd (void) {
+  factorize_svd ();
+  chop_svd ();
+  substitute_svd ();
+}
+
+// Annihilates near-zero singular values.
+template <class nr_type_t>
+void eqnsys<nr_type_t>::chop_svd (void) {
+  int c;
+  nr_double_t Max, Min;
+  Max = 0.0;
+  for (c = 0; c < N; c++) if (fabs (S_(c)) > Max) Max = fabs (S_(c));
+  Min = Max * NR_EPSI;
+  for (c = 0; c < N; c++) if (fabs (S_(c)) < Min) S_(c) = 0.0;
+}
+
+/* The function uses the singular value decomposition A = USV' to
+   solve the equation system AX = B by simple matrix multiplications.
+   Remember that the factorization actually computed U, S and V'. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::substitute_svd (void) {
+  int c, r;
+  nr_type_t f;
+  // calculate U'B
+  for (c = 0; c < N; c++) {
+    f = 0.0;
+    // non-zero result only if S is non-zero
+    if (S_(c) != 0.0) {
+      for (r = 0; r < N; r++) f += conj (U_(r, c)) * B_(r);
+      // this is the divide by S
+      f /= S_(c);
+    }
+    R_(c) = f;
+  }
+  // matrix multiply by V to get the final solution
+  for (r = 0; r < N; r++) {
+    for (f = 0.0, c = 0; c < N; c++) f += conj (V_(c, r)) * R_(c);
+    X_(r) = f;
+  }
+}
+
+/* The function decomposes the matrix A into three other matrices U, S
+   and V'.  The matrix A is overwritten by the U matrix, S is stored
+   in a separate vector and V in a separate matrix. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::factorize_svd (void) {
+  int i, j, l;
+  nr_type_t t;
+
+  // allocate space for vectors and matrices
+  if (R) delete R; R = new tvector<nr_type_t> (N);
+  if (T) delete T; T = new tvector<nr_type_t> (N);
+  if (V) delete V; V = new tmatrix<nr_type_t> (N);
+  if (S) delete S; S = new tvector<nr_double_t> (N);
+  if (E) delete E; E = new tvector<nr_double_t> (N);
+
+  // bidiagonalization through householder transformations
+  for (i = 0; i < N; i++) {
+    T_(i) = householder_left (i);
+    if (i < N - 1) R_(i) = householder_right (i);
+  }
+
+  // copy over the real valued bidiagonal values
+  for (i = 0; i < N; i++) S_(i) = real (A_(i, i));
+  for (E_(0) = 0, i = 1; i < N; i++) E_(i) = real (A_(i - 1, i));
+
+  // backward accumulation of right-hand householder transformations
+  // yields the V' matrix
+  for (l = N, i = N - 1; i >= 0; l = i--) {
+    if (i < N - 1) {
+      if ((t = R_(i)) != 0.0) {
+	householder_apply_right_extern (i, conj (t));
+      }
+      else for (j = l; j < N; j++) // cleanup this row
+	V_(i, j) = V_(j, i) = 0.0;
+    }
+    V_(i, i) = 1.0;
+  }
+
+  // backward accumulation of left-hand householder transformations
+  // yields the U matrix in place of the A matrix
+  for (l = N, i = N - 1; i >= 0; l = i--) {
+    for (j = l; j < N; j++) // cleanup upper row
+      A_(i, j) = 0.0;
+    if ((t = T_(i)) != 0.0) {
+      householder_apply_left (i, conj (t));
+      for (j = l; j < N; j++) A_(j, i) *= -t;
+    }
+    else for (j = l; j < N; j++) // cleanup this column
+      A_(j, i) = 0.0;
+    A_(i, i) = 1.0 - t;
+  }
+
+  // S and E contain diagonal and super-diagonal, A contains U, V'
+  // calculated; now diagonalization can begin
+  diagonalize_svd ();
+}
+
+#ifndef MAX
+# define MAX(x,y) (((x) > (y)) ? (x) : (y))
+#endif
+
+// Helper function computes Givens rotation.
+static nr_double_t
+givens (nr_double_t a, nr_double_t b, nr_double_t& c, nr_double_t& s) {
+  nr_double_t z = xhypot (a, b);
+  c = a / z;
+  s = b / z;
+  return z;
+}
+
+template <class nr_type_t>
+void eqnsys<nr_type_t>::givens_apply_u (int c1, int c2,
+					nr_double_t c, nr_double_t s) {
+  for (int i = 0; i < N; i++) {
+    nr_type_t y = U_(i, c1);
+    nr_type_t z = U_(i, c2);
+    U_(i, c1) = y * c + z * s;
+    U_(i, c2) = z * c - y * s;
+  }
+}
+
+template <class nr_type_t>
+void eqnsys<nr_type_t>::givens_apply_v (int r1, int r2,
+					nr_double_t c, nr_double_t s) {
+  for (int i = 0; i < N; i++) {
+    nr_type_t y = V_(r1, i);
+    nr_type_t z = V_(r2, i);
+    V_(r1, i) = y * c + z * s;
+    V_(r2, i) = z * c - y * s;
+  }
+}
+
+/* This function diagonalizes the upper bidiagonal matrix fromed by
+   the diagonal S and the super-diagonal vector E.  Both vectors are
+   real valued.  Thus real valued calculations even when solving a
+   complex valued equation systems is possible except for the matrix
+   updates of U and V'. */
+template <class nr_type_t>
+void eqnsys<nr_type_t>::diagonalize_svd (void) {
+  bool split;
+  int i, l, j, its, k, n, MaxIters = 30;
+  nr_double_t an, f, g, h, d, c, s, b, a;
+
+  // find largest bidiagonal value
+  for (an = 0, i = 0; i < N; i++)
+    an = MAX (an, fabs (S_(i)) + fabs (E_(i)));
+
+  // diagonalize the bidiagonal matrix (stored as super-diagonal
+  // vector E and diagonal vector S)
+  for (k = N - 1; k >= 0; k--) {
+    // loop over singular values
+    for (its = 0; its <= MaxIters; its++) {
+      split = true;
+      // check for a zero entry along the super-diagonal E, if there
+      // is one, it is possible to QR iterate on two separate matrices
+      // above and below it
+      for (n = 0, l = k; l >= 1; l--) {
+	// note that E_(0) is always zero
+	n = l - 1;
+	if (fabs (E_(l)) + an == an) { split = false; break; }
+	if (fabs (S_(n)) + an == an) break;
+      }
+      // if there is a zero on the diagonal S, it is possible to zero
+      // out the corresponding super-diagonal E entry to its right
+      if (split) {
+	// cancellation of E_(l), if l > 0
+	c = 0.0;
+	s = 1.0;
+	for (i = l; i <= k; i++) {
+	  f = -s * E_(i);
+	  E_(i) *= c;
+	  if (fabs (f) + an == an) break;
+	  g = S_(i);
+	  S_(i) = givens (f, g, c, s);
+	  // apply inverse rotation to U
+	  givens_apply_u (n, i, c, s);
+	}
+      }
+
+      d = S_(k);
+      // convergence
+      if (l == k) {
+	// singular value is made non-negative
+	if (d < 0.0) {
+	  S_(k) = -d;
+	  for (j = 0; j < N; j++) V_(k, j) = -V_(k, j);
+	}
+	break;
+      }
+      if (its == MaxIters) {
+	logprint (LOG_ERROR, "WARNING: no convergence in %d SVD iterations\n",
+		  MaxIters);
+      }
+
+      // shift from bottom 2-by-2 minor
+      a = S_(l);
+      n = k - 1;
+      b = S_(n);
+      g = E_(n);
+      h = E_(k);
+
+      // compute QR shift value (as close as possible to the largest
+      // eigenvalue of the 2-by-2 minor matrix)
+      f  = (b - d) * (b + d) + (g - h) * (g + h);
+      f /= 2.0 * h * b;
+      f += sign_(f) * xhypot (f, 1.0);
+      f  = ((a - d) * (a + d) + h * (b / f - h)) / a;
+      // f => (B_{ll}^2 - u) / B_{ll}
+      // u => eigenvalue of T = B' * B nearer T_{22} (Wilkinson shift)
+
+      // next QR transformation
+      c = s = 1.0;
+      for (j = l; j <= n; j++) {
+	i = j + 1;
+	g = E_(i);
+	b = S_(i);
+	h = s * g; // h => right-hand non-zero to annihilate
+	g *= c;
+	E_(j) = givens (f, h, c, s);
+	// perform the rotation
+	f = a * c + g * s;
+	g = g * c - a * s;
+	h = b * s;
+	b *= c;
+	// here: +-   -+
+	//       | f g | = B * V'_j (also first V'_1)
+	//       | h b |
+	//       +-   -+
+
+	// accumulate the rotation in V'
+	givens_apply_v (j, i, c, s);
+	d = S_(j) = xhypot (f, h);
+	// rotation can be arbitrary if d = 0
+	if (d != 0.0) {
+	  // d => non-zero result on diagonal
+	  d = 1.0 / d;
+	  // rotation coefficients to annihilate the lower non-zero
+	  c = f * d;
+	  s = h * d;
+	}
+	f = c * g + s * b;
+	a = c * b - s * g;
+	// here: +-   -+
+	//       | d f | => U_j * B
+	//       | 0 a |
+	//       +-   -+
+
+	// accumulate rotation into U
+	givens_apply_u (j, i, c, s);
+      }
+      E_(l) = 0;
+      E_(k) = f;
+      S_(k) = a;
+    }
+  }
+}
+
+#undef V_
