@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: equation.cpp,v 1.58 2007/05/27 17:50:14 ela Exp $
+ * $Id: equation.cpp,v 1.62 2007/09/25 17:39:07 ela Exp $
  *
  */
 
@@ -194,17 +194,17 @@ char * constant::toString (void) {
     break;
   case TAG_MATRIX:
     {
-      int len = 3 + (m->getRows () - 1) * (m->getCols () - 1);
+      int len = 3 + (m->getRows () - 1) * m->getCols () + (m->getCols () - 1);
       txt = (char *) malloc (len);
       strcpy (txt, "[");
-      for (int r = 1; r <= m->getRows (); r++) {
-	for (int c = 1; c <= m->getCols (); c++) {
+      for (int r = 0; r < m->getRows (); r++) {
+	for (int c = 0; c < m->getCols (); c++) {
 	  char * s = Cplx2String (m->get (r, c));
 	  txt = (char *) realloc (txt, len += strlen (s));
 	  strcat (txt, s);
-	  if (c != m->getCols ()) strcat (txt, " ");
+	  if (c != m->getCols () - 1) strcat (txt, ",");
 	}
-	if (r != m->getRows ()) strcat (txt, ";");
+	if (r != m->getRows () - 1) strcat (txt, ";");
       }
       strcat (txt, "]");
     }
@@ -515,7 +515,7 @@ application::application () : node (APPLICATION) {
 
 /* Constructor creates an instance of the application class with a
    given function name and the number of arguments. */
-application::application (char * func, int a) : node (APPLICATION) {
+application::application (const char * func, int a) : node (APPLICATION) {
   n = func ? strdup (func) : NULL;
   nargs = a;
   args = NULL;
@@ -604,6 +604,25 @@ char * application::toString (void) {
     }
     strcat (txt, "]");
   }
+  // vectors and matrices
+  else if (!strcmp (n, "vector") || !strcmp (n, "matrix")) {
+    int len = 3 + nargs - 1;
+    txt = (char *) malloc (len);
+    sprintf (txt, "[");
+    for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
+      if (arg->getType () == TAG_CHAR) {
+	txt = (char *) realloc (txt, len++);
+	strcat (txt, ";");
+      } else {
+	char * str = arg->toString ();
+	txt = (char *) realloc (txt, len += strlen (str));
+	strcat (txt, str);
+	node * next = arg->getNext ();
+	if (next && next->getType () != TAG_CHAR) strcat (txt, ",");
+      }
+    }
+    strcat (txt, "]");
+  }
   // unary and n-ary operations here
   else {
     int len = strlen (n) + 3 + nargs - 1;
@@ -688,18 +707,20 @@ int application::evalType (void) {
     // The correct application?
     if (!strcmp (n, app->application)) {
       int nr = 0;
-      // The correct number of arguments?
-      if (nargs != app->nargs) continue;
-      // The correct types of arguments?
-      for (node * arg = args; arg != NULL; arg = arg->getNext (), nr++) {
-	if (arg->getTag () == REFERENCE)
-	  // Skip checking generated reference variables.
-	  if (checker::isGenerated (R (arg)->n))
-	    continue;
-	// Evaluate and check the type of argument.
-	if (!(arg->getType () & app->args[nr])) { nr = -1; break; }
+      if (app->nargs >= 0) {
+	// The correct number of arguments?
+	if (nargs != app->nargs) continue;
+	// The correct types of arguments?
+	for (node * arg = args; arg != NULL; arg = arg->getNext (), nr++) {
+	  if (arg->getTag () == REFERENCE)
+	    // Skip checking generated reference variables.
+	    if (checker::isGenerated (R (arg)->n))
+	      continue;
+	  // Evaluate and check the type of argument.
+	  if (!(arg->getType () & app->args[nr])) { nr = -1; break; }
+	}
+	if (nr == -1) continue;
       }
-      if (nr == -1) continue;
       // A valid application function?
       if (app->eval == NULL) continue;
       // Everything just fine here.
@@ -786,7 +807,7 @@ node * application::differentiate (char * derivative) {
 // Constructor creates an untyped instance of the equation node class.
 node::node () {
   tag = UNKNOWN;
-  dropdeps = output = evaluated = evalPossible = cycle = duplicate = 0;
+  dropdeps = output = evaluated = evalPossible = cycle = duplicate = skip = 0;
   next = NULL;
   dependencies = NULL;
   dataDependencies = NULL;
@@ -802,7 +823,7 @@ node::node () {
 // This constructor creates an typed instance of the equation node class.
 node::node (int type) {
   tag = type;
-  dropdeps = output = evaluated = evalPossible = cycle = duplicate = 0;
+  dropdeps = output = evaluated = evalPossible = cycle = duplicate = skip = 0;
   next = NULL;
   dependencies = NULL;
   dataDependencies = NULL;
@@ -819,7 +840,7 @@ node::node (int type) {
    the given node. */
 node::node (const node & o) {
   tag = o.tag;
-  dropdeps = output = evaluated = evalPossible = cycle = duplicate = 0;
+  dropdeps = output = evaluated = evalPossible = cycle = duplicate = skip = 0;
   next = NULL;
   dependencies = NULL;
   dataDependencies = NULL;
@@ -843,7 +864,7 @@ node::~node () {
 }
 
 // Sets the instance name where the node occurred.
-void node::setInstance (char * n) {
+void node::setInstance (const char * n) {
   if (instance) free (instance);
   instance = n ? strdup (n) : NULL;
 }
@@ -875,12 +896,21 @@ int node::count (void) {
 
 // Appends yet another node to the equation node object.
 void node::append (node * last) {
+  if (!last) return;
   node * n;
   for (n = this; n->getNext () != NULL; n = n->getNext ());
   last->setNext (NULL);
   n->setNext (last);
 }
 
+// Appends othere nodes to the equation node object.
+void node::appendNodes (node * last) {
+  if (!last) return;
+  node * n;
+  for (n = this; n->getNext () != NULL; n = n->getNext ());
+  n->setNext (last);
+}
+
 // Returns the equation node at the given argument position.
 node * node::get (int pos) {
   node * n = this;
@@ -900,6 +930,23 @@ constant * node::getResult (int pos) {
   return n ? n->getResult () : NULL;
 }
 
+/* Returns a double value depending on the type of the equation nodes
+   result type. */
+nr_double_t node::getResultDouble (void) {
+  constant * c = getResult ();
+  if (c != NULL) {
+    switch (getType ()) {
+    case TAG_DOUBLE:
+      return c->d; break;
+    case TAG_COMPLEX:
+      return real (*(c->c)); break;
+    case TAG_BOOLEAN:
+      return c->b ? 1.0 : 0.0; break;
+    }
+  }
+  return 0.0;
+}
+
 // Assigns the dependency list to the equation node object.
 void node::setDependencies (strlist * depends) {
   if (dependencies) delete dependencies;
@@ -1458,7 +1505,7 @@ solver::~solver () {
 void solver::evaluate (void) {
   foreach_equation (eqn) {
     // FIXME: Can save evaluation of already evaluated equations?
-    if (eqn->evalPossible /* && eqn->evaluated == 0 */) {
+    if (eqn->evalPossible && !eqn->skip /* && eqn->evaluated == 0 */) {
       // exception handling around evaluation
       try_running () {
 	eqn->solvee = this;
@@ -1471,7 +1518,7 @@ void solver::evaluate (void) {
 	break;
       }
       eqn->evaluated++;
-#if DEBUG
+#if DEBUG && 0
       // print equation results
       logprint (LOG_STATUS, "%s = %s\n", A(eqn)->result, 
 		eqn->getResult () ? eqn->getResult()->toString () : "error");
@@ -1503,7 +1550,7 @@ node * solver::addEquationData (vector * v, bool ref) {
 /* The function puts the given vector into the equation set.  The
    resulting data vector is going to be copied and exported - given a
    generated name based upon the second argument. */
-node * solver::addGeneratedEquation (vector * v, char * n) {
+node * solver::addGeneratedEquation (vector * v, const char * n) {
   // create generated name
   char * str = (char *) malloc (strlen (n) + 6);
   sprintf (str, "%s.%04d", n, ++generated);
@@ -1930,7 +1977,7 @@ bool checker::containsVariable (char * ident) {
 
 // Structure defining a predefined constant.
 struct pconstant {
-  char * ident;
+  const char * ident;
   nr_double_t value;
 };
 
@@ -1961,7 +2008,8 @@ void checker::constants (void) {
 
 /* The function adds a new equation to the equation checker consisting
    of an assignment of a double variable. */
-node * checker::addDouble (char * type, char * ident, nr_double_t value) {
+node * checker::addDouble (const char * type, const char * ident,
+			   nr_double_t value) {
   node * eqn = createDouble (type, ident, value);
   addEquation (eqn);
   return eqn;
@@ -1985,7 +2033,8 @@ void checker::appendEquation (node * eqn) {
 
 /* This function creates a equation consisting of an assignment of a
    double variable. */
-node * checker::createDouble (char * type, char * ident, nr_double_t value) {
+node * checker::createDouble (const char * type, const char * ident,
+			      nr_double_t value) {
   // create constant double value
   constant * c = new constant (TAG_DOUBLE);
   c->checkee = this;
@@ -2002,7 +2051,8 @@ node * checker::createDouble (char * type, char * ident, nr_double_t value) {
 
 /* This function creates a equation consisting of an assignment of a
    reference. */
-node * checker::createReference (char * type, char * ident, char * value) {
+node * checker::createReference (const char * type, char * ident,
+				 char * value) {
   // create reference value
   reference * r = new reference ();
   r->checkee = this;
@@ -2023,13 +2073,7 @@ node * checker::createReference (char * type, char * ident, char * value) {
 nr_double_t checker::getDouble (char * ident) {
   foreach_equation (eqn) {
     if (!strcmp (ident, eqn->result)) {
-      constant * c = C (eqn->getResult ());
-      if (c != NULL) {
-	if (c->type == TAG_DOUBLE)
-	  return c->d;
-	else if (c->type == TAG_COMPLEX)
-	  return real (*(c->c));
-      }
+      return eqn->getResultDouble ();
     }
   }
   return 0.0;
