@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: equation.h,v 1.38 2007/04/28 09:40:44 ela Exp $
+ * $Id: equation.h,v 1.42 2007/09/25 17:39:07 ela Exp $
  *
  */
 
@@ -66,6 +66,7 @@ public:
   void setNext (node * n) { next = n; }
   int count (void);
   void append (node *);
+  void appendNodes (node *);
   void setDependencies (strlist *);
   strlist * getDependencies (void);
   void setDataDependencies (strlist *);
@@ -83,9 +84,10 @@ public:
   int getTag (void) { return tag; }
   void setType (int tag) { type = tag; }
   constant * getResult (void) { return res; } 
+  nr_double_t getResultDouble (void);
   void setResult (constant *);
   char * getInstance (void);
-  void setInstance (char *);
+  void setInstance (const char *);
   void applyInstance (void);
   constant * calculate (void);    
   strlist * collectDependencies (void);
@@ -105,6 +107,7 @@ public:
   int duplicate;
   int cycle;
   int evalPossible;
+  int skip;
   char * txt;
   int evaluated;
   char * instance;
@@ -229,7 +232,7 @@ class application : public node
 public:
   application ();
   application (const application &);
-  application (char *, int);
+  application (const char *, int);
   ~application ();
   void print (void);
   void addDependencies (strlist *);
@@ -267,7 +270,7 @@ public:
   node * getEquations (void) { return equations; }
   void list (void);
   int findUndefined (int);
-  static char * tag2key (int);
+  static const char * tag2key (int);
   static int isGenerated (char *);
   strlist * getVariables (void);
   int findDuplicate (void);
@@ -283,9 +286,9 @@ public:
   void constants (void);
   int check (int noundefined = 1);
   strlist * variables (void);
-  node * addDouble (char *, char *, nr_double_t);
-  node * createDouble (char *, char *, nr_double_t);
-  node * createReference (char *, char *, char *);
+  node * addDouble (const char *, const char *, nr_double_t);
+  node * createDouble (const char *, const char *, nr_double_t);
+  node * createReference (const char *, char *, char *);
   void appendEquation (node *);
   void addEquation (node *);
   node * findEquation (char *);
@@ -317,7 +320,7 @@ public:
   void evaluate (void);
   node * addEquationData (vector *, bool ref = false);
   node * addEquationData (matvec *);
-  node * addGeneratedEquation (vector *, char *);
+  node * addGeneratedEquation (vector *, const char *);
   vector * dataVector (node *);
   void checkinDataset (void);
   void checkoutDataset (void);
