@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: evaluate.cpp,v 1.61 2007/05/24 16:40:31 ela Exp $
+ * $Id: evaluate.cpp,v 1.70 2007/11/02 19:09:26 ela Exp $
  *
  */
 
@@ -1223,6 +1223,14 @@ constant * evaluate::unwrap_v_2 (constant * args) {
   _RETV (unwrap (*v1, fabs (d2)));
 }
 
+constant * evaluate::unwrap_v_3 (constant * args) {
+  _ARV0 (v1);
+  _ARD1 (d2);
+  _ARD2 (d3);
+  _DEFV ();
+  _RETV (unwrap (*v1, fabs (d2), fabs (d3)));
+}
+
 // ******** radian/degree conversion **********
 constant * evaluate::deg2rad_d (constant * args) {
   _ARD0 (d1);
@@ -1285,6 +1293,18 @@ constant * evaluate::dB_v (constant * args) {
   _RETV (dB (*v1));
 }
 
+constant * evaluate::dB_m (constant * args) {
+  _ARM0 (m1);
+  _DEFM ();
+  _RETM (dB (*m1));
+}
+
+constant * evaluate::dB_mv (constant * args) {
+  _ARMV0 (v1);
+  _DEFMV ();
+  _RETMV (dB (*v1));
+}
+
 // ********** square root *****************
 constant * evaluate::sqrt_d (constant * args) {
   _ARD0 (d1);
@@ -1976,6 +1996,7 @@ constant * evaluate::index_mv_2 (constant * args) {
     sprintf (txt, "matvec indices [%d,%d] out of bounds [1-%d,1-%d]",
 	     r, c, mv->getRows (), mv->getCols ());
     THROW_MATH_EXCEPTION (txt);
+    res->v = new vector (mv->getSize ());
   } else {
     res->v = new vector (mv->get (r - 1, c - 1));
   }
@@ -1990,6 +2011,7 @@ constant * evaluate::index_mv_1 (constant * args) {
     char txt[256];
     sprintf (txt, "matvec index [%d] out of bounds [1-%d]", i, mv->getSize ());
     THROW_MATH_EXCEPTION (txt);
+    res->m = new matrix (mv->getRows (), mv->getCols ());
   } else {
     res->m = new matrix (mv->get (i - 1));
   }
@@ -2080,6 +2102,7 @@ constant * evaluate::index_m_2 (constant * args) {
     sprintf (txt, "matrix indices [%d,%d] out of bounds [1-%d,1-%d]",
 	     r, c, m->getRows (), m->getCols ());
     THROW_MATH_EXCEPTION (txt);
+    res->c = new complex ();
   } else {
     res->c = new complex (m->get (r - 1, c - 1));
   }
@@ -2586,6 +2609,17 @@ constant * evaluate::mu2_mv (constant * args) {
   _RETV (k);
 }
 
+constant * evaluate::b1_m (constant * args) {
+  _ARM0 (m);
+  _DEFD ();
+  _RETD (b1 (*m));
+}
+
+constant * evaluate::b1_mv (constant * args) {
+  _ARMV0 (mv);
+  _DEFV ();
+  _RETV (b1 (*mv));
+}
 
 // ***************** vector creation *****************
 constant * evaluate::linspace (constant * args) {
@@ -3662,21 +3696,115 @@ constant * evaluate::kbd_d (constant * args) {
 // ***************** if-then-else operation ****************
 constant * evaluate::ifthenelse_d_d (constant * args) {
   _ARB0 (cond);
-  int t1 = _ARG(1)->getType ();
-  int t2 = _ARG(2)->getType ();
-  nr_double_t d1, d2;
-  if (t1 == TAG_DOUBLE)
-    d1 = D(_ARES(1));
-  else
-    d1 = abs (*C(_ARES(1)));
-  if (t2 == TAG_DOUBLE)
-    d2 = D(_ARES(2));
-  else
-    d2 = abs (*C(_ARES(2)));
+  _ARD1 (d1);
+  _ARD2 (d2);
   _DEFD ();
   _RETD (cond ? d1 : d2);
 }
 
+constant * evaluate::ifthenelse_b_b (constant * args) {
+  _ARB0 (cond);
+  _ARB1 (b1);
+  _ARB2 (b2);
+  _DEFB ();
+  _RETB (cond ? b1 : b2);
+}
+
+constant * evaluate::ifthenelse_d_b (constant * args) {
+  _ARB0 (cond);
+  _ARD1 (d1);
+  _ARB2 (b2);
+  _DEFD ();
+  _RETD (cond ? d1 : (b2 ? 1.0 : 0.0));
+}
+
+constant * evaluate::ifthenelse_b_d (constant * args) {
+  _ARB0 (cond);
+  _ARB1 (b1);
+  _ARD2 (d2);
+  _DEFD ();
+  _RETD (cond ? (b1 ? 1.0 : 0.0) : d2);
+}
+
+constant * evaluate::ifthenelse_c_c (constant * args) {
+  _ARB0 (cond);
+  int t1 = _ARG(1)->getType ();
+  int t2 = _ARG(2)->getType ();
+  complex c1, c2;
+  if (t1 == TAG_DOUBLE)
+    c1 = D(_ARES(1));
+  else if (t1 == TAG_COMPLEX)
+    c1 = *C(_ARES(1));
+  else
+    c1 = B(_ARES(1)) ? 1.0 : 0.0;
+  if (t2 == TAG_DOUBLE)
+    c2 = D(_ARES(2));
+  else if (t2 == TAG_COMPLEX)
+    c2 = *C(_ARES(2));
+  else
+    c2 = B(_ARES(2)) ? 1.0 : 0.0;
+  _DEFC ();
+  _RETC (cond ? c1 : c2);
+}
+
+constant * evaluate::ifthenelse_m_m (constant * args) {
+  _ARB0 (cond);
+  int t1 = _ARG(1)->getType ();
+  int t2 = _ARG(2)->getType ();
+  matrix m1, m2;
+  switch (t1) {
+  case TAG_DOUBLE:
+    m1 = matrix (1); m1 (1,1) = D(_ARES(1)); break;
+  case TAG_COMPLEX:
+    m1 = matrix (1); m1 (1,1) = *C(_ARES(1)); break;
+  case TAG_BOOLEAN:
+    m1 = matrix (1); m1 (1,1) = B(_ARES(1)) ? 1.0 : 0.0; break;
+  case TAG_MATRIX:
+    m1 = *M(_ARES(1)); break;
+  }
+  switch (t2) {
+  case TAG_DOUBLE:
+    m2 = matrix (1); m2 (0,0) = D(_ARES(2)); break;
+  case TAG_COMPLEX:
+    m2 = matrix (1); m2 (0,0) = *C(_ARES(2)); break;
+  case TAG_BOOLEAN:
+    m2 = matrix (1); m2 (0,0) = B(_ARES(2)) ? 1.0 : 0.0; break;
+  case TAG_MATRIX:
+    m2 = *M(_ARES(2)); break;
+  }
+  _DEFM ();
+  _RETM (cond ? m1 : m2);
+}
+
+constant * evaluate::ifthenelse_v_v (constant * args) {
+  _ARB0 (cond);
+  int t1 = _ARG(1)->getType ();
+  int t2 = _ARG(2)->getType ();
+  vector v1, v2;
+  switch (t1) {
+  case TAG_DOUBLE:
+    v1 = vector (1); v1 (0) = D(_ARES(1)); break;
+  case TAG_COMPLEX:
+    v1 = vector (1); v1 (0) = *C(_ARES(1)); break;
+  case TAG_BOOLEAN:
+    v1 = vector (1); v1 (0) = B(_ARES(1)) ? 1.0 : 0.0; break;
+  case TAG_VECTOR:
+    v1 = *V(_ARES(1)); break;
+  }
+  switch (t2) {
+  case TAG_DOUBLE:
+    v2 = vector (1); v2 (0) = D(_ARES(2)); break;
+  case TAG_COMPLEX:
+    v2 = vector (1); v2 (0) = *C(_ARES(2)); break;
+  case TAG_BOOLEAN:
+    v2 = vector (1); v2 (0) = B(_ARES(2)) ? 1.0 : 0.0; break;
+  case TAG_VECTOR:
+    v2 = *V(_ARES(2)); break;
+  }
+  _DEFV ();
+  _RETV (cond ? v1 : v2);
+}
+
 // ************************** less *************************
 constant * evaluate::less_d_d (constant * args) {
   _ARD0 (d0);
@@ -3762,5 +3890,99 @@ constant * evaluate::and_b_b (constant * args) {
   _RETB (b0 && b1);
 }
 
+// ******************* random numbers **********************
+constant * evaluate::rand (constant *) {
+  _DEFD ();
+  _RETD (((nr_double_t) ::rand ()) / (nr_double_t) RAND_MAX);
+}
+
+constant * evaluate::srand_d (constant * args) {
+  static int done = 0;
+  _ARD0 (d0);
+  _DEFD ();
+  if (!done) {
+    unsigned int i0 = (unsigned int) d0;
+    ::srand (i0);
+    done = 1;
+    _RETD (1.0);
+  } else {
+    _RETD (0.0);
+  }
+}
+
+// ******************* immediate vectors *******************
+constant * evaluate::vector_x (constant * args) {
+  _DEFV ();
+  vector * v = new vector ();
+  for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
+    constant * c = arg->getResult ();
+    switch (arg->getType ()) {
+    case TAG_COMPLEX:
+      v->add (*(c->c)); break;
+    case TAG_DOUBLE:
+      v->add (c->d); break;
+    case TAG_BOOLEAN:
+      v->add (c->b ? 1.0 : 0.0); break;
+    case TAG_VECTOR:
+      v->add (c->v); break;
+    default:
+      v->add (0.0); break;
+    }
+  }
+  res->v = v;
+  return res;
+}
+
+// ******************* immediate matrices ******************
+constant * evaluate::matrix_x (constant * args) {
+  _DEFM ();
+  /* create temporary list of vectors */
+  vector * va = NULL;
+  vector * v = new vector ();
+  va = v;
+  for (node * arg = args; arg != NULL; arg = arg->getNext ()) {
+    constant * c = arg->getResult ();
+    switch (arg->getType ()) {
+    case TAG_COMPLEX:
+      v->add (*(c->c)); break;
+    case TAG_DOUBLE:
+      v->add (c->d); break;
+    case TAG_BOOLEAN:
+      v->add (c->b ? 1.0 : 0.0); break;
+    case TAG_VECTOR:
+      v->add (c->v); break;
+    case TAG_CHAR:
+      if (c->chr == ';') {
+	/* append new vector, i.e. a new matrix row */
+	vector * vn = new vector ();
+	v->setNext (vn);
+	v = vn;
+      }
+      else v->add (0.0);
+      break;
+    default:
+      v->add (0.0); break;
+    }
+  }
+  /* determine matrix dimensions and create it */
+  int r, c;
+  for (r = 0, c = 0, v = va; v != NULL; v = (vector *) v->getNext (), r++) {
+    if (c < v->getSize ()) c = v->getSize ();
+  }
+  matrix * m = new matrix (r, c);
+  /* fill in matrix entries and delete temporary vector list */
+  vector * vn = NULL;
+  for (r = 0, v = va; v != NULL; v = vn, r++) {
+    for (c = 0; c < v->getSize (); c++) {
+      m->set (r, c, v->get (c));
+    }
+    vn = (vector *) v->getNext ();
+    delete v;
+  }
+  /* return result matrix */
+  res->m = m;
+  return res;
+}
+
 // Include the application array.
 #include "applications.h"
