@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: evaluate.h,v 1.36 2007/05/24 16:40:31 ela Exp $
+ * $Id: evaluate.h,v 1.44 2007/11/02 19:09:26 ela Exp $
  *
  */
 
@@ -209,6 +209,7 @@ public:
 
   static constant * unwrap_v_1 (constant *);
   static constant * unwrap_v_2 (constant *);
+  static constant * unwrap_v_3 (constant *);
 
   static constant * deg2rad_d (constant *);
   static constant * deg2rad_c (constant *);
@@ -220,6 +221,8 @@ public:
   static constant * dB_d (constant *);
   static constant * dB_c (constant *);
   static constant * dB_v (constant *);
+  static constant * dB_m (constant *);
+  static constant * dB_mv (constant *);
 
   static constant * sqrt_d (constant *);
   static constant * sqrt_c (constant *);
@@ -529,6 +532,8 @@ public:
   static constant * mu1_mv (constant *);
   static constant * mu2_m  (constant *);
   static constant * mu2_mv (constant *);
+  static constant * b1_m   (constant *);
+  static constant * b1_mv  (constant *);
 
   static constant * linspace (constant *);
   static constant * logspace (constant *);
@@ -692,7 +697,14 @@ public:
   static constant * kbd_d_d (constant *);
   static constant * kbd_d   (constant *);
 
+  static constant * ifthenelse_b_b (constant *);
+  static constant * ifthenelse_b_d (constant *);
+  static constant * ifthenelse_d_b (constant *);
   static constant * ifthenelse_d_d (constant *);
+  static constant * ifthenelse_c_c (constant *);
+  static constant * ifthenelse_m_m (constant *);
+  static constant * ifthenelse_v_v (constant *);
+
   static constant * less_d_d (constant *);
   static constant * greater_d_d (constant *);
   static constant * lessorequal_d_d (constant *);
@@ -704,6 +716,12 @@ public:
   static constant * not_b (constant *);
   static constant * or_b_b (constant *);
   static constant * and_b_b (constant *);
+
+  static constant * rand (constant *);
+  static constant * srand_d (constant *);
+
+  static constant * vector_x (constant *);
+  static constant * matrix_x (constant *);
 };
 
 // Type of application function.
@@ -712,11 +730,11 @@ typedef constant * (* evaluator_t) (constant *);
 // Structure defining an application.
 struct application_t
 {
-  char * application; /* the name of the application     */
-  int retval;         /* its return type                 */
-  evaluator_t eval;   /* the actual application function */
-  int nargs;          /* number of arguments             */
-  int args[16];       /* the appropriate argument types  */
+  const char * application; /* the name of the application     */
+  int retval;               /* its return type                 */
+  evaluator_t eval;         /* the actual application function */
+  int nargs;                /* number of arguments             */
+  int args[16];             /* the appropriate argument types  */
 };
 
 extern struct application_t applications[];
