@@ -1,7 +1,7 @@
 /*
  * hbsolver.cpp - harmonic balance solver class implementation
  *
- * Copyright (C) 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: hbsolver.cpp,v 1.22 2007/04/04 19:25:41 ela Exp $
+ * $Id: hbsolver.cpp,v 1.24 2007/12/28 20:08:47 ela Exp $
  *
  */
 
@@ -139,7 +139,7 @@ hbsolver::hbsolver (hbsolver & o) : analysis (o) {
 
 /* This is the HB netlist solver.  It prepares the circuit list and
    solves it then. */
-void hbsolver::solve (void) {
+int hbsolver::solve (void) {
 
   int iterations = 0, done = 0;
   int MaxIterations = getPropertyInteger ("MaxIter");
@@ -287,6 +287,7 @@ void hbsolver::solve (void) {
 
   // save results into dataset
   saveResults ();
+  return 0;
 }
 
 /* Goes through the list of circuit objects and runs its calcHB()
@@ -407,13 +408,13 @@ void hbsolver::collectFrequencies (void) {
     ndfreqs[i] = (n + 1) * 2;
   }
 
-#if DEBUG && 0
+#if HB_DEBUG
   fprintf (stderr, "%d frequencies: [ ", negfreqs.getSize ());
   for (i = 0; i < negfreqs.getSize (); i++) {
     fprintf (stderr, "%g ", (double) real (negfreqs.get (i)));
   }
   fprintf (stderr, "]\n");
-#endif /* DEBUG */
+#endif /* HB_DEBUG */
 
   // build list of positive frequencies including DC
   for (n = 0; n < negfreqs.getSize (); n++) {
