@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: input.cpp,v 1.72 2007/05/27 17:50:15 ela Exp $
+ * $Id: input.cpp,v 1.76 2007/12/18 21:15:47 ela Exp $
  *
  */
 
@@ -379,6 +379,10 @@ circuit * input::createCircuit (char * type) {
     return new iexp ();
   else if (!strcmp (type, "Vexp"))
     return new vexp ();
+  else if (!strcmp (type, "Ifile"))
+    return new ifile ();
+  else if (!strcmp (type, "Vfile"))
+    return new vfile ();
   else if (!strcmp (type, "AM_Mod"))
     return new vam ();
   else if (!strcmp (type, "PM_Mod"))
@@ -497,6 +501,10 @@ circuit * input::createCircuit (char * type) {
     return new hicumL2p1 ();
   else if (!strcmp (type, "HBT_X"))
     return new HBT_X ();
+  else if (!strcmp (type, "mod_amp"))
+    return new mod_amp ();
+  else if (!strcmp (type, "hic2_full"))
+    return new hic2_full ();
 
   logprint (LOG_ERROR, "no such circuit type `%s'\n", type);
   return NULL;
