@@ -1,7 +1,7 @@
 /*
  * matrix.h - matrix class definitions
  *
- * Copyright (C) 2003, 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: matrix.h,v 1.18 2006/07/03 08:52:23 raimi Exp $
+ * $Id: matrix.h,v 1.21 2007/11/01 21:42:46 ela Exp $
  *
  */
 
@@ -28,9 +28,9 @@
 class vector;
 class matrix;
 
-// other operations
 matrix eye (int);
 
+/*!\brief Dense complex matrix class */
 class matrix
 {
  public:
@@ -77,6 +77,7 @@ class matrix
   friend matrix transpose (matrix);
   friend matrix conj (matrix);
   friend matrix abs (matrix);
+  friend matrix dB (matrix);
   friend matrix arg (matrix);
   friend matrix adjoint (matrix);
   friend matrix real (matrix);
@@ -120,14 +121,33 @@ class matrix
 
   friend matrix twoport (matrix, char, char);
   friend nr_double_t rollet (matrix);
+  friend nr_double_t b1 (matrix);
 
-  // easy accessor operators
+  /*! \brief Read access operator 
+      \param[in] r: row number (from 0 like usually in C)
+      \param[in] c: column number (from 0 like usually in C)
+      \return Cell in the row r and column c
+      \todo: Why not inline
+      \todo: Why not r and c not const
+      \todo: Create a debug version checking out of bound (using directly assert)
+  */  
   complex  operator () (int r, int c) const { return data[r * cols + c]; }
+  /*! \brief Write access operator 
+      \param[in] r: row number (from 0 like usually in C)
+      \param[in] c: column number (from 0 like usually in C)
+      \return Reference to cell in the row r and column c
+      \todo: Why not inline
+      \todo: Why r and c not const
+      \todo: Create a debug version checking out of bound (using directly assert)
+  */  
   complex& operator () (int r, int c) { return data[r * cols + c]; }
 
  private:
+  /*! Number of colunms */
   int cols;
+  /*! Number of rows */
   int rows;
+  /*! Matrix data */
   complex * data;
 };
 
