@@ -1,7 +1,7 @@
 /*
  * matvec.cpp - matrix vector class implementation
  *
- * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: matvec.cpp,v 1.20 2006/07/03 08:52:23 raimi Exp $
+ * $Id: matvec.cpp,v 1.23 2007/11/01 21:42:46 ela Exp $
  *
  */
 
@@ -90,7 +90,7 @@ matvec::~matvec () {
 }
 
 // Sets the name of the matvec object.
-void matvec::setName (char * n) {
+void matvec::setName (const char * n) {
   if (name) free (name);
   name = n ? strdup (n) : NULL;
 }
@@ -123,7 +123,7 @@ vector matvec::get (int r, int c) {
 
 /* This function returns a static text representation with the
    'n[r,c]' scheme indicating a matrix (vector) entry. */
-char * matvec::createMatrixString (char * n, int r, int c) {
+char * matvec::createMatrixString (const char * n, int r, int c) {
   static char str[256]; // hopefully enough
   sprintf (str, "%s[%d,%d]", n, r + 1, c + 1);
   return str;
@@ -436,6 +436,13 @@ matvec abs (matvec a) {
   return res;
 }
 
+// Computes magnitude in dB of each matrix vector element.
+matvec dB (matvec a) {
+  matvec res (a.getSize (), a.getRows (), a.getCols ());
+  for (int i = 0; i < a.getSize (); i++) res.set (dB (a.get (i)), i);
+  return res;
+}
+
 // Computes the argument of each matrix vector element.
 matvec arg (matvec a) {
   matvec res (a.getSize (), a.getRows (), a.getCols ());
@@ -583,3 +590,12 @@ vector rollet (matvec m) {
   for (int i = 0; i < m.getSize (); i++) res.set (rollet (m.get (i)), i);
   return res;
 }
+
+/* The function returns the stability measure B1 vector of the given
+   S-parameter matrix vector. */
+vector b1 (matvec m) {
+  assert (m.getCols () >= 2 && m.getRows () >= 2);
+  vector res (m.getSize ());
+  for (int i = 0; i < m.getSize (); i++) res.set (b1 (m.get (i)), i);
+  return res;
+}
