@@ -1,7 +1,7 @@
 /*
  * matvec.h - matrix vector class definitions
  *
- * Copyright (C) 2004, 2005, 2006 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2005, 2006, 2007 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: matvec.h,v 1.13 2006/07/03 08:52:23 raimi Exp $
+ * $Id: matvec.h,v 1.16 2007/11/01 21:42:46 ela Exp $
  *
  */
 
@@ -38,13 +38,13 @@ class matvec
   int getSize (void) { return size; }
   int getCols (void) { return cols; }
   int getRows (void) { return rows; }
-  void setName (char *);
+  void setName (const char *);
   char * getName (void);
   void set (vector, int, int);
   void set (matrix, int);
   vector get (int, int);
   matrix get (int);
-  static char * createMatrixString (char *, int, int);
+  static char * createMatrixString (const char *, int, int);
   static char * createMatrixString (char, int, int);
   static char * isMatrixVector (char *, int&, int&);
 
@@ -94,9 +94,11 @@ class matvec
   friend matvec real      (matvec);
   friend matvec imag      (matvec);
   friend matvec abs       (matvec);
+  friend matvec dB        (matvec);
   friend matvec arg       (matvec);
   friend matvec adjoint   (matvec);
   friend vector rollet    (matvec);
+  friend vector b1        (matvec);
 
   friend matvec stos (matvec, complex, complex z0 = 50.0);
   friend matvec stos (matvec, nr_double_t, nr_double_t z0 = 50.0);
