@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: qucsdefs.h,v 1.71 2007/05/17 09:28:18 ela Exp $
+ * $Id: qucsdefs.h,v 1.77 2007/12/20 21:02:09 ela Exp $
  *
  */
 
@@ -206,6 +206,26 @@ struct define_t qucs_definition_available[] =
       { "Tf", PROP_REAL, { 1e-9, PROP_NO_STR }, PROP_POS_RANGE },
       PROP_NO_PROP }
   },
+  /* file based current source */
+  { "Ifile", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "File", PROP_STR, { PROP_NO_VAL, "ifile.dat" }, PROP_NO_RANGE },
+      PROP_NO_PROP },
+    { { "Interpolator", PROP_STR, { PROP_NO_VAL, "linear" }, PROP_NO_RANGE },
+      { "Repeat", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
+      { "G", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE },
+      { "T", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
+  /* file based voltage source */
+  { "Vfile", 2, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
+    { { "File", PROP_STR, { PROP_NO_VAL, "vfile.dat" }, PROP_NO_RANGE },
+      PROP_NO_PROP },
+    { { "Interpolator", PROP_STR, { PROP_NO_VAL, "linear" }, PROP_NO_RANGE },
+      { "Repeat", PROP_STR, { PROP_NO_VAL, "no" }, PROP_NO_RANGE },
+      { "G", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE },
+      { "T", PROP_REAL, { 0, PROP_NO_STR }, PROP_POS_RANGE },
+      PROP_NO_PROP }
+  },
   /* AM modulated AC voltage source */
   { "AM_Mod", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_LINEAR,
     { { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, 
@@ -627,7 +647,6 @@ struct define_t qucs_definition_available[] =
       PROP_NO_PROP }
   },
 
-
   /* hicumL2p1 verilog device */
   { "hicumL2p1", 5, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
     {
@@ -822,6 +841,149 @@ struct define_t qucs_definition_available[] =
       PROP_NO_PROP },
     { PROP_NO_PROP }
   },
+  /* mod_amp verilog device */
+  { "mod_amp", 3, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "GBP", PROP_REAL, { 1e6, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "AOLDC", PROP_REAL, { 106.0, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "FP2", PROP_REAL, { 3e6, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "RO", PROP_REAL, { 75, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "CD", PROP_REAL, { 1e-12, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "RD", PROP_REAL, { 2e6, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "IOFF", PROP_REAL, { 20e-9, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "IB", PROP_REAL, { 80e-9, PROP_NO_STR }, { '[', 1e-20, 0, '.' } },
+      { "VOFF", PROP_REAL, { 7e-4, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "CMRRDC", PROP_REAL, { 90.0, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "FCM", PROP_REAL, { 200, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "PSRT", PROP_REAL, { 5e5, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "NSRT", PROP_REAL, { 5e5, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "VLIMP", PROP_REAL, { 14, PROP_NO_STR }, { '[', 0.01, 0, '.' } },
+      { "VLIMN", PROP_REAL, { (-14), PROP_NO_STR }, { '.', 0, 0, ']' } },
+      { "ILMAX", PROP_REAL, { 35e-3, PROP_NO_STR }, { '[', 1e-9, 0, '.' } },
+      { "CSCALE", PROP_REAL, { 50, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
+  /* hic2_full verilog device */
+  { "hic2_full", 5, PROP_COMPONENT, PROP_NO_SUBSTRATE, PROP_NONLINEAR,
+    {
+      { "c10", PROP_REAL, { 2.0E-30, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "qp0", PROP_REAL, { 2.0E-14, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "ich", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "hfe", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "hfc", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "hjei", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 100, ']' } },
+      { "hjci", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 100, ']' } },
+      { "ibeis", PROP_REAL, { 1.0E-18, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mbei", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ireis", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mrei", PROP_REAL, { 2.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ibeps", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mbep", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ireps", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "mrep", PROP_REAL, { 2.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "mcf", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "tbhrec", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "ibcis", PROP_REAL, { 1.0E-16, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "mbci", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ibcxs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "mbcx", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "ibets", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "abet", PROP_REAL, { 40, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "tunode", PROP_INT, { 1, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "favl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "qavl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "alfav", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alqav", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "rbi0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "rbx", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "fgeo", PROP_REAL, { 0.6557, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "fdqr0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "fcrbi", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "fqi", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "re", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "rcx", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "itss", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "msf", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "iscs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1.0, ']' } },
+      { "msc", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "tsf", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "rsu", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "csu", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "cjei0", PROP_REAL, { 1.0E-20, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vdei", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zei", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "ajei", PROP_REAL, { 2.5, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "cjep0", PROP_REAL, { 1.0E-20, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vdep", PROP_REAL, { 0.9, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zep", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "ajep", PROP_REAL, { 2.5, PROP_NO_STR }, { '[', 1, 0, '.' } },
+      { "cjci0", PROP_REAL, { 1.0E-20, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vdci", PROP_REAL, { 0.7, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zci", PROP_REAL, { 0.4, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vptci", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "cjcx0", PROP_REAL, { 1.0E-20, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vdcx", PROP_REAL, { 0.7, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zcx", PROP_REAL, { 0.4, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vptcx", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "fbcpar", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "fbepar", PROP_REAL, { 1.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "cjs0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vds", PROP_REAL, { 0.6, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "zs", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 1, ']' } },
+      { "vpts", PROP_REAL, { 100, PROP_NO_STR }, { ']', 0, 100, ']' } },
+      { "t0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "dt0h", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "tbvl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "tef0", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "gtfe", PROP_REAL, { 1.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "thcs", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "ahc", PROP_REAL, { 0.1, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "fthc", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "rci0", PROP_REAL, { 150, PROP_NO_STR }, { ']', 0, 0, '.' } },
+      { "vlim", PROP_REAL, { 0.5, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vces", PROP_REAL, { 0.1, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "vpt", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "tr", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "cbepar", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "cbcpar", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "alqf", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "alit", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "flnqs", PROP_INT, { 0, PROP_NO_STR }, { '[', 0, 1, ']' } },
+      { "kf", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "af", PROP_REAL, { 2.0, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "cfbe", PROP_INT, { (-1), PROP_NO_STR }, { '[', (-2), (-1), ']' } },
+      { "latb", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "latl", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "vgb", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "alt0", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "kt0", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetaci", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alvs", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alces", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarbi", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarbx", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetarcx", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetare", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetacx", PROP_REAL, { 1.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "vge", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vgc", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "vgs", PROP_REAL, { 1.17, PROP_NO_STR }, { ']', 0, 10, ']' } },
+      { "f1vg", PROP_REAL, { (-1.02377e-4), PROP_NO_STR }, PROP_NO_RANGE },
+      { "f2vg", PROP_REAL, { 4.3215e-4, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetact", PROP_REAL, { 3.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "zetabet", PROP_REAL, { 3.5, PROP_NO_STR }, PROP_NO_RANGE },
+      { "alb", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "flsh", PROP_INT, { 0, PROP_NO_STR }, { '[', 0, 2, ']' } },
+      { "rth", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "cth", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "flcomp", PROP_REAL, { 0.0, PROP_NO_STR }, { '[', 0, 0, '.' } },
+      { "tnom", PROP_REAL, { 27.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "dt", PROP_REAL, { 0.0, PROP_NO_STR }, PROP_NO_RANGE },
+      { "Temp", PROP_REAL, { 26.85, PROP_NO_STR }, PROP_MIN_VAL (K) },
+      PROP_NO_PROP },
+    { PROP_NO_PROP }
+  },
 
   /* microstrip substrate */
   { "SUBST", 0, PROP_COMPONENT, PROP_SUBSTRATE, PROP_LINEAR,
