@@ -1,7 +1,9 @@
-/* A Bison parser, made by GNU Bison 2.1.  */
+/* A Bison parser, made by GNU Bison 2.3.  */
 
-/* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+/* Skeleton interface for Bison's Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,10 +20,18 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.  */
 
-/* As a special exception, when this file is copied by Bison into a
-   Bison output file, you may use that output file without restriction.
-   This special exception was added by the Free Software Foundation
-   in version 1.24 of Bison.  */
+/* As a special exception, you may create a larger work that contains
+   part or all of the Bison parser skeleton and distribute that work
+   under terms of your choice, so long as that work isn't itself a
+   parser generator using the skeleton or a modified version thereof
+   as a parser skeleton.  Alternatively, if you modify or redistribute
+   the parser skeleton itself, you may (at your option) remove this
+   special exception, which will cause the skeleton and the resulting
+   Bison output files to be licensed under the GNU General Public
+   License without this special exception.
+
+   This special exception was added by the Free Software Foundation in
+   version 2.2 of Bison.  */
 
 /* Tokens.  */
 #ifndef YYTOKENTYPE
@@ -42,8 +52,17 @@
      COMPLEX = 268,
      Character = 269,
      STRING = 270,
-     NEG = 271,
-     POS = 272
+     Or = 271,
+     And = 272,
+     Equal = 273,
+     NotEqual = 274,
+     GreaterOrEqual = 275,
+     LessOrEqual = 276,
+     Greater = 277,
+     Less = 278,
+     Not = 279,
+     NEG = 280,
+     POS = 281
    };
 #endif
 /* Tokens.  */
@@ -60,15 +79,25 @@
 #define COMPLEX 268
 #define Character 269
 #define STRING 270
-#define NEG 271
-#define POS 272
+#define Or 271
+#define And 272
+#define Equal 273
+#define NotEqual 274
+#define GreaterOrEqual 275
+#define LessOrEqual 276
+#define Greater 277
+#define Less 278
+#define Not 279
+#define NEG 280
+#define POS 281
 
 
 
 
-#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 71 "parse_netlist.y"
-typedef union YYSTYPE {
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef union YYSTYPE
+#line 76 "parse_netlist.y"
+{
   char * ident;
   char * str;
   double d;
@@ -87,9 +116,10 @@ typedef union YYSTYPE {
   eqn::reference * ref;
   eqn::application * app;
   eqn::assignment * assign;
-} YYSTYPE;
-/* Line 1447 of yacc.c.  */
-#line 93 "tokens_netlist.h"
+}
+/* Line 1489 of yacc.c.  */
+#line 122 "tokens_netlist.h"
+	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -97,5 +127,3 @@ typedef union YYSTYPE {
 
 extern YYSTYPE netlist_lval;
 
-
-
