@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: vector.cpp,v 1.34 2007/05/03 19:01:05 ela Exp $
+ * $Id: vector.cpp,v 1.36 2007/11/02 19:09:26 ela Exp $
  *
  */
 
@@ -74,7 +74,7 @@ vector::vector (int s, complex val) : object () {
 }
 
 // Constructor creates an named instance of the vector class.
-vector::vector (char * n) : object (n) {
+vector::vector (const char * n) : object (n) {
   capacity = size = 0;
   data = NULL;
   dependencies = NULL;
@@ -84,7 +84,7 @@ vector::vector (char * n) : object (n) {
 
 /* This constructor creates a named instance of the vector class with
    a given initial size. */
-vector::vector (char * n, int s) : object (n) {
+vector::vector (const char * n, int s) : object (n) {
   assert (s >= 0);
   capacity = size = s;
   data = s > 0 ? (complex *) calloc (capacity, sizeof (complex)) : NULL;
@@ -226,16 +226,16 @@ nr_double_t vector::minimum (void) {
 
 /* Unwraps a phase vector in radians.  Adds +/- 2*Pi if consecutive
    values jump about |Pi|. */
-vector unwrap (vector v, nr_double_t tol) {
+vector unwrap (vector v, nr_double_t tol, nr_double_t step) {
   vector result (v.getSize ());
   nr_double_t add = 0;
   result (0) = v (0);
   for (int i = 1; i < v.getSize (); i++) {
     nr_double_t diff = real (v (i) - v (i-1));
     if (diff > +tol) {
-      add -= 2 * M_PI;
+      add -= step;
     } else if (diff < -tol) {
-      add += 2 * M_PI;
+      add += step;
     }
     result (i) = v (i) + add;
   }
