@@ -340,7 +340,7 @@ void Component::paintScheme(QPainter *p)
 
   // paint all ports
   for(Port *p2 = Ports.first(); p2 != 0; p2 = Ports.next())
-    p->drawEllipse(cx+p2->x-4, cy+p2->y-4, 8, 8);
+    if(p2->avail) p->drawEllipse(cx+p2->x-4, cy+p2->y-4, 8, 8);
 
   for(Arc *p3 = Arcs.first(); p3 != 0; p3 = Arcs.next())   // paint all arcs
     p->drawArc(cx+p3->x, cy+p3->y, p3->w, p3->h, p3->angle, p3->arclen);
@@ -811,7 +811,7 @@ bool Component::load(const QString& _s)
     if(Model != "EDD")
     if(p1->Description.isEmpty()) {  // unknown number of properties ?
       p1->Name = n.section('=',0,0);
-      n = n.section('=',1,1);
+      n = n.section('=',1);
       // allocate memory for a new property (e.g. for equations)
       if(Props.count() < (counts>>1)) {
         Props.insert(z >> 1, new Property("y", "1", true));
@@ -849,10 +849,11 @@ int Component::analyseLine(const QString& Row, int numProps)
     if(!getIntegers(Row, &i1, &i2, &i3))
       return -1;
     for(i6 = Ports.count(); i6<i3; i6++)  // if ports not in numerical order
-      Ports.append(new Port(0, 0));
+      Ports.append(new Port(0, 0, false));
 
     Ports.at(i3-1)->x  = i1;
     Ports.current()->y = i2;
+    Ports.current()->avail = true;
 
     if(i1 < x1)  x1 = i1;  // keep track of component boundings
     if(i1 > x2)  x2 = i1;
@@ -1473,6 +1474,7 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "Vnoise") c = new Noise_iv();
         else if(cstr == "nv") c = new Logical_Inv();
         else if(cstr == "exp") c = new iExp();
+        else if(cstr == "file") c = new iFile();
         break;
   case 'J' : if(cstr == "FET") c = new JFET();
 	else if(cstr == "KFF") c = new JK_FlipFlop();
@@ -1489,6 +1491,7 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "HDL") c = new VHDL_File();
         else if(cstr == "erilog") c = new Verilog_File();
         else if(cstr == "exp") c = new vExp();
+        else if(cstr == "file") c = new vFile();
         break;
   case 'T' : if(cstr == "r") c = new Transformer();
         else if(cstr == "LIN") c = new TLine();
@@ -1565,9 +1568,12 @@ Component* getComponentFromName(QString& Line)
         else if(cstr == "NOR") c = new Logical_XNOR();
         break;
   case 'h' : if(cstr == "icumL2p1") c = new hicumL2p1();
+        else if(cstr == "ic2_full") c = new hic2_full();
         break;
   case 'H' : if(cstr == "BT_X") c = new HBT_X();
         break;
+  case 'm' : if(cstr == "od_amp") c = new mod_amp();
+        break;
   }
   if(!c) {
     QMessageBox::critical(0, QObject::tr("Error"),
