@@ -49,6 +49,8 @@
 #include "source_ac.h"
 #include "vexp.h"
 #include "iexp.h"
+#include "vfile.h"
+#include "ifile.h"
 #include "vccs.h"
 #include "cccs.h"
 #include "vcvs.h"
@@ -125,5 +127,7 @@
 
 #include "hicumL2p1.h"
 #include "HBT_X.h"
+#include "mod_amp.h"
+#include "hic2_full.h"
 
 #endif
