@@ -79,7 +79,7 @@ Component* SP_Sim::newOne()
 Element* SP_Sim::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("S-parameter simulation");
-  BitmapFile = "sparameter";
+  BitmapFile = (char *) "sparameter";
 
   if(getNewOne)  return new SP_Sim();
   return 0;
