@@ -616,8 +616,9 @@ void DiagramDialog::slotReadVars(int)
   }
 
   QString Line, tmp, Var;
-  QTextStream ReadWhole(&file);
-  QString FileString = ReadWhole.read();   // read whole data file
+  // reading the file as a whole improves speed very much, also using
+  // a QByteArray rather than a QString
+  QByteArray FileString = file.readAll();
   file.close();
 
   ChooseVars->clear();
@@ -626,7 +627,8 @@ void DiagramDialog::slotReadVars(int)
   if(i > 0)
   do {
     j = FileString.find('>', i);
-    Line = FileString.mid(i, j-i);
+    for(int k=0;k<j-i;k++) Line[k]=FileString[k+i];
+    Line.truncate(j-i);
     i = FileString.find('<', j)+1;
 
     Var = Line.section(' ', 1, 1).remove('>');
@@ -671,7 +673,10 @@ void DiagramDialog::slotTakeVar(QListViewItem *Item)
         g->Color = ColorButt->paletteBackgroundColor();
         g->Thick = Property2->text().toInt();
         ColorButt->setPaletteBackgroundColor(
-		QColor(DefaultColors[GraphList->count()]));
+                   QColor(DefaultColors[GraphList->count()]));
+        if(g->Var.right(3) == ".Vb")   // harmonic balance output ?
+          if(PropertyBox->count() >= GRAPHSTYLE_ARROW)
+            PropertyBox->setCurrentItem(GRAPHSTYLE_ARROW);
         g->Style   = PropertyBox->currentItem();
         if(yAxisBox) {
           g->yAxisNo = yAxisBox->currentItem();
@@ -900,15 +905,18 @@ void DiagramDialog::slotApply()
       Diag->xAxis.autoScale = !(manualX->isChecked());
       changed = true;
     }
-    if(Diag->xAxis.limit_min != startX->text().toDouble()) {
+
+    // Use string compares for all floating point numbers, in
+    // order to avoid rounding problems.
+    if(QString::number(Diag->xAxis.limit_min) != startX->text()) {
       Diag->xAxis.limit_min = startX->text().toDouble();
       changed = true;
     }
-    if(Diag->xAxis.step != stepX->text().toDouble()) {
+    if(QString::number(Diag->xAxis.step) != stepX->text()) {
       Diag->xAxis.step = stepX->text().toDouble();
       changed = true;
     }
-    if(Diag->xAxis.limit_max != stopX->text().toDouble()) {
+    if(QString::number(Diag->xAxis.limit_max) != stopX->text()) {
       Diag->xAxis.limit_max = stopX->text().toDouble();
       changed = true;
     }
@@ -916,15 +924,15 @@ void DiagramDialog::slotApply()
       Diag->yAxis.autoScale = !(manualY->isChecked());
       changed = true;
     }
-    if(Diag->yAxis.limit_min != startY->text().toDouble()) {
+    if(QString::number(Diag->yAxis.limit_min) != startY->text()) {
       Diag->yAxis.limit_min = startY->text().toDouble();
       changed = true;
     }
-    if(Diag->yAxis.step != stepY->text().toDouble()) {
+    if(QString::number(Diag->yAxis.step) != stepY->text()) {
       Diag->yAxis.step = stepY->text().toDouble();
       changed = true;
     }
-    if(Diag->yAxis.limit_max != stopY->text().toDouble()) {
+    if(QString::number(Diag->yAxis.limit_max) != stopY->text()) {
       Diag->yAxis.limit_max = stopY->text().toDouble();
       changed = true;
     }
@@ -932,15 +940,15 @@ void DiagramDialog::slotApply()
       Diag->zAxis.autoScale = !(manualZ->isChecked());
       changed = true;
     }
-    if(Diag->zAxis.limit_min != startZ->text().toDouble()) {
+    if(QString::number(Diag->zAxis.limit_min) != startZ->text()) {
       Diag->zAxis.limit_min = startZ->text().toDouble();
       changed = true;
     }
-    if(Diag->zAxis.step != stepZ->text().toDouble()) {
+    if(QString::number(Diag->zAxis.step) != stepZ->text()) {
       Diag->zAxis.step = stepZ->text().toDouble();
       changed = true;
     }
-    if(Diag->zAxis.limit_max != stopZ->text().toDouble()) {
+    if(QString::number(Diag->zAxis.limit_max) != stopZ->text()) {
       Diag->zAxis.limit_max = stopZ->text().toDouble();
       changed = true;
     }
