@@ -27,6 +27,7 @@
 class QListView;
 class QListViewItem;
 class QLineEdit;
+class QCheckBox;
 class QVBoxLayout;
 class QPushButton;
 class QComboBox;
@@ -49,15 +50,25 @@ private slots:
   void slotAdd();
   void slotRemove();
   void slotEditSuffix(QListViewItem*);
+  void slotColorComment();
+  void slotColorString();
+  void slotColorInteger();
+  void slotColorReal();
+  void slotColorCharacter();
+  void slotColorDataType();
+  void slotColorAttributes();
 
 public:
   QucsApp *App;
 
   QFont Font;
+  QCheckBox *checkWiring;
   QComboBox *LanguageCombo;
   QPushButton *FontButton, *BGColorButton;
   QLineEdit *undoNumEdit, *editorEdit, *Input_Suffix, *Input_Program;
   QListView *List_Suffix;
+  QPushButton *ColorComment, *ColorString, *ColorInteger,
+       *ColorReal, *ColorCharacter, *ColorDataType, *ColorAttributes;
 
   QVBoxLayout *all;
   QIntValidator *val200;
