@@ -20,6 +20,8 @@
 Element::Element()
 {
   Type = isDummy;
+  isSelected = false;
+  cx = cy = x1 = y1 = x2 = y2 = 0;
 }
 
 Element::~Element()
