@@ -43,12 +43,19 @@ struct tQucsSettings {
   QColor BGColor;      // background color of view area
   QString Language;
 
+  // VHDL syntax highlighting
+  QColor VHDL_Comment, VHDL_String, VHDL_Integer, VHDL_Real,
+         VHDL_Character, VHDL_Types, VHDL_Attributes;
+
   unsigned int maxUndo;    // size of undo stack
   QString Editor;
   QString BinDir;
   QString BitmapDir;
   QString LangDir;
   QString LibDir;
+  QString AscoDir;
+
+  unsigned int NodeWiring;
 
   // registered filename extensions with program to open the file
   QStringList FileTypes;
@@ -57,7 +64,8 @@ struct tQucsSettings {
 extern tQucsSettings QucsSettings;  // extern because nearly everywhere used
 extern QFont savingFont;       // to remember which font to save in "qucsrc"
 
-extern QucsApp *QucsMain;    // the Qucs application itself
+extern QucsApp *QucsMain;  // the Qucs application itself
+extern QString lastDir;    // to remember last directory for several dialogs
 
 bool saveApplSettings(QucsApp*);
 
@@ -69,7 +77,12 @@ void    str2num    (const QString&, double&, QString&, double&);
 QString num2str    (double);
 QString StringNiceNum(double);
 void    convert2Unicode(QString&);
-QString properName (const QString&);
+void    convert2ASCII(QString&);
+QString properName(const QString&);
+QString properAbsFileName(const QString&);
+QString properFileName(const QString&);
 bool    VHDL_Time(QString&, const QString&);
+bool    Verilog_Time(QString&, const QString&);
+bool    checkVersion(QString&);
 
 #endif
