@@ -22,6 +22,8 @@
 #include "mouseactions.h"
 #include "components/component.h"
 #include "components/spicedialog.h"
+#include "components/spicefile.h"
+#include "components/optimizedialog.h"
 #include "components/componentdialog.h"
 #include "diagrams/diagramdialog.h"
 #include "diagrams/markerdialog.h"
@@ -42,6 +44,17 @@
 #include <stdlib.h>
 
 
+#define  DOC_X_POS(x)  (int(float(x)/Doc->Scale) + Doc->ViewX1)
+#define  DOC_Y_POS(y)  (int(float(y)/Doc->Scale) + Doc->ViewY1)
+#define  DOC_X_FPOS    (float(Event->pos().x())/Doc->Scale + float(Doc->ViewX1))
+#define  DOC_Y_FPOS    (float(Event->pos().y())/Doc->Scale + float(Doc->ViewY1))
+
+#define  SCR_X_POS(x)  int(float(x - Doc->ViewX1) * Doc->Scale)
+#define  SCR_Y_POS(y)  int(float(y - Doc->ViewY1) * Doc->Scale)
+
+QAction *formerAction;   // remember action before drag n'drop etc.
+
+
 MouseActions::MouseActions()
 {
   selElem  = 0;  // no component/diagram is selected
@@ -225,7 +238,7 @@ void MouseActions::moveElements(QPtrList<Element> *movElements, int x, int y)
   Element *pe;
   for(pe = movElements->first(); pe != 0; pe = movElements->next()) {
     if(pe->Type == isWire) {
-      pw = (Wire*)pe;   // connecting wires are not moved completely
+      pw = (Wire*)pe;   // connected wires are not moved completely
 
       if(((unsigned long)pw->Port1) > 3) {
 	pw->x1 += x;  pw->y1 += y;
@@ -262,8 +275,8 @@ void MouseActions::MMoveElement(Schematic *Doc, QMouseEvent *Event)
 
   int x  = Event->pos().x();
   int y  = Event->pos().y();
-  int fx = int(float(x)/Doc->Scale) + Doc->ViewX1;
-  int fy = int(float(y)/Doc->Scale) + Doc->ViewY1;
+  int fx = DOC_X_POS(x);
+  int fy = DOC_Y_POS(y);
   int gx = fx;
   int gy = fy;
   Doc->setOnGrid(gx, gy);
@@ -309,8 +322,8 @@ void MouseActions::MMoveWire2(Schematic *Doc, QMouseEvent *Event)
     }
   else drawn = true;
 
-  MAx2  = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  MAy2  = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
+  MAx2  = DOC_X_POS(Event->pos().x());
+  MAy2  = DOC_Y_POS(Event->pos().y());
   Doc->setOnGrid(MAx2, MAy2);
 
   if(MAx1 == 0) {
@@ -329,25 +342,26 @@ void MouseActions::MMoveWire2(Schematic *Doc, QMouseEvent *Event)
 void MouseActions::MMoveWire1(Schematic *Doc, QMouseEvent *Event)
 {
   QPainter painter(Doc->viewport());
-  setPainter(Doc, &painter);
+  painter.setPen(Qt::DotLine);
+  painter.setRasterOp(Qt::NotROP);  // background should not be erased
 
   if(drawn) {
-    painter.drawLine(MAx1, MAy3, MAx2, MAy3); // erase old
-    painter.drawLine(MAx3, MAy1, MAx3, MAy2);
+    painter.drawLine(0, MAy3, MAx2, MAy3); // erase old
+    painter.drawLine(MAx3, 0, MAx3, MAy2);
   }
-  drawn = true;
 
-  MAx3  = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  MAy3  = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
+  MAx3 = DOC_X_POS(Event->pos().x());
+  MAy3 = DOC_Y_POS(Event->pos().y());
   Doc->setOnGrid(MAx3, MAy3);
+  MAx3 = SCR_X_POS(MAx3) - Doc->contentsX();
+  MAy3 = SCR_Y_POS(MAy3) - Doc->contentsY();
 
-  MAx1  = Doc->contentsX()+Doc->ViewX1;
-  MAy1  = Doc->contentsY()+Doc->ViewY1;
-  MAx2  = MAx1 + Doc->visibleWidth();
-  MAy2  = MAy1 + Doc->visibleHeight();
+  MAx2  = Doc->visibleWidth();
+  MAy2  = Doc->visibleHeight();
 
-  painter.drawLine(MAx1, MAy3, MAx2, MAy3); // paint
-  painter.drawLine(MAx3, MAy1, MAx3, MAy2);
+  drawn = true;
+  painter.drawLine(0, MAy3, MAx2, MAy3); // paint
+  painter.drawLine(MAx3, 0, MAx3, MAy2);
 }
 
 // -----------------------------------------------------------
@@ -359,8 +373,8 @@ void MouseActions::MMoveSelect(Schematic *Doc, QMouseEvent *Event)
 
   if(drawn) painter.drawRect(MAx1, MAy1, MAx2, MAy2); // erase old rectangle
   drawn = true;
-  MAx2 = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1 - MAx1;
-  MAy2 = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1 - MAy1;
+  MAx2 = DOC_X_POS(Event->pos().x()) - MAx1;
+  MAy2 = DOC_Y_POS(Event->pos().y()) - MAy1;
   if(isMoveEqual)     // x and y size must be equal ?
     if(abs(MAx2) > abs(MAy2)) {
       if(MAx2<0) MAx2 = -abs(MAy2); else MAx2 = abs(MAy2);
@@ -375,8 +389,8 @@ void MouseActions::MMoveResizePainting(Schematic *Doc, QMouseEvent *Event)
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
-  MAx1 = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  MAy1 = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
+  MAx1 = DOC_X_POS(Event->pos().x());
+  MAy1 = DOC_Y_POS(Event->pos().y());
   Doc->setOnGrid(MAx1, MAy1);
   ((Painting*)focusElement)->MouseResizeMoving(MAx1, MAy1, &painter);
 }
@@ -388,8 +402,8 @@ void MouseActions::MMoveMoving(Schematic *Doc, QMouseEvent *Event)
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
-  MAx2 = int(Event->pos().x()/Doc->Scale) + Doc->ViewX1;
-  MAy2 = int(Event->pos().y()/Doc->Scale) + Doc->ViewY1;
+  MAx2 = DOC_X_POS(Event->pos().x());
+  MAy2 = DOC_Y_POS(Event->pos().y());
 
   Doc->setOnGrid(MAx2, MAy2);
   MAx3 = MAx1 = MAx2 - MAx1;
@@ -441,8 +455,8 @@ void MouseActions::MMoveMoving2(Schematic *Doc, QMouseEvent *Event)
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
-  MAx2 = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  MAy2 = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
+  MAx2 = DOC_X_POS(Event->pos().x());
+  MAy2 = DOC_Y_POS(Event->pos().y());
 
   Element *pe;
   if(drawn) // erase old scheme
@@ -479,25 +493,37 @@ void MouseActions::MMovePaste(Schematic *Doc, QMouseEvent *Event)
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
-  MAx1 = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  MAy1 = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
-  Doc->setOnGrid(MAx1, MAy1);
-
-  for(Element *pe=movingElements.first(); pe!=0; pe=movingElements.next()) {
-    if(pe->Type & isLabel) {
-      pe->cx += MAx1;  pe->x1 += MAx1;
-      pe->cy += MAy1;  pe->y1 += MAy1;
-    }
-    else
-      pe->setCenter(MAx1, MAy1, true);
-    pe->paintScheme(&painter);
-  }
+  MAx1 = DOC_X_POS(Event->pos().x());
+  MAy1 = DOC_Y_POS(Event->pos().y());
+  moveElements(Doc,MAx1,MAy1);
+  paintElementsScheme(&painter);      
 
   drawn = true;
   QucsMain->MouseMoveAction = &MouseActions::MMoveMoving2;
   QucsMain->MouseReleaseAction = &MouseActions::MReleasePaste;
 }
 
+// -----------------------------------------------------------
+// Moves scroll bar of diagram (e.g. tabular) according the mouse cursor.
+void MouseActions::MMoveScrollBar(Schematic *Doc, QMouseEvent *Event)
+{
+  TabDiagram *d = (TabDiagram*)focusElement;
+  int x = DOC_X_POS(Event->pos().x());
+  int y = DOC_Y_POS(Event->pos().y());
+
+  if(d->scrollTo(MAx2, x - MAx1, y - MAy1)) {
+    Doc->setChanged(true, true, 'm'); // 'm' = only the first time
+
+    QPainter p(Doc->viewport());
+    ViewPainter Painter;
+    Painter.init(&p, Doc->Scale, -Doc->ViewX1, -Doc->ViewY1,
+                 Doc->contentsX(), Doc->contentsY());
+    Painter.fillRect(d->cx-d->x1, d->cy-d->y2, d->x2+d->x1, d->y2+d->y1,
+                     QucsSettings.BGColor);
+    d->paint(&Painter);
+  }
+}
+
 // -----------------------------------------------------------
 // Paints a cross under the mouse cursor to show the delete modus.
 void MouseActions::MMoveDelete(Schematic *Doc, QMouseEvent *Event)
@@ -738,8 +764,8 @@ void MouseActions::MMoveMoveText(Schematic *Doc, QMouseEvent *Event)
     painter.drawRect(MAx1, MAy1, MAx2, MAy2); // erase old
   drawn = true;
 
-  int newX = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-  int newY = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
+  int newX = DOC_X_POS(Event->pos().x());
+  int newY = DOC_Y_POS(Event->pos().y());
   MAx1 += newX - MAx3;
   MAy1 += newY - MAy3;
   MAx3  = newX;
@@ -778,11 +804,11 @@ void MouseActions::MMoveZoomIn(Schematic *Doc, QMouseEvent *Event)
 // ************************************************************************
 
 // Is called from several MousePress functions to show right button menu.
-void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, int x, int y)
+void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, float fX, float fY)
 {
-  MAx1 = x;
-  MAy1 = y;
-  focusElement = Doc->selectElement(x, y, false);
+  MAx1 = int(fX);
+  MAy1 = int(fY);
+  focusElement = Doc->selectElement(fX, fY, false);
 
   if(focusElement)  // remove special function (4 least significant bits)
     focusElement->Type &= isSpecialMask;
@@ -828,10 +854,13 @@ void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, int x, int
       ComponentMenu->insertItem(QObject::tr("2-port matching"), QucsMain,
                                 SLOT(slot2PortMatching()));
   }
-  while(true) {
+  do {
     if(focusElement) {
       if(focusElement->Type == isDiagram) break;
-      if(focusElement->Type == isGraph) break;
+      if(focusElement->Type == isGraph) {
+        QucsMain->graph2csv->addTo(ComponentMenu);
+        break;
+      }
     }
     ComponentMenu->insertSeparator();
     if(focusElement) if(focusElement->Type & isComponent)
@@ -843,9 +872,7 @@ void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, int x, int
       QucsMain->editMirror->addTo(ComponentMenu);
     if(!QucsMain->editMirrorY->isOn())
       QucsMain->editMirrorY->addTo(ComponentMenu);
-    break;
-  }
-
+  } while(false);
 
   *focusMEvent = *Event;  // remember event for "edit component" action
   ComponentMenu->popup(Event->globalPos());
@@ -854,8 +881,9 @@ void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, int x, int
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressLabel(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressLabel(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
+  int x = int(fX), y = int(fY);
   Wire *pw = 0;
   WireLabel *pl=0;
   Node *pn = Doc->selectedNode(x, y);
@@ -872,7 +900,7 @@ void MouseActions::MPressLabel(Schematic *Doc, QMouseEvent*, int x, int y)
   if(pe) {
     if(pe->Type & isComponent) {
       QMessageBox::information(0, QObject::tr("Info"),
-		QObject::tr("The ground potential cannot be labeled!"));
+                 QObject::tr("The ground potential cannot be labeled!"));
       return;
     }
     pl = ((Conductor*)pe)->Label;
@@ -922,16 +950,16 @@ void MouseActions::MPressLabel(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, int x, int y)
+void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, float fX, float fY)
 {
   bool Ctrl;
   if(Event->state() & Qt::ControlButton) Ctrl = true;
   else Ctrl = false;
 
   int No=0;
-  MAx1 = x;
-  MAy1 = y;
-  focusElement = Doc->selectElement(x, y, Ctrl, &No);
+  MAx1 = int(fX);
+  MAy1 = int(fY);
+  focusElement = Doc->selectElement(fX, fY, Ctrl, &No);
   isMoveEqual = false;   // moving not neccessarily square
 
 
@@ -973,16 +1001,27 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, int x, int y
       Doc->grabKeyboard(); // no keyboard inputs during move actions
       return;
 
-    case isDiagramScroll:  // scroll in tabular ?
+    case isDiagramHScroll:  // scroll in tabular ?
+      MAy1 = MAx1;
+
+    case isDiagramVScroll:
       focusElement->Type = isDiagram;
 
-      if(((Diagram*)focusElement)->Name == "Time") {
-        if(((TimingDiagram*)focusElement)->scroll(MAx1))
-          Doc->setChanged(true, true, 'm'); // 'm' = only the first time
-      }
-      else {
-        if(((TabDiagram*)focusElement)->scroll(MAy1))
+      No = ((TabDiagram*)focusElement)->scroll(MAy1);
+
+      switch(No) {
+        case 1:
           Doc->setChanged(true, true, 'm'); // 'm' = only the first time
+          break;
+        case 2:  // move scroll bar with mouse cursor
+          QucsMain->MouseMoveAction = &MouseActions::MMoveScrollBar;
+          QucsMain->MousePressAction = 0;
+          QucsMain->MouseDoubleClickAction = 0;
+          Doc->grabKeyboard();  // no keyboard inputs during move actions
+
+          // Remember inital scroll bar position.
+          MAx2 = int(((TabDiagram*)focusElement)->xAxis.limit_min);
+          return;
       }
       Doc->viewport()->update();
       drawn = false;
@@ -994,6 +1033,29 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, int x, int y
       MAx3 = No;
       QucsMain->slotApplyCompText();
       return;
+
+    case isNode:
+      if (QucsSettings.NodeWiring) {
+      MAx1 = 0;   // paint wire corner first up, then left/right
+      MAx3 = focusElement->cx;  // works even if node is not on grid
+      MAy3 = focusElement->cy;
+      QucsMain->MouseMoveAction = &MouseActions::MMoveWire2;
+      QucsMain->MousePressAction = &MouseActions::MPressWire2;
+      QucsMain->MouseReleaseAction = 0; // if function is called from elsewhere
+      QucsMain->MouseDoubleClickAction = 0;
+
+      formerAction = QucsMain->select; // to restore action afterwards
+      QucsMain->activeAction = QucsMain->insWire;
+
+      QucsMain->select->blockSignals(true);
+      QucsMain->select->setOn(false);
+      QucsMain->select->blockSignals(false);
+
+      QucsMain->insWire->blockSignals(true);
+      QucsMain->insWire->setOn(true);
+      QucsMain->insWire->blockSignals(false);
+      return;
+      }
   }
 
 
@@ -1022,9 +1084,9 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, int x, int y
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressDelete(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressDelete(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  Element *pe = Doc->selectElement(x, y, false);
+  Element *pe = Doc->selectElement(fX, fY, false);
   if(pe) {
     pe->isSelected = true;
     Doc->deleteElements();
@@ -1036,11 +1098,11 @@ void MouseActions::MPressDelete(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressActivate(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressActivate(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  MAx1 = x;
-  MAy1 = y;
-  if(!Doc->activateSpecifiedComponent(x, y)) {
+  MAx1 = int(fX);
+  MAy1 = int(fY);
+  if(!Doc->activateSpecifiedComponent(MAx1, MAy1)) {
 //    if(Event->button() != Qt::LeftButton) return;
     MAx2 = 0;  // if not clicking on a component => open a rectangle
     MAy2 = 0;
@@ -1053,17 +1115,17 @@ void MouseActions::MPressActivate(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressMirrorX(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressMirrorX(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
   // no use in mirroring wires or diagrams
-  Component *c = Doc->selectedComponent(x, y);
+  Component *c = Doc->selectedComponent(int(fX), int(fY));
   if(c) {
     if(c->Ports.count() < 1) return;  // only mirror components with ports
     c->mirrorX();
     Doc->setCompPorts(c);
   }
   else {
-    Painting *p = Doc->selectedPainting(x, y);
+    Painting *p = Doc->selectedPainting(fX, fY);
     if(p == 0) return;
     p->mirrorX();
   }
@@ -1074,17 +1136,17 @@ void MouseActions::MPressMirrorX(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressMirrorY(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressMirrorY(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
   // no use in mirroring wires or diagrams
-  Component *c = Doc->selectedComponent(x, y);
+  Component *c = Doc->selectedComponent(int(fX), int(fY));
   if(c) {
     if(c->Ports.count() < 1) return;  // only mirror components with ports
     c->mirrorY();
     Doc->setCompPorts(c);
   }
   else {
-    Painting *p = Doc->selectedPainting(x, y);
+    Painting *p = Doc->selectedPainting(fX, fY);
     if(p == 0) return;
     p->mirrorY();
   }
@@ -1095,9 +1157,9 @@ void MouseActions::MPressMirrorY(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  Element *e = Doc->selectElement(x, y, false);
+  Element *e = Doc->selectElement(int(fX), int(fY), false);
   if(e == 0) return;
   e->Type &= isSpecialMask;  // remove special functions
 
@@ -1150,14 +1212,14 @@ void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, int, int)
+void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, float)
 {
   if(selElem == 0) return;
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
   
-  int x1, y1, x2, y2;
+  int x1, y1, x2, y2, rot;
   if(selElem->Type & isComponent) {
     Component *Comp = (Component*)selElem;
     switch(Event->button()) {
@@ -1175,7 +1237,11 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, int, int)
 	drawn = false;
 	Doc->viewport()->update();
 	Doc->setChanged(true, true);
+	rot = Comp->rotated;
 	Comp = Comp->newOne(); // component is used, so create a new one
+	rot -= Comp->rotated;
+	rot &= 3;
+	while(rot--) Comp->rotate(); // keep last rotation for single component
 	break;
 
       case Qt::RightButton :  // right mouse button rotates the component
@@ -1226,30 +1292,34 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, int, int)
     Doc->enlargeView(x1, y1, x2, y2);
     selElem = ((Painting*)selElem)->newOne();
 
-    drawn = false;
     Doc->viewport()->update();
     Doc->setChanged(true, true);
+
+    MMoveElement(Doc, Event);  // needed before next mouse pressing
+    drawn = false;
   }
 }
 
 // -----------------------------------------------------------
 // Is called if starting point of wire is pressed
-void MouseActions::MPressWire1(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressWire1(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
   QPainter painter(Doc->viewport());
-  setPainter(Doc, &painter);
+  painter.setPen(Qt::DotLine);
+  painter.setRasterOp(Qt::NotROP);  // background should not be erased
 
   if(drawn) {
-    painter.drawLine(MAx1, MAy3, MAx2, MAy3); // erase old mouse cross
-    painter.drawLine(MAx3, MAy1, MAx3, MAy2);
+    painter.drawLine(0, MAy3, MAx2, MAy3); // erase old mouse cross
+    painter.drawLine(MAx3, 0, MAx3, MAy2);
   }
   drawn = false;
 
   MAx1 = 0;   // paint wire corner first up, then left/right
-  MAx3 = x;
-  MAy3 = y;
+  MAx3 = int(fX);
+  MAy3 = int(fY);
   Doc->setOnGrid(MAx3, MAy3);
 
+  formerAction = 0; // keep wire action active after first wire finished
   QucsMain->MouseMoveAction = &MouseActions::MMoveWire2;
   QucsMain->MousePressAction = &MouseActions::MPressWire2;
   // Double-click action is set in "MMoveWire2" to not initiate it
@@ -1258,59 +1328,48 @@ void MouseActions::MPressWire1(Schematic *Doc, QMouseEvent*, int x, int y)
 
 // -----------------------------------------------------------
 // Is called if ending point of wire is pressed
-void MouseActions::MPressWire2(Schematic *Doc, QMouseEvent *Event, int x, int y)
+void MouseActions::MPressWire2(Schematic *Doc, QMouseEvent *Event, float fX, float fY)
 {
   QPainter painter(Doc->viewport());
   setPainter(Doc, &painter);
 
-  int set = 0;
+  int set1 = 0, set2 = 0;
   switch(Event->button()) {
   case Qt::LeftButton :
     if(MAx1 == 0) { // which wire direction first ?
+      if(MAy2 != MAy3)
+        set1 = Doc->insertWire(new Wire(MAx3, MAy3, MAx3, MAy2));
       if(MAx2 != MAx3) {
-	set = Doc->insertWire(new Wire(MAx3, MAy2, MAx2, MAy2));
-	if(set & 2) {
-	  // if last port is connected, then start a new wire
-	  QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
-	  QucsMain->MousePressAction = &MouseActions::MPressWire1;
-	  QucsMain->MouseDoubleClickAction = 0;
-	}
-	if(MAy2 != MAy3)
-	  set |= Doc->insertWire(new Wire(MAx3, MAy3, MAx3, MAy2));
+        set2 = set1;
+        set1 = Doc->insertWire(new Wire(MAx3, MAy2, MAx2, MAy2));
       }
-      else if(MAy2 != MAy3) {
-	set = Doc->insertWire(new Wire(MAx3, MAy3, MAx3, MAy2));
-	if(set & 2) {
-	  // if last port is connected, then start a new wire
-	  QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
-	  QucsMain->MousePressAction = &MouseActions::MPressWire1;
-	  QucsMain->MouseDoubleClickAction = 0;
-	} }
     }
     else {
+      if(MAx2 != MAx3)
+        set1 = Doc->insertWire(new Wire(MAx3, MAy3, MAx2, MAy3));
       if(MAy2 != MAy3) {
-	set = Doc->insertWire(new Wire(MAx2, MAy3, MAx2, MAy2));
-	if(set & 2) {
-	  // if last port is connected, then start a new wire
-	  QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
-	  QucsMain->MousePressAction = &MouseActions::MPressWire1;
-	  QucsMain->MouseDoubleClickAction = 0;
-	}
-	if(MAx2 != MAx3)
-	  set |= Doc->insertWire(new Wire(MAx3, MAy3, MAx2, MAy3));
+        set2 = set1;
+        set1 = Doc->insertWire(new Wire(MAx2, MAy3, MAx2, MAy2));
       }
-      else if(MAx2 != MAx3) {
-	set = Doc->insertWire(new Wire(MAx3, MAy3, MAx2, MAy3));
-	if(set & 2) {
-	  // if last port is connected, then start a new wire
-	  QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
-	  QucsMain->MousePressAction = &MouseActions::MPressWire1;
-	  QucsMain->MouseDoubleClickAction = 0;
-	} }
     }
+
+    if(set1 & 2) {
+      // if last port is connected, then...
+      if(formerAction) {
+        // ...restore old action
+        QucsMain->select->setOn(true);
+      }
+      else {
+        // ...start a new wire
+        QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
+        QucsMain->MousePressAction = &MouseActions::MPressWire1;
+        QucsMain->MouseDoubleClickAction = 0;
+      }
+    }
+
     Doc->viewport()->update();
     drawn = false;
-    if(set) Doc->setChanged(true, true);
+    if(set1 | set2) Doc->setChanged(true, true);
     MAx3 = MAx2;
     MAy3 = MAy2;
     break;
@@ -1325,8 +1384,8 @@ void MouseActions::MPressWire2(Schematic *Doc, QMouseEvent *Event, int x, int y)
       painter.drawLine(MAx2, MAy3, MAx2, MAy2); // erase old
     }
 
-    MAx2  = x;
-    MAy2  = y;
+    MAx2  = int(fX);
+    MAy2  = int(fY);
     Doc->setOnGrid(MAx2, MAy2);
 
     MAx1 ^= 1;    // change the painting direction of wire corner
@@ -1346,10 +1405,10 @@ void MouseActions::MPressWire2(Schematic *Doc, QMouseEvent *Event, int x, int y)
 
 // -----------------------------------------------------------
 // Is called for setting a marker on a diagram's graph
-void MouseActions::MPressMarker(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressMarker(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  MAx1 = x;
-  MAy1 = y;
+  MAx1 = int(fX);
+  MAy1 = int(fY);
   Marker *pm = Doc->setMarker(MAx1, MAy1);
 
   if(pm) {
@@ -1362,9 +1421,9 @@ void MouseActions::MPressMarker(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressOnGrid(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressOnGrid(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  Element *pe = Doc->selectElement(x, y, false);
+  Element *pe = Doc->selectElement(fX, fY, false);
   if(pe) {
     pe->Type &= isSpecialMask;  // remove special functions (4 lowest bits)
 
@@ -1379,10 +1438,10 @@ void MouseActions::MPressOnGrid(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressMoveText(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressMoveText(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  MAx1 = x;
-  MAy1 = y;
+  MAx1 = int(fX);
+  MAy1 = int(fY);
   focusElement = Doc->selectCompText(MAx1, MAy1, MAx2, MAy2);
 
   if(focusElement) {
@@ -1399,10 +1458,10 @@ void MouseActions::MPressMoveText(Schematic *Doc, QMouseEvent*, int x, int y)
 }
 
 // -----------------------------------------------------------
-void MouseActions::MPressZoomIn(Schematic *Doc, QMouseEvent*, int x, int y)
+void MouseActions::MPressZoomIn(Schematic *Doc, QMouseEvent*, float fX, float fY)
 {
-  MAx1 = x;
-  MAy1 = y;
+  MAx1 = int(fX);
+  MAy1 = int(fY);
   MAx2 = 0;  // rectangle size
   MAy2 = 0;
 
@@ -1482,9 +1541,10 @@ void MouseActions::MReleaseActivate(Schematic *Doc, QMouseEvent *Event)
 
 // -----------------------------------------------------------
 // Is called after moving selected elements.
-void MouseActions::MReleaseMoving(Schematic *Doc, QMouseEvent *Event)
+void MouseActions::MReleaseMoving(Schematic *Doc, QMouseEvent*)
 {
-  if(Event->button() != Qt::LeftButton) return;
+  // Allow all mouse buttons, because for others than the left one,
+  // a menu has already created.
   endElementMoving(Doc, &movingElements);
   Doc->releaseKeyboard();  // allow keyboard inputs again
 
@@ -1563,10 +1623,71 @@ void MouseActions::MReleaseResizePainting(Schematic *Doc, QMouseEvent *Event)
   Doc->setChanged(true, true);
 }
 
+// -----------------------------------------------------------
+void MouseActions::paintElementsScheme(QPainter *p)
+{
+  Element *pe;
+  for(pe = movingElements.first(); pe != 0; pe = movingElements.next())
+    pe->paintScheme(p);
+}
+
+// -----------------------------------------------------------
+void MouseActions::moveElements(Schematic *Doc, int& x1, int& y1)
+{
+  Element *pe;
+  Doc->setOnGrid(x1, y1);
+
+  for(pe=movingElements.first(); pe!=0; pe=movingElements.next()) {
+    if(pe->Type & isLabel) {
+      pe->cx += x1;  pe->x1 += x1;
+      pe->cy += y1;  pe->y1 += y1;
+    }
+    else
+      pe->setCenter(x1, y1, true);
+  }
+}
+
+// -----------------------------------------------------------
+void MouseActions::rotateElements(Schematic *Doc, int& x1, int& y1)
+{
+  int x2, y2;
+  Element *pe;
+  Doc->setOnGrid(x1, y1);
+
+  for(pe = movingElements.first(); pe != 0; pe = movingElements.next()) {
+    switch(pe->Type) {
+    case isComponent:
+    case isAnalogComponent:
+    case isDigitalComponent:
+      ((Component*)pe)->rotate(); // rotate !before! rotating the center
+      x2 = x1 - pe->cx;
+      pe->setCenter(pe->cy - y1 + x1, x2 + y1);
+      break;
+    case isWire:
+      x2     = pe->x1;
+      pe->x1 = pe->y1 - y1 + x1;
+      pe->y1 = x1 - x2 + y1;
+      x2     = pe->x2;
+      pe->x2 = pe->y2 - y1 + x1;
+      pe->y2 = x1 - x2 + y1;
+      break;
+    case isPainting:
+      ((Painting*)pe)->rotate(); // rotate !before! rotating the center
+      ((Painting*)pe)->getCenter(x2, y2);
+      pe->setCenter(y2 - y1 + x1, x1 - x2 + y1);
+          break;
+    default:
+      x2 = x1 - pe->cx;   // if diagram -> only rotate cx/cy
+      pe->setCenter(pe->cy - y1 + x1, x2 + y1);
+      break;
+    }
+  }
+}
+
 // -----------------------------------------------------------
 void MouseActions::MReleasePaste(Schematic *Doc, QMouseEvent *Event)
 {
-  int x1, y1, x2, y2;
+  int x1, y1, x2, y2, rot;
   QFileInfo Info(Doc->DocName);
   QPainter painter(Doc->viewport());
 
@@ -1610,6 +1731,11 @@ void MouseActions::MReleasePaste(Schematic *Doc, QMouseEvent *Event)
     }
 
     pasteElements(Doc);
+    // keep rotation sticky for pasted elements
+    rot = movingRotated;
+    x1 = y1 = 0;
+    while(rot--) rotateElements(Doc,x1,y1);
+    
     QucsMain->MouseMoveAction = &MouseActions::MMovePaste;
     QucsMain->MousePressAction = 0;
     QucsMain->MouseReleaseAction = 0;
@@ -1625,43 +1751,16 @@ void MouseActions::MReleasePaste(Schematic *Doc, QMouseEvent *Event)
     setPainter(Doc, &painter);
 
     if(drawn) // erase old scheme
-      for(pe = movingElements.first(); pe != 0; pe = movingElements.next())
-        pe->paintScheme(&painter);
+      paintElementsScheme(&painter);      
     drawn = true;
 
-    x1  = int(float(Event->pos().x())/Doc->Scale) + Doc->ViewX1;
-    y1  = int(float(Event->pos().y())/Doc->Scale) + Doc->ViewY1;
-    Doc->setOnGrid(x1, y1);
-
-    for(pe = movingElements.first(); pe != 0; pe = movingElements.next()) {
-      switch(pe->Type) {
-        case isComponent:
-        case isAnalogComponent:
-        case isDigitalComponent:
-	  ((Component*)pe)->rotate(); // rotate !before! rotating the center
-          x2 = x1 - pe->cx;
-          pe->setCenter(pe->cy - y1 + x1, x2 + y1);
-          break;
-        case isWire:
-	  x2    = pe->x1;
-          pe->x1 = pe->y1 - y1 + x1;
-          pe->y1 = x1 - x2 + y1;
-          x2    = pe->x2;
-          pe->x2 = pe->y2 - y1 + x1;
-          pe->y2 = x1 - x2 + y1;
-          break;
-        case isPainting:
-	  ((Painting*)pe)->rotate(); // rotate !before! rotating the center
-          ((Painting*)pe)->getCenter(x2, y2);
-          pe->setCenter(y2 - y1 + x1, x1 - x2 + y1);
-          break;
-        default:
-	  x2 = x1 - pe->cx;   // if diagram -> only rotate cx/cy
-          pe->setCenter(pe->cy - y1 + x1, x2 + y1);
-          break;
-      }
-      pe->paintScheme(&painter);
-    }
+    x1 = DOC_X_POS(Event->pos().x());
+    y1 = DOC_Y_POS(Event->pos().y());
+    rotateElements(Doc,x1,y1);
+    paintElementsScheme(&painter);      
+    // save rotation
+    movingRotated++;
+    movingRotated &= 3;
     break;
 
   default: ;    // avoids compiler warnings
@@ -1694,9 +1793,12 @@ void MouseActions::MReleaseZoomIn(Schematic *Doc, QMouseEvent *Event)
   float DX = float(abs(MAx2));
   float DY = float(abs(MAy2));
   if((Doc->Scale * DX) < 6.0) {
-    MAx1  = (MAx1<<1) - (Doc->visibleWidth()>>1)  - Doc->contentsX();
-    MAy1  = (MAy1<<1) - (Doc->visibleHeight()>>1) - Doc->contentsY();
-    Doc->zoom(1.5);    // a simple click zooms by constant factor
+    DX = 1.5;    // a simple click zooms by constant factor
+    Doc->zoom(DX);
+
+    DX -= 1.0;
+    MAx1 = int(DX * float(Event->pos().x()));
+    MAy1 = int(DX * float(Event->pos().y()));
   }
   else {
     float xScale = float(Doc->visibleWidth())  / DX;
@@ -1736,8 +1838,7 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
   int x1, y1, x2, y2;
 
   QFileInfo Info(Doc->DocName);
-  int x = int(Event->pos().x()/Doc->Scale) + Doc->ViewX1;
-  int y = int(Event->pos().y()/Doc->Scale) + Doc->ViewY1;
+  float fX = DOC_X_FPOS, fY = DOC_Y_FPOS;
 
   switch(focusElement->Type) {
     case isComponent:
@@ -1746,19 +1847,23 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
          c = (Component*)focusElement;
          if(c->Model == "GND") return;
 
-	 if(c->Model == "SPICE") {
-	   SpiceDialog *sd = new SpiceDialog((SpiceFile*)c, Doc);
+         if(c->Model == "SPICE") {
+           SpiceDialog *sd = new SpiceDialog((SpiceFile*)c, Doc);
            if(sd->exec() != 1) break;   // dialog is WDestructiveClose
-	 }
-	 else {
-	   ComponentDialog * cd = new ComponentDialog(c, Doc);
-	   if(cd->exec() != 1) break;   // dialog is WDestructiveClose
+         }
+         else if(c->Model == ".Opt") {
+           OptimizeDialog *od = new OptimizeDialog((Optimize_Sim*)c, Doc);
+           if(od->exec() != 1) break;   // dialog is WDestructiveClose
+         }
+         else {
+           ComponentDialog * cd = new ComponentDialog(c, Doc);
+           if(cd->exec() != 1) break;   // dialog is WDestructiveClose
 
            Doc->Components->findRef(c);
            Doc->Components->take();
            Doc->setComponentNumber(c); // for ports/power sources
            Doc->Components->append(c);
-	 }
+         }
 
          Doc->setChanged(true, true);
          c->entireBounds(x1,y1,x2,y2, Doc->textCorr());
@@ -1769,14 +1874,14 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
          dia = (Diagram*)focusElement;
          if(dia->Name.at(0) == 'T')  // don't open dialog on scrollbar
            if(dia->Name == "Time") {
-             if(dia->cy < y) {
+             if(dia->cy < int(fY)) {
 	       if(((TimingDiagram*)focusElement)->scroll(MAx1))
 	         Doc->setChanged(true, true, 'm'); // 'm' = only the first time
 	       break;
              }
 	   }
            else {
-             if(dia->cx > x) {
+             if(dia->cx > int(fX)) {
 	       if(((TabDiagram*)focusElement)->scroll(MAy1))
 	         Doc->setChanged(true, true, 'm'); // 'm' = only the first time
 	       break;
@@ -1808,14 +1913,14 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
          break;
 
     case isWire:
-         MPressLabel(Doc, Event, x, y);
+         MPressLabel(Doc, Event, fX, fY);
          break;
 
     case isNodeLabel:
     case isHWireLabel:
     case isVWireLabel:
-	 editLabel(Doc, (WireLabel*)focusElement);
-	 break;
+         editLabel(Doc, (WireLabel*)focusElement);
+         break;
 
     case isPainting:
          if( ((Painting*)focusElement)->Dialog() )
@@ -1829,6 +1934,12 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
          break;
   }
 
+  // Very strange: Now an open VHDL editor gets all the keyboard input !?!
+  // I don't know why it only happens here, nor am I sure whether it only
+  // happens here. Anyway, I hope the best and give the focus back to the
+  // current document.
+  Doc->setFocus();
+
   Doc->viewport()->update();
   drawn = false;
 }
@@ -1837,18 +1948,20 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
 void MouseActions::MDoubleClickSelect(Schematic *Doc, QMouseEvent *Event)
 {
   Doc->releaseKeyboard();  // allow keyboard inputs again
+  QucsMain->editText->setHidden(true);
   editElement(Doc, Event);
 }
 
 // -----------------------------------------------------------
 void MouseActions::MDoubleClickWire2(Schematic *Doc, QMouseEvent *Event)
 {
-  int x = int(Event->pos().x()/Doc->Scale) + Doc->ViewX1;
-  int y = int(Event->pos().y()/Doc->Scale) + Doc->ViewY1;
+  MPressWire2(Doc, Event, DOC_X_FPOS, DOC_Y_FPOS);
 
-  MPressWire2(Doc, Event, x, y);
-
-  QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
-  QucsMain->MousePressAction = &MouseActions::MPressWire1;
-  QucsMain->MouseDoubleClickAction = 0;
+  if(formerAction)
+    QucsMain->select->setOn(true);  // restore old action
+  else {
+    QucsMain->MouseMoveAction = &MouseActions::MMoveWire1;
+    QucsMain->MousePressAction = &MouseActions::MPressWire1;
+    QucsMain->MouseDoubleClickAction = 0;
+  }
 }
