@@ -20,11 +20,22 @@
 
 #include "painting.h"
 
+#include <qstring.h>
+#include <qptrlist.h>
+
+struct SubParameter {
+  SubParameter(bool display_, const QString& Name_, const QString& Descr_)
+     : display(display_), Name(Name_), Description(Descr_) {};
+
+  bool display;
+  QString Name, Description;
+};
+
 
 class ID_Text : public Painting  {
 public:
   ID_Text(int cx_=0, int cy_=0);
-  ~ID_Text();
+ ~ID_Text();
 
   void paintScheme(QPainter*);
   void getCenter(int&, int&);
@@ -33,8 +44,7 @@ public:
   bool load(const QString&);
   QString save();
   void paint(ViewPainter*);
-  bool getSelected(int, int);
-  void Bounding(int&, int&, int&, int&);
+  bool getSelected(float, float, float);
 
   void rotate();
   void mirrorX();
@@ -42,6 +52,7 @@ public:
   bool Dialog();
 
   QString Prefix;
+  QPtrList<SubParameter> Parameter;
 };
 
 #endif
