@@ -23,15 +23,17 @@ Painting::Painting()
   State = 0;
 }
 
-Painting::~Painting()
-{
-}
-
 Painting* Painting::newOne()
 {
   return new Painting();
 }
 
+void Painting::Bounding(int& _x1, int& _y1, int& _x2, int& _y2)
+{
+  _x1 = cx;     _y1 = cy;
+  _x2 = cx+x2;  _y2 = cy+y2;
+}
+
 QString Painting::save()
 {
   return QString();
