@@ -323,7 +323,7 @@ pInfoFunc Sources[] =
    &CCCS::info, &VCVS::info, &CCVS::info, &vPulse::info, &iPulse::info,
    &vRect::info, &iRect::info, &Noise_ii::info, &Noise_vv::info,
    &Noise_iv::info, &AM_Modulator::info, &PM_Modulator::info, &iExp::info,
-   &vExp::info, 0};
+   &vExp::info, &vFile::info, &iFile::info, 0};
 
 pInfoFunc Probes[] =
   {&iProbe::info, &vProbe::info, 0};
@@ -340,7 +340,8 @@ pInfoFunc nonlinearComps[] =
    &BJTsub::info_pnp, &JFET::info, &JFET::info_p,
    &MOSFET::info, &MOSFET::info_p, &MOSFET::info_depl,
    &MOSFET_sub::info, &MOSFET_sub::info_p, &MOSFET_sub::info_depl,
-   &OpAmp::info, &hicumL2p1::info, &HBT_X::info, &EqnDefined::info};
+   &OpAmp::info, &hicumL2p1::info, &HBT_X::info, &EqnDefined::info,
+   &mod_amp::info, &hic2_full::info, 0};
 
 pInfoFunc digitalComps[] =
   {&Digi_Source::info, &Logical_Inv::info, &Logical_OR::info,
@@ -522,22 +523,27 @@ void QucsApp::slotCMenuRename()
     }
 
   QString Name   = Item->text(0);
-  QString Suffix = Name.section('.',2);   // remember suffix
-  if(!Suffix.isEmpty())
-    Suffix = '.' + Suffix;
+  QString Suffix = Name.section('.',-1);   // remember suffix
+  QString Base   = Name.section('.',0,-2);
+  if(Base.isEmpty()) Base = Name;
 
   bool ok;
   QString s = QInputDialog::getText(tr("Rename file"), tr("Enter new name:"),
-		QLineEdit::Normal, Name.left(Name.length()-4), &ok, this);
+		QLineEdit::Normal, Base, &ok, this);
   if(!ok) return;
   if(s.isEmpty()) return;
 
+  QString NewName;
+  if(s.contains('.'))
+    NewName = s;
+  else
+    NewName = s+"."+Suffix;
   QDir file(QucsWorkDir.path());
-  if(!file.rename(Name, s+Suffix)) {
+  if(!file.rename(Name, NewName)) {
     QMessageBox::critical(this, tr("Error"), tr("Cannot rename file: ")+Name);
     return;
   }
-  Item->setText(0, s+Suffix);
+  Item->setText(0, NewName);
 }
 
 // ----------------------------------------------------------
