@@ -39,6 +39,9 @@
 #include "dialogs/matchdialog.h"
 #include "dialogs/changedialog.h"
 #include "dialogs/searchdialog.h"
+#include "dialogs/librarydialog.h"
+#include "dialogs/importdialog.h"
+#include "dialogs/packagedialog.h"
 
 // for editing component name on schematic
 QRegExp  Expr_CompProp;
@@ -195,7 +198,7 @@ void QucsApp::slotZoomIn(bool on)
 {
   TextDoc *Doc = (TextDoc*)DocumentTab->currentPage();
   if(Doc->inherits("QTextEdit")) {
-    Doc->zoom(2.0f);
+    Doc->zoomBy(2.0f);
     magPlus->blockSignals(true);
     magPlus->setOn(false);
     magPlus->blockSignals(false);
@@ -267,6 +270,7 @@ void QucsApp::slotEditPaste(bool on)
 
   view->drawn = false;
   MouseMoveAction = &MouseActions::MMovePaste;
+  view->movingRotated = 0;
   MousePressAction = 0;
   MouseReleaseAction = 0;
   MouseDoubleClickAction = 0;
@@ -501,6 +505,34 @@ void QucsApp::slotDistribVert()
   view->drawn = false;
 }
 
+// --------------------------------------------------------------
+// Is called, when "Center horizontally" action is activated.
+void QucsApp::slotCenterHorizontal()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  Schematic *Doc = (Schematic*)DocumentTab->currentPage();
+  if(!Doc->aligning(4))
+    QMessageBox::information(this, tr("Info"),
+		      tr("At least two elements must be selected !"));
+  Doc->viewport()->update();
+  view->drawn = false;
+}
+
+// --------------------------------------------------------------
+// Is called, when "Center vertically" action is activated.
+void QucsApp::slotCenterVertical()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  Schematic *Doc = (Schematic*)DocumentTab->currentPage();
+  if(!Doc->aligning(5))
+    QMessageBox::information(this, tr("Info"),
+		      tr("At least two elements must be selected !"));
+  Doc->viewport()->update();
+  view->drawn = false;
+}
+
 // ---------------------------------------------------------------------
 // Is called when the "select all" action is activated.
 void QucsApp::slotSelectAll()
@@ -631,6 +663,23 @@ void QucsApp::slotCallMatch()
   d->exec();
 }
 
+// ------------------------------------------------------------------------
+// Is called to start the attenuator calculation program.
+void QucsApp::slotCallAtt()
+{
+  QProcess *QucsAtt =
+    new QProcess(QString(QucsSettings.BinDir + "qucsattenuator"));
+  if(!QucsAtt->start()) {
+    QMessageBox::critical(this, tr("Error"),
+                          tr("Cannot start attenuator calculation program!"));
+    delete QucsAtt;
+    return;
+  }
+
+  // to kill it before qucs ends
+  connect(this, SIGNAL(signalKillEmAll()), QucsAtt, SLOT(kill()));
+}
+
 // --------------------------------------------------------------
 void QucsApp::slotHelpIndex()
 {
@@ -694,7 +743,6 @@ void QucsApp::slotChangeProps()
 // --------------------------------------------------------------
 void QucsApp::slotAddToProject()
 {
-  static QString lastDir;  // to remember last directory and file
   editText->setHidden(true); // disable text edit of component property
 
   if(ProjName.isEmpty()) {
@@ -718,11 +766,11 @@ void QucsApp::slotAddToProject()
 
   QStringList FileList = List;  // make a copy as recommended by Qt
   QStringList::Iterator it = FileList.begin();
-  lastDir = (*it);   // remember last directory and file
+  QFileInfo Info(*it);
+  lastDir = Info.dirPath(true);  // remember last directory
 
   // copy all files to project directory
   int Num;
-  QFileInfo Info;
   QFile origFile, destFile;
   while(it != FileList.end()) {
     Info.setFile(*it);
@@ -917,8 +965,8 @@ void QucsApp::slotCursorDown()
       movingElements.clear();
     }
     else {
-      if(Doc->scrollUp(Doc->verticalScrollBar()->lineStep()))
-        Doc->scrollBy(0, -Doc->verticalScrollBar()->lineStep());
+      if(Doc->scrollDown(-Doc->verticalScrollBar()->lineStep()))
+        Doc->scrollBy(0, Doc->verticalScrollBar()->lineStep());
     }
 
     Doc->viewport()->update();
@@ -1026,7 +1074,7 @@ void QucsApp::slotApplyCompText()
     view->MAx2 += editText->fontMetrics().width(pp->Name+"=");
     if(pp->Description.find('[') >= 0)  // is selection list ?
       editText->setReadOnly(true);
-    Expr_CompProp.setPattern("[^\"=]+");
+    Expr_CompProp.setPattern("[^\"]*");
     if(!pc->showName) n--;
   }
   else   // it is the component name
@@ -1051,3 +1099,117 @@ void QucsApp::slotResizePropEdit(const QString& t)
   editText->resize(editText->fontMetrics().width(t)+4,
                    editText->fontMetrics().lineSpacing());
 }
+
+// -----------------------------------------------------------
+void QucsApp::slotCreateLib()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  if(ProjName.isEmpty()) {
+    QMessageBox::critical(this, tr("Error"), tr("Please open project with subcircuits!"));
+    return;
+  }
+
+  (new LibraryDialog(this, ConSchematics))->exec();
+}
+
+// -----------------------------------------------------------
+void QucsApp::slotImportData()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  if(ProjName.isEmpty()) {
+    QMessageBox::critical(this, tr("Error"), tr("Please open project first!"));
+    return;
+  }
+
+  ImportDialog *d = new ImportDialog(this);
+  if(d->exec() == QDialog::Accepted)
+    readProjectFiles();  // re-read all project files
+}
+
+// -----------------------------------------------------------
+void QucsApp::slotExportGraphAsCsv()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  for(;;) {
+    if(view->focusElement)
+      if(view->focusElement->Type == isGraph)
+        break;
+
+    QMessageBox::critical(this, tr("Error"), tr("Please select a diagram graph!"));
+    return;
+  }
+
+  QString s = QFileDialog::getSaveFileName(
+     lastDir.isEmpty() ? QString(".") : lastDir,
+     tr("CSV file")+" (*.csv);;" + tr("Any File")+" (*)",
+     this, 0, tr("Enter an Output File Name"));
+  if(s.isEmpty())
+    return;
+
+  QFileInfo Info(s);
+  lastDir = Info.dirPath(true);  // remember last directory
+  if(Info.extension().isEmpty())
+    s += ".csv";
+
+  QFile File(s);
+  if(File.exists())
+    if(QMessageBox::information(this, tr("Info"),
+          tr("Output file already exists!")+"\n"+tr("Overwrite it?"),
+          tr("&Yes"), tr("&No"), 0,1,1))
+      return;
+
+  if(!File.open(IO_WriteOnly)) {
+    QMessageBox::critical(this, QObject::tr("Error"),
+                          QObject::tr("Cannot create output file!"));
+    return;
+  }
+
+  QTextStream Stream(&File);
+
+
+  DataX *pD;
+  Graph *g = (Graph*)view->focusElement;
+  // First output the names of independent and dependent variables.
+  for(pD = g->cPointsX.first(); pD!=0; pD = g->cPointsX.next())
+    Stream << '\"' << pD->Var << "\";";
+  Stream << "\"r " << g->Var << "\";\"i " << g->Var << "\"\n";
+
+
+  int n, m;
+  double *py = g->cPointsY;
+  int Count = g->countY * g->cPointsX.getFirst()->count;
+  for(n = 0; n < Count; n++) {
+    m = n;
+    for(pD = g->cPointsX.first(); pD!=0; pD = g->cPointsX.next()) {
+      Stream << *(pD->Points + m%pD->count) << ';';
+      m /= pD->count;
+    }
+
+    Stream << *(py) << ';' << *(py+1) << '\n';
+    py += 2;
+  }
+
+  File.close();
+}
+
+// ----------------------------------------------------------
+void QucsApp::slotCreatePackage()
+{
+  editText->setHidden(true); // disable text edit of component property
+
+  PackageDialog *d = new PackageDialog(this, true);
+  d->exec();
+}
+
+// ----------------------------------------------------------
+void QucsApp::slotExtractPackage()
+{
+  editText->setHidden(true); // disable text edit of component property
+  PackageDialog *d = new PackageDialog(this, false);
+  d->show();
+  d->extractPackage();
+  readProjects();
+}
