@@ -869,19 +869,62 @@ void Schematic::markerUpDown(bool up, QPtrList<Element> *Elements)
 // Selects the element that contains the coordinates x/y.
 // Returns the pointer to the element.
 // If 'flag' is true, the element can be deselected.
-Element* Schematic::selectElement(int x, int y, bool flag, int *index)
+Element* Schematic::selectElement(float fX, float fY, bool flag, int *index)
 {
-  int n;
+  int n, x = int(fX), y = int(fY);
   Element *pe_1st=0, *pe_sel=0;
   float Corr = textCorr(); // for selecting text
 
+  WireLabel *pl;
+  // test all nodes and their labels
+  for(Node *pn = Nodes->last(); pn != 0; pn = Nodes->prev()) {
+    if(!flag)
+      if(index)  // only true if called from MouseActions::MPressSelect()
+        if(pn->getSelected(x, y))
+          return pn;
+
+    pl = pn->Label;
+    if(pl) if(pl->getSelected(x, y)) {
+      if(flag) { pl->isSelected ^= flag; return pl; }
+      if(pe_sel) {
+        pe_sel->isSelected = false;
+        return pl;
+      }
+      if(pe_1st == 0) pe_1st = pl;  // give access to elements lying beneath
+      if(pl->isSelected) pe_sel = pl;
+    }
+  }
+
+  // test all wires and wire labels
+  for(Wire *pw = Wires->last(); pw != 0; pw = Wires->prev()) {
+    if(pw->getSelected(x, y)) {
+      if(flag) { pw->isSelected ^= flag; return pw; }
+      if(pe_sel) {
+        pe_sel->isSelected = false;
+        return pw;
+      }
+      if(pe_1st == 0) pe_1st = pw;  // give access to elements lying beneath
+      if(pw->isSelected) pe_sel = pw;
+    }
+    pl = pw->Label;
+    if(pl) if(pl->getSelected(x, y)) {
+      if(flag) { pl->isSelected ^= flag; return pl; }
+      if(pe_sel) {
+        pe_sel->isSelected = false;
+        return pl;
+      }
+      if(pe_1st == 0) pe_1st = pl;  // give access to elements lying beneath
+      if(pl->isSelected) pe_sel = pl;
+    }
+  }
+
   // test all components
   for(Component *pc = Components->last(); pc != 0; pc = Components->prev())
     if(pc->getSelected(x, y)) {
       if(flag) { pc->isSelected ^= flag; return pc; }
       if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pc;
+        pe_sel->isSelected = false;
+        return pc;
       }
       if(pe_1st == 0) pe_1st = pc;  // give access to elements lying beneath
       if(pc->isSelected) pe_sel = pc;
@@ -895,45 +938,8 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
       }
     }
 
-  WireLabel *pl;
-  // test all wires and wire labels
-  for(Wire *pw = Wires->last(); pw != 0; pw = Wires->prev()) {
-    if(pw->getSelected(x, y)) {
-      if(flag) { pw->isSelected ^= flag; return pw; }
-      if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pw;
-      }
-      if(pe_1st == 0) pe_1st = pw;  // give access to elements lying beneath
-      if(pw->isSelected) pe_sel = pw;
-    }
-    pl = pw->Label;
-    if(pl) if(pl->getSelected(x, y)) {
-      if(flag) { pl->isSelected ^= flag; return pl; }
-      if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pl;
-      }
-      if(pe_1st == 0) pe_1st = pl;  // give access to elements lying beneath
-      if(pl->isSelected) pe_sel = pl;
-    }
-  }
-
-  // test all node labels
-  for(Node *pn = Nodes->last(); pn != 0; pn = Nodes->prev()) {
-    pl = pn->Label;
-    if(pl) if(pl->getSelected(x, y)) {
-      if(flag) { pl->isSelected ^= flag; return pl; }
-      if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pl;
-      }
-      if(pe_1st == 0) pe_1st = pl;  // give access to elements lying beneath
-      if(pl->isSelected) pe_sel = pl;
-    }
-  }
-
   Graph *pg;
+  Corr = 5.0 / Scale;  // size of line select and area for resizing
   // test all diagrams
   for(Diagram *pd = Diagrams->last(); pd != 0; pd = Diagrams->prev()) {
 
@@ -943,19 +949,19 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
         if(pm->getSelected(x-pd->cx, y-pd->cy)) {
           if(flag) { pm->isSelected ^= flag; return pm; }
           if(pe_sel) {
-	    pe_sel->isSelected = false;
-	    return pm;
-	  }
+            pe_sel->isSelected = false;
+            return pm;
+          }
           if(pe_1st == 0) pe_1st = pm; // give access to elements beneath
           if(pm->isSelected) pe_sel = pm;
         }
 
     // resize area clicked ?
     if(pd->isSelected)
-      if(pd->ResizeTouched(x, y))
-	if(pe_1st == 0) {
-	  pd->Type = isDiagramResize;
-	  return pd;
+      if(pd->resizeTouched(fX, fY, Corr))
+        if(pe_1st == 0) {
+          pd->Type = isDiagramResize;
+          return pd;
         }
 
     if(pd->getSelected(x, y)) {
@@ -963,13 +969,13 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
         if(pd->Name[1] == 'i') {
           if(y > pd->cy) {
             if(x < pd->cx+pd->xAxis.numGraphs) continue;
-            pd->Type = isDiagramScroll;
+            pd->Type = isDiagramHScroll;
             return pd;
           }
         }
         else {
           if(x < pd->cx) {      // clicked on scroll bar ?
-            pd->Type = isDiagramScroll;
+            pd->Type = isDiagramVScroll;
             return pd;
           }
         }
@@ -979,9 +985,9 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
         if(pg->getSelected(x-pd->cx, pd->cy-y) >= 0) {
           if(flag) { pg->isSelected ^= flag; return pg; }
           if(pe_sel) {
-	    pe_sel->isSelected = false;
-	    return pg;
-	  }
+            pe_sel->isSelected = false;
+            return pg;
+          }
           if(pe_1st == 0) pe_1st = pg;  // access to elements lying beneath
           if(pg->isSelected) pe_sel = pg;
         }
@@ -989,8 +995,8 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
 
       if(flag) { pd->isSelected ^= flag; return pd; }
       if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pd;
+        pe_sel->isSelected = false;
+        return pd;
       }
       if(pe_1st == 0) pe_1st = pd;  // give access to elements lying beneath
       if(pd->isSelected) pe_sel = pd;
@@ -1000,17 +1006,17 @@ Element* Schematic::selectElement(int x, int y, bool flag, int *index)
   // test all paintings
   for(Painting *pp = Paintings->last(); pp != 0; pp = Paintings->prev()) {
     if(pp->isSelected)
-      if(pp->ResizeTouched(x, y))
-	if(pe_1st == 0) {
-	  pp->Type = isPaintingResize;
-	  return pp;
+      if(pp->resizeTouched(fX, fY, Corr))
+        if(pe_1st == 0) {
+          pp->Type = isPaintingResize;
+          return pp;
         }
 
-    if(pp->getSelected(x, y)) {
+    if(pp->getSelected(fX, fY, Corr)) {
       if(flag) { pp->isSelected ^= flag; return pp; }
       if(pe_sel) {
-	pe_sel->isSelected = false;
-	return pp;
+        pe_sel->isSelected = false;
+        return pp;
       }
       if(pe_1st == 0) pe_1st = pp;  // give access to elements lying beneath
       if(pp->isSelected) pe_sel = pp;
@@ -1174,99 +1180,112 @@ void Schematic::selectMarkers()
 // For moving elements: If the moving element is connected to a not
 // moving element, insert two wires. If the connected element is already
 // a wire, use this wire. Otherwise create new wire.
-void Schematic::newMovingWires(QPtrList<Element> *p, Node *pn)
+void Schematic::newMovingWires(QPtrList<Element> *p, Node *pn, int pos)
 {
-  if(pn->Connections.count() < 1) return; // return, if connected node moves
-  Element *pe = pn->Connections.getFirst();
-  if(pe == (Element*)1) return; // return, if it was already treated this way
-  pn->Connections.prepend((Element*)1);  // to avoid doubling
+  Element *pe;
 
-  if(pn->Connections.count() == 2)    // 2, because of prepend (Element*)1
-    if(pe->Type == isWire) {    // is it connected to exactly one wire ?
+  if(pn->State & 8)  // Were new wires already inserted ?
+    return;
+  pn->State |= 8;
 
-      // .................................................
-      Wire *pw2=0, *pw = (Wire*)pe;
+  for (;;) {
+    if(pn->State & 16)  // node was already worked on
+      break;
 
-      Node *pn2 = pw->Port1;
-      if(pn2 == pn) pn2 = pw->Port2;
+    pe = pn->Connections.getFirst();
+    if(pe == 0)  return;
 
-      if(pn2->Connections.count() == 2) { // two existing wires connected ?
+    if(pn->Connections.count() > 1)
+      break;
+    if(pe->Type != isWire)  // is it connected to exactly one wire ?
+      break;
+
+    // .................................................
+    long  mask = 1, invMask = 3;
+    Wire *pw2=0, *pw = (Wire*)pe;
+
+    Node *pn2 = pw->Port1;
+    if(pn2 == pn) pn2 = pw->Port2;
+
+    if(pn2->Connections.count() == 2) // two existing wires connected ?
+      if((pn2->State & (8+4)) == 0) {
         Element *pe2 = pn2->Connections.getFirst();
         if(pe2 == pe) pe2 = pn2->Connections.getLast();
-        if(pe2 != (Element*)1)
-          if(pe2->Type == isWire)  // connected wire connected to ...
-            pw2  = (Wire*)pe2;     // ... exactly one wire ?
+        // connected wire connected to exactly one wire ?
+        if(pe2->Type == isWire)
+          pw2  = (Wire*)pe2;
       }
 
-      // .................................................
-      // reuse one wire
-      p->append(pw);
-      pw->Port1->Connections.removeRef(pw);   // remove connection 1
-      pw->Port2->Connections.removeRef(pw);   // remove connection 2
-      if(pw->Port1->Connections.getFirst() !=  (Element*)1)
-        pw->Port1->Connections.prepend((Element*)1);  // remember this action
-      if(pw->Port2->Connections.getFirst() !=  (Element*)1)
-        pw->Port2->Connections.prepend((Element*)1);  // remember this action
-      Wires->take(Wires->findRef(pw));
-      long mask = 1;
-      if(pw->isHorizontal()) mask = 2;
+    // .................................................
+    // reuse one wire
+    p->insert(pos, pw);
+    pw->Port1->Connections.removeRef(pw);   // remove connection 1
+    pw->Port1->State |= 16+4;
+    pw->Port2->Connections.removeRef(pw);   // remove connection 2
+    pw->Port2->State |= 16+4;
+    Wires->take(Wires->findRef(pw));
 
-      if(pw->Port1 != pn) {
-	pw->Port1->State = mask;
-	pw->Port1 = (Node*)mask;
-	pw->Port2->State = 3;
-	pw->Port2 = (Node*)3;    // move port 2 completely
-      }
-      else {
-	pw->Port1->State = 3;
-	pw->Port1 = (Node*)3;
-	pw->Port2->State = mask;
-	pw->Port2 = (Node*)mask;
-      }
+    if(pw->isHorizontal()) mask = 2;
 
-      // .................................................
-      // create new wire ?
-      if(pw2 == 0) {
-        if(pw->Port1 == (Node*)3)
-          p->append(new Wire(pw->x2, pw->y2, pw->x2, pw->y2,
-			     (Node*)mask, (Node*)0));
-        else
-          p->append(new Wire(pw->x1, pw->y1, pw->x1, pw->y1,
-			     (Node*)mask, (Node*)0));
-        return;
-      }
+    if(pw2 == 0) {  // place new wire between component and old wire
+      pn = pn2;
+      mask ^= 3;
+      invMask = 0;
+    }
 
+    if(pw->Port1 != pn) {
+      pw->Port1->State |= mask;
+      pw->Port1 = (Node*)mask;
+      pw->Port2->State |= invMask;
+      pw->Port2 = (Node*)invMask;  // move port 2 completely
+    }
+    else {
+      pw->Port1->State |= invMask;
+      pw->Port1 = (Node*)invMask;
+      pw->Port2->State |= mask;
+      pw->Port2 = (Node*)mask;
+    }
 
-      // .................................................
-      // reuse a second wire
-      p->append(pw2);
-      pw2->Port1->Connections.removeRef(pw2);   // remove connection 1
-      pw2->Port2->Connections.removeRef(pw2);   // remove connection 2
-      if(pw2->Port1->Connections.getFirst() !=  (Element*)1)
-        pw2->Port1->Connections.prepend((Element*)1); // remember this action
-      if(pw2->Port2->Connections.getFirst() !=  (Element*)1)
-        pw2->Port2->Connections.prepend((Element*)1); // remember this action
-      Wires->take(Wires->findRef(pw2));
-
-      if(pw2->Port1 != pn2) {
-	pw2->Port1->State = 0;
-	pw2->Port1 = (Node*)0;
-	pw2->Port2->State = mask;
-	pw2->Port2 = (Node*)mask;
-      }
-      else {
-	pw2->Port1->State = mask;
-	pw2->Port1 = (Node*)mask;
-	pw2->Port2->State = 0;
-	pw2->Port2 = (Node*)0;
-      }
+    invMask ^= 3;
+    // .................................................
+    // create new wire ?
+    if(pw2 == 0) {
+      if(pw->Port1 != (Node*)mask)
+        p->insert(pos,
+          new Wire(pw->x2, pw->y2, pw->x2, pw->y2, (Node*)mask, (Node*)invMask));
+      else
+        p->insert(pos,
+          new Wire(pw->x1, pw->y1, pw->x1, pw->y1, (Node*)mask, (Node*)invMask));
       return;
     }
 
+
+    // .................................................
+    // reuse a second wire
+    p->insert(pos, pw2);
+    pw2->Port1->Connections.removeRef(pw2);   // remove connection 1
+    pw2->Port1->State |= 16+4;
+    pw2->Port2->Connections.removeRef(pw2);   // remove connection 2
+    pw2->Port2->State |= 16+4;
+    Wires->take(Wires->findRef(pw2));
+
+    if(pw2->Port1 != pn2) {
+      pw2->Port1 = (Node*)0;
+      pw2->Port2->State |= mask;
+      pw2->Port2 = (Node*)mask;
+    }
+    else {
+      pw2->Port1->State |= mask;
+      pw2->Port1 = (Node*)mask;
+      pw2->Port2 = (Node*)0;
+    }
+    return;
+  }
+
   // only x2 moving
-  p->append(new Wire(pn->cx, pn->cy, pn->cx, pn->cy, (Node*)0, (Node*)1));
+  p->insert(pos, new Wire(pn->cx, pn->cy, pn->cx, pn->cy, (Node*)0, (Node*)1));
   // x1, x2, y2 moving
-  p->append(new Wire(pn->cx, pn->cy, pn->cx, pn->cy, (Node*)1, (Node*)3));
+  p->insert(pos, new Wire(pn->cx, pn->cy, pn->cx, pn->cy, (Node*)1, (Node*)3));
 }
 
 // ---------------------------------------------------
@@ -1274,7 +1293,7 @@ void Schematic::newMovingWires(QPtrList<Element> *p, Node *pn)
 // list 'p' and deletes them from the document.
 int Schematic::copySelectedElements(QPtrList<Element> *p)
 {
-  int markerCount = 0;
+  int i, count = 0;
   Port      *pp;
   Component *pc;
   Wire      *pw;
@@ -1284,13 +1303,17 @@ int Schematic::copySelectedElements(QPtrList<Element> *p)
 
 
   // test all components *********************************
+  // Insert components before wires in order to prevent short-cut removal.
   for(pc = Components->first(); pc != 0; )
     if(pc->isSelected) {
       p->append(pc);
+      count++;
 
       // delete all port connections
-      for(pp = pc->Ports.first(); pp!=0; pp = pc->Ports.next())
+      for(pp = pc->Ports.first(); pp!=0; pp = pc->Ports.next()) {
         pp->Connection->Connections.removeRef((Element*)pc);
+        pp->Connection->State = 4;
+      }
 
       Components->take();   // take component out of the document
       pc = Components->current();
@@ -1306,13 +1329,85 @@ int Schematic::copySelectedElements(QPtrList<Element> *p)
       p->append(pw);
 
       pw->Port1->Connections.removeRef(pw);   // remove connection 1
+      pw->Port1->State = 4;
       pw->Port2->Connections.removeRef(pw);   // remove connection 2
+      pw->Port2->State = 4;
       Wires->take();
       pw = Wires->current();
     }
     else pw = Wires->next();
   }
 
+  // ..............................................
+  // Inserts wires, if a connection to a not moving element is found.
+  // The order of the "for"-loops is important to guarantee a stable
+  // operation: components, new wires, old wires
+  pc = (Component*)p->first();
+  for(i=0; i<count; i++) {
+    for(pp = pc->Ports.first(); pp!=0; pp = pc->Ports.next())
+       newMovingWires(p, pp->Connection, count);
+
+    p->findRef(pc);   // back to the real current pointer
+    pc = (Component*)p->next();
+  }
+
+  for(pe = (Element*)pc; pe != 0; pe = p->next())  // new wires
+    if(pe->isSelected)
+      break;
+
+  for(pw = (Wire*)pe; pw != 0; pw = (Wire*)p->next())
+    if(pw->Type == isWire) {  // not working on labels
+      newMovingWires(p, pw->Port1, count);
+      newMovingWires(p, pw->Port2, count);
+      p->findRef(pw);   // back to the real current pointer
+    }
+
+
+  // ..............................................
+  // delete the unused nodes
+  for(pn = Nodes->first(); pn!=0; ) {
+    if(pn->State & 8)
+      if(pn->Connections.count() == 2)
+        if(oneTwoWires(pn)) {  // if possible, connect two wires to one
+          pn = Nodes->current();
+          continue;
+        }
+
+    if(pn->Connections.count() == 0) {
+      if(pn->Label) {
+        pn->Label->Type = isMovingLabel;
+        if(pn->State & 1) {
+          if(!(pn->State & 2)) pn->Label->Type = isHMovingLabel;
+        }
+        else if(pn->State & 2) pn->Label->Type = isVMovingLabel;
+        p->append(pn->Label);    // do not forget the node labels
+      }
+      Nodes->remove();
+      pn = Nodes->current();
+      continue;
+    }
+
+    pn->State = 0;
+    pn = Nodes->next();
+  }
+
+  // test all node labels
+  // do this last to avoid double copying
+  for(pn = Nodes->first(); pn != 0; pn = Nodes->next())
+    if(pn->Label) if(pn->Label->isSelected)
+      p->append(pn->Label);
+
+
+  // test all paintings **********************************
+  for(Painting *ppa = Paintings->first(); ppa != 0; )
+    if(ppa->isSelected) {
+      p->append(ppa);
+      Paintings->take();
+      ppa = Paintings->current();
+    }
+    else ppa = Paintings->next();
+
+  count = 0;  // count markers now
   // test all diagrams **********************************
   for(pd = Diagrams->first(); pd != 0; )
     if(pd->isSelected) {
@@ -1324,7 +1419,7 @@ int Schematic::copySelectedElements(QPtrList<Element> *p)
       for(Graph *pg = pd->Graphs.first(); pg!=0; pg = pd->Graphs.next())
         for(Marker *pm = pg->Markers.first(); pm != 0; )
           if(pm->isSelected) {
-            markerCount++;
+            count++;
             p->append(pm);
             pg->Markers.take();
             pm = pg->Markers.current();
@@ -1334,71 +1429,7 @@ int Schematic::copySelectedElements(QPtrList<Element> *p)
       pd = Diagrams->next();
     }
 
-  // test all paintings **********************************
-  for(Painting *ppa = Paintings->first(); ppa != 0; )
-    if(ppa->isSelected) {
-      p->append(ppa);
-      Paintings->take();
-      ppa = Paintings->current();
-    }
-    else ppa = Paintings->next();
-
-  // ..............................................
-  // Inserts wires, if a connection to a not moving element is found.
-  // Go backwards in order not to test the new insertions.
-  for(pe = p->last(); pe!=0; pe = p->prev())
-    if(pe->Type & isComponent) {
-      pc = (Component*)pe;
-      for(pp = pc->Ports.first(); pp!=0; pp = pc->Ports.next())
-         newMovingWires(p, pp->Connection);
-
-      p->findRef(pe);   // back to the real current pointer
-    }
-    else if(pe->Type == isWire) {
-      pw = (Wire*)pe;
-      newMovingWires(p, pw->Port1);
-      newMovingWires(p, pw->Port2);
-      p->findRef(pe);   // back to the real current pointer
-    }
-
-
-  // ..............................................
-  // delete the unused nodes
-  for(pn = Nodes->first(); pn!=0; ) {
-    if(pn->Connections.getFirst() == (Element*)1) {
-      pn->Connections.removeFirst();  // delete tag
-      if(pn->Connections.count() == 2)
-        if(oneTwoWires(pn)) {  // if possible, connect two wires to one
-          pn = Nodes->current();
-          continue;
-        }
-    }
-
-    if(pn->Connections.count() == 0) {
-      if(pn->Label) {
-	pn->Label->Type = isMovingLabel;
-	if(pn->State & 1) {
-	  if(!(pn->State & 2)) pn->Label->Type = isHMovingLabel;
-	}
-	else if(pn->State & 2) pn->Label->Type = isVMovingLabel;
-	pn->State = 0;
-	p->append(pn->Label);    // do not forget the node labels
-      }
-      Nodes->remove();
-      pn = Nodes->current();
-      continue;
-    }
-
-    pn = Nodes->next();
-  }
-
-  // test all node labels
-  // do this last to avoid double copying
-  for(pn = Nodes->first(); pn != 0; pn = Nodes->next())
-    if(pn->Label) if(pn->Label->isSelected)
-      p->append(pn->Label);
-
-  return markerCount;
+  return count;
 }
 
 // ---------------------------------------------------
@@ -1561,33 +1592,54 @@ bool Schematic::deleteElements()
 bool Schematic::aligning(int Mode)
 {
   int x1, y1, x2, y2;
-  int bx1, by1, bx2, by2, *bx=0, *by=0;
+  int bx1, by1, bx2, by2, *bx=0, *by=0, *ax=0, *ay=0;
   QPtrList<Element> ElementCache;
   int count = copyElements(x1, y1, x2, y2, &ElementCache);
   if(count < 1) return false;
 
 
+  ax = ay = &x2;  // = 0
   switch(Mode) {
     case 0:  // align top
 	bx = &x1;
 	by = &by1;
+	y2 = 1;
 	break;
     case 1:  // align bottom
 	bx = &x1;
 	y1 = y2;
 	by = &by2;
+	y2 = 1;
 	break;
     case 2:  // align left
 	by = &y1;
 	bx = &bx1;
+	y2 = 1;
 	break;
     case 3:  // align right
 	by = &y1;
 	x1 = x2;
 	bx = &bx2;
+	y2 = 1;
+	break;
+    case 4:  // center horizontally
+	x1 = (x2+x1) / 2;
+	by = &x2;  // = 0
+	ax = &bx1;
+	bx = &bx2;
+	y1 = 0;
+	y2 = 2;
+	break;
+    case 5:  // center vertically
+	y1 = (y2+y1) / 2;
+	bx = &x2;  // = 0
+	ay = &by1;
+	by = &by2;
+	x1 = 0;
+	y2 = 2;
 	break;
   }
-
+  x2 = 0;
 
   Wire *pw;
   Component *pc;
@@ -1598,31 +1650,39 @@ bool Schematic::aligning(int Mode)
       case isComponent:
       case isAnalogComponent:
       case isDigitalComponent:
-	pc = (Component*)pe;
-	pc->Bounding(bx1, by1, bx2, by2);
-	pc->setCenter(x1-(*bx), y1-(*by), true);
-	insertRawComponent(pc);
-	break;
+        pc = (Component*)pe;
+        pc->Bounding(bx1, by1, bx2, by2);
+        pc->setCenter(x1-((*bx)+(*ax))/y2, y1-((*by)+(*ay))/y2, true);
+        insertRawComponent(pc);
+        break;
 
       case isWire:
-	pw = (Wire*)pe;
-	bx1 = pw->x1;
-	by1 = pw->y1;
-	bx2 = pw->x2;
-	by2 = pw->y2;
-	pw->setCenter(x1-(*bx), y1-(*by), true);
-//	if(pw->Label) {	}
-	insertWire(pw);
-	break;
+        pw = (Wire*)pe;
+        bx1 = pw->x1;
+        by1 = pw->y1;
+        bx2 = pw->x2;
+        by2 = pw->y2;
+        pw->setCenter(x1-((*bx)+(*ax))/y2, y1-((*by)+(*ay))/y2, true);
+//        if(pw->Label) {  }
+        insertWire(pw);
+        break;
 
       case isDiagram:
-	((Diagram*)pe)->Bounding(bx1, by1, bx2, by2);
-	((Diagram*)pe)->setCenter(x1-(*bx), y1-(*by), true);
-	break;
+        // Should the axis label be counted for ? I guess everyone
+        // has a different opinion.
+//        ((Diagram*)pe)->Bounding(bx1, by1, bx2, by2);
+
+        // Take size without axis label.
+        bx1 = ((Diagram*)pe)->cx;
+        by2 = ((Diagram*)pe)->cy;
+        bx2 = bx1 + ((Diagram*)pe)->x2;
+        by1 = by2 - ((Diagram*)pe)->y2;
+        ((Diagram*)pe)->setCenter(x1-((*bx)+(*ax))/y2, y1-((*by)+(*ay))/y2, true);
+        break;
 
       case isPainting:
         ((Painting*)pe)->Bounding(bx1, by1, bx2, by2);
-        ((Painting*)pe)->setCenter(x1-(*bx), y1-(*by), true);
+        ((Painting*)pe)->setCenter(x1-((*bx)+(*ax))/y2, y1-((*by)+(*ay))/y2, true);
         break;
 
       case isNodeLabel:
@@ -1635,8 +1695,8 @@ bool Schematic::aligning(int Mode)
           bx1 = pw->x1;  by1 = pw->y1;
           bx2 = pw->x2;  by2 = pw->y2;
         }
-        ((WireLabel*)pe)->cx += x1-(*bx);
-        ((WireLabel*)pe)->cy += y1-(*by);
+        ((WireLabel*)pe)->cx += x1-((*bx)+(*ax))/y2;
+        ((WireLabel*)pe)->cy += y1-((*by)+(*ay))/y2;
         insertNodeLabel((WireLabel*)pe);
         break;
 
@@ -1812,6 +1872,7 @@ bool Schematic::distributeVertical()
       case isPainting:
         pe->getCenter(bx1, by1);
         pe->setCenter(bx1, y, false);
+        break;
 
       case isNodeLabel:
         if(((Element*)(((WireLabel*)pe)->pOwner))->Type & isComponent)
@@ -2488,11 +2549,12 @@ void Schematic::copyLabels(int& x1, int& y1, int& x2, int& y2,
    *****                                                         *****
    ******************************************************************* */
 
-Painting* Schematic::selectedPainting(int x, int y)
+Painting* Schematic::selectedPainting(float fX, float fY)
 {
-  // test all paintings
+  float Corr = 5.0 / Scale; // size of line select
+
   for(Painting *pp = Paintings->first(); pp != 0; pp = Paintings->next())
-    if(pp->getSelected(x,y))
+    if(pp->getSelected(fX, fY, Corr))
       return pp;
 
   return 0;
