@@ -19,20 +19,23 @@
 # include <config.h>
 #endif
 
-#include "node.h"
-#include "diagrams/diagrams.h"
-#include "paintings/paintings.h"
-#include "components/spicefile.h"
-#include "components/libcomp.h"
-#include "schematic.h"
-#include "main.h"
-
 #include <qmessagebox.h>
 #include <qdir.h>
 #include <qstringlist.h>
 #include <qregexp.h>
 #include <qprocess.h>
 #include <qtextedit.h>
+#include <qptrlist.h>
+
+#include "main.h"
+#include "node.h"
+#include "schematic.h"
+#include "diagrams/diagrams.h"
+#include "paintings/paintings.h"
+#include "components/spicefile.h"
+#include "components/vhdlfile.h"
+#include "components/verilogfile.h"
+#include "components/libcomp.h"
 
 
 extern QDir QucsWorkDir;
@@ -208,6 +211,17 @@ int Schematic::saveDocument()
   stream << "  <DataSet=" << DataSet << ">\n";
   stream << "  <DataDisplay=" << DataDisplay << ">\n";
   stream << "  <OpenDisplay=" << SimOpenDpl << ">\n";
+  stream << "  <showFrame=" << showFrame << ">\n";
+
+  QString t;
+  convert2ASCII(t = Frame_Text0);
+  stream << "  <FrameText0=" << t << ">\n";
+  convert2ASCII(t = Frame_Text1);
+  stream << "  <FrameText1=" << t << ">\n";
+  convert2ASCII(t = Frame_Text2);
+  stream << "  <FrameText2=" << t << ">\n";
+  convert2ASCII(t = Frame_Text3);
+  stream << "  <FrameText3=" << t << ">\n";
   stream << "</Properties>\n";
 
   Painting *pp;
@@ -275,9 +289,8 @@ bool Schematic::loadProperties(QTextStream *stream)
 		ViewX2 = nstr.section(',',2,2).toInt(&ok); if(ok) {
 		ViewY2 = nstr.section(',',3,3).toInt(&ok); if(ok) {
 		Scale  = nstr.section(',',4,4).toDouble(&ok); if(ok) {
-		int PosX = nstr.section(',',5,5).toInt(&ok); if(ok) {
-		int PosY = nstr.section(',',6,6).toInt(&ok); if(ok)
-		setContentsPos(PosX, PosY); }}}}}} }
+		tmpViewX1 = nstr.section(',',5,5).toInt(&ok); if(ok)
+		tmpViewY1 = nstr.section(',',6,6).toInt(&ok); }}}}} }
     else if(cstr == "Grid") {
 		GridX = nstr.section(',',0,0).toInt(&ok); if(ok) {
 		GridY = nstr.section(',',1,1).toInt(&ok); if(ok) {
@@ -288,6 +301,12 @@ bool Schematic::loadProperties(QTextStream *stream)
     else if(cstr == "OpenDisplay")
 		if(nstr.toInt(&ok) == 0) SimOpenDpl = false;
 		else SimOpenDpl = true;
+    else if(cstr == "showFrame")
+		showFrame = nstr.at(0).latin1() - '0';
+    else if(cstr == "FrameText0") convert2Unicode(Frame_Text0 = nstr);
+    else if(cstr == "FrameText1") convert2Unicode(Frame_Text1 = nstr);
+    else if(cstr == "FrameText2") convert2Unicode(Frame_Text2 = nstr);
+    else if(cstr == "FrameText3") convert2Unicode(Frame_Text3 = nstr);
     else {
       QMessageBox::critical(0, QObject::tr("Error"),
 	   QObject::tr("Format Error:\nUnknown property: ")+cstr);
@@ -558,11 +577,8 @@ bool Schematic::loadDocument()
     return false;
   }
 
-  QString s = PACKAGE_VERSION;
-  s.remove('.');
   Line = Line.mid(16, Line.length()-17);
-  Line.remove('.');
-  if(Line > s) {  // wrong version number ? (only backward compatible)
+  if(!checkVersion(Line)) { // wrong version number ?
     file.close();
     QMessageBox::critical(0, QObject::tr("Error"),
 		 QObject::tr("Wrong document version: ")+Line);
@@ -747,7 +763,7 @@ void Schematic::throughAllNodes(bool User, QStringList& Collect,
       if(Signals.findIndex(pn->Name) < 0)  // avoid redeclaration of signal
         Signals.append(pn->Name);
 
-    createNodeSet(Collect, countInit, pn, pn);
+    if(Analog) createNodeSet(Collect, countInit, pn, pn);
 
     pn->State = 1;
     Cons.append(pn);
@@ -773,7 +789,7 @@ void Schematic::throughAllNodes(bool User, QStringList& Collect,
 	  }
 	  if(setName) {
 	    Cons.findRef(p2);   // back to current Connection
-	    createNodeSet(Collect, countInit, pw, pn);
+	    if (Analog) createNodeSet(Collect, countInit, pw, pn);
 	    setName = false;
 	  }
 	}
@@ -812,7 +828,10 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
   bool r;
   QString s;
   // give the ground nodes the name "gnd", and insert subcircuits etc.
-  for(Component *pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
+  QPtrListIterator<Component> it(DocComps);
+  Component *pc;
+  while((pc = it.current()) != 0) {
+    ++it;
     if(pc->isActive != COMP_IS_ACTIVE) continue;
 
     if(NumPorts < 0) {
@@ -834,11 +853,12 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
     }
 
     if(pc->Model == "Sub") {
-      s = pc->Props.getFirst()->Value;
-      if(StringList.findIndex(s) >= 0)
+      QString f = "SCH:"+pc->getSubcircuitFile();
+      if(StringList.findIndex(f) >= 0)
         continue;   // insert each subcircuit just one time
+      StringList.append(f);
 
-      StringList.append(s);
+      s = pc->Props.first()->Value;
       Schematic *d = new Schematic(0, QucsWorkDir.filePath(s));
       if(!d->loadDocument()) {  // load document if possible
         delete d;
@@ -846,6 +866,8 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
         return false;
       }
       d->DocName = s;
+      d->isVerilog = isVerilog;
+      d->creatingLib = creatingLib;
       r = d->createSubNetlist(stream, countInit, Collect, ErrText, NumPorts);
       delete d;
       if(!r) return false;
@@ -853,17 +875,31 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
     }
 
     if(pc->Model == "Lib") {
-      s  = pc->Props.first()->Value + "_";
-      s += pc->Props.next()->Value;
+      if(creatingLib) {
+	ErrText->insert(
+	    QObject::tr("WARNING: Skipping library component \"%1\".").
+	    arg(pc->Name));
+	continue;
+      }
+      s  = "LIB:" + pc->getSubcircuitFile();
+      s += "/" + pc->Props.next()->Value;
       if(StringList.findIndex(s) >= 0)
         continue;   // insert each subcircuit just one time
-
       StringList.append(s);
-      r = ((LibComp*)pc)->outputSubNetlist(stream);
+
+      if(NumPorts < 0)
+	r = ((LibComp*)pc)->createSubNetlist(stream, StringList, 1);
+      else {
+	if(isVerilog)
+	  r = ((LibComp*)pc)->createSubNetlist(stream, StringList, 4);
+	else
+	  r = ((LibComp*)pc)->createSubNetlist(stream, StringList, 2);
+      }
       if(!r) {
-        ErrText->insert(
-        QObject::tr("ERROR: Cannot load library component \"%1\".").arg(pc->Name));
-        return false;
+	ErrText->insert(
+	    QObject::tr("ERROR: Cannot load library component \"%1\".").
+	    arg(pc->Name));
+	return false;
       }
       continue;
     }
@@ -875,44 +911,55 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
                         arg(pc->Name));
         return false;
       }
-      if(StringList.findIndex(s) >= 0)
+      QString f = "CIR:"+pc->getSubcircuitFile();
+      if(StringList.findIndex(f) >= 0)
         continue;   // insert each spice component just one time
+      StringList.append(f);
 
-      StringList.append(s);
+#if 0
       s += '"'+pc->Props.next()->Value;
       if(pc->Props.next()->Value == "yes")  s = "SPICE \""+s;
       else  s = "SPICEo\""+s;
       Collect.append(s);
+#endif
+
+      SpiceFile *sf = (SpiceFile*)pc;
+      r = sf->createSubNetlist(stream);
+      ErrText->insert(sf->getErrorText());
+      if(!r) return false;
       continue;
     }
 
-    if(pc->Model == "VHDL") {
+    if(pc->Model == "VHDL" || pc->Model == "Verilog") {
+      if(isVerilog && pc->Model == "VHDL")
+	continue;
+      if(!isVerilog && pc->Model == "Verilog")
+	continue;
       s = pc->Props.getFirst()->Value;
       if(s.isEmpty()) {
-        ErrText->insert(QObject::tr("ERROR: No file name in VHDL component \"%1\".").
+        ErrText->insert(QObject::tr("ERROR: No file name in %1 component \"%2\".").
+			arg(pc->Model).
                         arg(pc->Name));
         return false;
       }
-      if(StringList.findIndex(s) >= 0)
-        continue;   // insert each vhdl component just one time
-      StringList.append(s);
+      QString f = pc->getSubcircuitFile();
+      f = ((pc->Model == "VHDL") ? "VHD:" : "VER:") + f;
+      if(StringList.findIndex(f) >= 0)
+        continue;   // insert each vhdl/verilog component just one time
+      StringList.append(f);
 
-      QFileInfo Info(s);
-      if(Info.isRelative())
-        s = QucsWorkDir.filePath(s);
-
-      QFile f(s);
-      if(!f.open(IO_ReadOnly)) {
-        ErrText->insert(
-           QObject::tr("ERROR: Cannot open VHDL file \"%1\".").arg(s));
-        return false;
+      if(pc->Model == "VHDL") {
+	VHDL_File *vf = (VHDL_File*)pc;
+	r = vf->createSubNetlist(stream);
+	ErrText->insert(vf->getErrorText());
+	if(!r) return false;
       }
-
-      // Write the whole VHDL file into the netlist output.
-      QTextStream streamVHDL(&f);
-      s = streamVHDL.read();
-      f.close();
-      (*stream) << '\n' << s << '\n';
+      if(pc->Model == "Verilog") {
+	Verilog_File *vf = (Verilog_File*)pc;
+	r = vf->createSubNetlist(stream);
+	ErrText->insert(vf->getErrorText());
+	if(!r) return false;
+      }      
       continue;
     }
   }
@@ -928,13 +975,199 @@ bool Schematic::giveNodeNames(QTextStream *stream, int& countInit,
 }
 
 // ---------------------------------------------------
-// Write the netlist as subcircuit to the text stream 'NetlistFile'.
+bool Schematic::createLibNetlist(QTextStream *stream, QTextEdit *ErrText,
+				 int NumPorts)
+{
+  int countInit = 0;
+  QStringList Collect;
+  Collect.clear();
+  StringList.clear();
+  Signals.clear();
+
+  // Apply node names and collect subcircuits and file include
+  creatingLib = true;
+  if(!giveNodeNames(stream, countInit, Collect, ErrText, NumPorts)) {
+    creatingLib = false;
+    return false;
+  }
+  creatingLib = false;
+
+  // Marking start of actual top-level subcircuit
+  QString c;
+  if(NumPorts >= 0) {
+    if (isVerilog)
+      c = "///";
+    else
+      c = "---";
+  }
+  else c = "###";
+  (*stream) << "\n" << c << " TOP LEVEL MARK " << c << "\n";
+
+  // Emit subcircuit components
+  createSubNetlistPlain(stream, ErrText, NumPorts);
+
+  Signals.clear();  // was filled in "giveNodeNames()"
+  return true;
+}
+
+// ---------------------------------------------------
+void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
+				      int NumPorts)
+{
+  int i, z;
+  QString s;
+  QStringList SubcircuitPorts;
+  QStringList InPorts;
+  QStringList OutPorts;
+  QStringList InOutPorts;
+  QStringList::Iterator it;
+  Component *pc;
+
+  // probably creating a library currently
+  QTextStream * tstream = stream;
+  QFile ofile;
+  if(creatingLib) {
+    QString f = properAbsFileName(DocName) + ".lst";
+    ofile.setName(f);
+    if(!ofile.open(IO_WriteOnly)) {
+      ErrText->insert(tr("ERROR: Cannot create library file \"%s\".").arg(f));
+      return;
+    }
+    tstream = new QTextStream(&ofile);
+  }
+
+  // collect subcircuit ports and sort their node names into "SubcircuitPorts"
+  for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
+    if(pc->Model.at(0) == '.') {  // no simulations in subcircuits
+      ErrText->insert(
+        QObject::tr("WARNING: Ignore simulation component in subcircuit \"%1\".").arg(DocName)+"\n");
+      continue;
+    }
+    else if(pc->Model == "Port") {
+      i  = pc->Props.first()->Value.toInt();
+      for(z=SubcircuitPorts.size(); z<i; z++)
+        SubcircuitPorts.append(" ");
+      it = SubcircuitPorts.at(i-1);
+      (*it) = pc->Ports.getFirst()->Connection->Name;
+      if(NumPorts >= 0) {
+	if (isVerilog) {
+	  Signals.remove(Signals.find(*it)); // remove node name
+	  switch(pc->Props.at(1)->Value.at(0).latin1()) {
+          case 'a':
+	    InOutPorts.append(*it);
+	    break;
+          case 'o':
+	    OutPorts.append(*it);
+	    break;
+          default:
+	    InPorts.append(*it);
+	  }
+	}
+	else {
+	  Signals.remove(Signals.find(*it)); // remove node name of output port
+	  switch(pc->Props.at(1)->Value.at(0).latin1()) {
+          case 'a': (*it) += ": inout";  // attribut "analog" is "inout"
+	    break;
+          case 'o': Signals.append(*it);   // output ports need workaround
+	    (*it) = "net_out" + (*it);
+	    // no "break;" here !!!
+          default:  (*it) += ": " + pc->Props.at(1)->Value;
+	  }
+	  (*it) += " bit";
+	}
+      }
+    }
+  }
+
+  QString f = properFileName(DocName);
+  QString Type = properName(f);
+
+  Painting *pi;
+  if(NumPorts < 0) {
+    // ..... analog subcircuit ...................................
+    (*tstream) << "\n.Def:" << Type << " " << SubcircuitPorts.join(" ");
+    for(pi = SymbolPaints.first(); pi != 0; pi = SymbolPaints.next())
+      if(pi->Name == ".ID ") {
+        SubParameter *pp;
+        ID_Text *pid = (ID_Text*)pi;
+        for(pp = pid->Parameter.first(); pp != 0; pp = pid->Parameter.next()) {
+          s = pp->Name;  // keep 'Name' unchanged
+          (*tstream) << " " << s.replace("=", "=\"") << '"';
+        }
+        break;
+      }
+    (*tstream) << '\n';
+
+    // write all components with node names into netlist file
+    for(pc = DocComps.first(); pc != 0; pc = DocComps.next())
+      (*tstream) << pc->getNetlist();
+
+    (*tstream) << ".Def:End\n";
+
+  }
+  else {
+    if (isVerilog) {
+      // ..... digital subcircuit ...................................
+      (*tstream) << "\nmodule Sub_" << Type << " ("
+		 << SubcircuitPorts.join(", ") << ");\n";
+      if(!InPorts.isEmpty())
+	(*tstream) << "  input " << InPorts.join(", ") << ";\n";
+      if(!OutPorts.isEmpty())
+	(*tstream) << "  output " << OutPorts.join(", ") << ";\n";
+      if(!InOutPorts.isEmpty())
+	(*tstream) << "  inout " << InOutPorts.join(", ") << ";\n";
+      if(!Signals.isEmpty())
+	(*tstream) << "  wire " << Signals.join(",\n       ")
+		   << ";\n";
+      (*tstream) << "\n";
+
+      if(Signals.findIndex("gnd") >= 0)
+	(*tstream) << "  assign gnd = 0;\n";  // should appear only once
+
+      // write all components into netlist file
+      for(pc = DocComps.first(); pc != 0; pc = DocComps.next())
+	(*tstream) << pc->get_Verilog_Code(NumPorts);
+
+      (*tstream) << "endmodule\n";
+    } else {
+      // ..... digital subcircuit ...................................
+      (*tstream) << "\nentity Sub_" << Type << " is\n"
+		 << "  port (" << SubcircuitPorts.join(";\n        ") << ");\n"
+		 << "end entity;\n"
+		 << "use work.all;\n"
+		 << "architecture Arch_Sub_" << Type << " of Sub_" << Type
+		 << " is\n";
+      if(!Signals.isEmpty())
+	(*tstream) << "  signal " << Signals.join(",\n         ")
+		   << " : bit;\n";
+
+      (*tstream) << "begin\n";
+
+      if(Signals.findIndex("gnd") >= 0)
+	(*tstream) << "  gnd <= '0';\n";  // should appear only once
+
+      // write all components into netlist file
+      for(pc = DocComps.first(); pc != 0; pc = DocComps.next())
+	(*tstream) << pc->get_VHDL_Code(NumPorts);
+
+      (*tstream) << "end architecture;\n";
+    }
+  }
+
+  // close file
+  if(creatingLib) {
+    ofile.close();
+    delete tstream;
+  }
+}
+
+// ---------------------------------------------------
+// Write the netlist as subcircuit to the text stream 'stream'.
 bool Schematic::createSubNetlist(QTextStream *stream, int& countInit,
                      QStringList& Collect, QTextEdit *ErrText, int NumPorts)
 {
-  int i, z;
 //  int Collect_count = Collect.count();   // position for this subcircuit
-  QString s;
+
   // TODO: NodeSets have to be put into the subcircuit block.
   if(!giveNodeNames(stream, countInit, Collect, ErrText, NumPorts))
     return false;
@@ -947,89 +1180,10 @@ bool Schematic::createSubNetlist(QTextStream *stream, int& countInit,
       }
       else it++;*/
 
-  QStringList SubcircuitPorts;
-  QStringList::Iterator it;
-  Component *pc;
-  // collect subcircuit ports and sort their node names into "SubcircuitPorts"
-  for(pc = DocComps.first(); pc != 0; pc = DocComps.next())
-    if(pc->Model == "Port") {
-      i  = pc->Props.first()->Value.toInt();
-      for(z=SubcircuitPorts.size(); z<i; z++)
-        SubcircuitPorts.append(" ");
-      it = SubcircuitPorts.at(i-1);
-      (*it) = pc->Ports.getFirst()->Connection->Name;
-      if(NumPorts >= 0) {
-        Signals.remove(Signals.find(*it));  // remove node name of output port
-        switch(pc->Props.at(1)->Value.at(0).latin1()) {
-          case 'a': (*it) += ": inout";  // attribut "analog" is "inout"
-                    break;
-          case 'o': Signals.append(*it);   // output ports need workaround
-                    (*it) = "net_out" + (*it);
-                    // no "break;" here !!!
-          default:  (*it) += ": " + pc->Props.at(1)->Value;
-        }
-        (*it) += " bit";
-      }
-    }
+  // Emit subcircuit components
+  createSubNetlistPlain(stream, ErrText, NumPorts);
 
-  QString  Type = properName(DocName);
-
-  if(NumPorts < 0)
-    (*stream) << "\n.Def:" << Type << " " << SubcircuitPorts.join(" ") << '\n';
-  else {
-    (*stream) << "\nentity Sub_" << Type << " is\n"
-              << "  port (" << SubcircuitPorts.join(";\n        ") << ");\n"
-              << "end entity;\n"
-              << "use work.all;\n"
-              << "architecture Arch_Sub_" << Type << " of Sub_" << Type << " is\n";
-    if(!Signals.isEmpty())
-      (*stream) << "  signal " << Signals.join(",\n         ") << " : bit;\n";
-
-    (*stream) << "begin\n";
-
-    if(Signals.findIndex("gnd") >= 0)
-      (*stream) << "  gnd <= '0';\n";  // should appear only once
-  }
   Signals.clear();  // was filled in "giveNodeNames()"
-
-
-  // write all components with node names into the netlist file
-  for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-    if(pc->isActive == COMP_IS_OPEN) continue;  // should it be simulated ?
-  
-    if(pc->Model.at(0) == '.') {  // no simulations in subcircuits
-      ErrText->insert(
-        QObject::tr("WARNING: Ignore simulation component in subcircuit \"%1\".").arg(DocName));
-      continue;
-    }
-    if(pc->Model == "Eqn") {  // no equations in subcircuits
-      ErrText->insert(
-        QObject::tr("WARNING: Ignore equation in subcircuit \"%1\".").arg(DocName));
-      continue;
-    }
-
-    if(pc->isActive == COMP_IS_ACTIVE) {
-      if(NumPorts < 0)
-        s = pc->NetList();
-      else
-        s = pc->VHDL_Code(NumPorts);
-    }
-    else {
-      if(NumPorts < 0)
-        s = pc->getShortenNetlist();
-      else
-        s = pc->getShortenVHDL();
-    }
-
-    if(!s.isEmpty())  // not inserted: subcircuit ports, disabled components
-      (*stream) << s << "\n";
-  }
-
-  if(NumPorts < 0)
-    (*stream) << ".Def:End\n\n";
-  else
-    (*stream) << "end architecture;\n\n";
-
   return true;
 }
 
@@ -1040,6 +1194,7 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
 {
   if(showBias > 0)  showBias = -1;  // do not show DC bias anymore
 
+  isVerilog = false;
   bool isTruthTable = false;
   int allTypes = 0, NumPorts = 0;
   // Detect simulation domain (analog/digital) by looking at component types.
@@ -1054,6 +1209,8 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
         }
         if(pc->Props.getFirst()->Value != "TimeList")
           isTruthTable = true;
+	if(pc->Props.getLast()->Value != "VHDL")
+	  isVerilog = true;
         allTypes |= isDigitalComponent;
       }
       else allTypes |= isAnalogComponent;
@@ -1094,6 +1251,8 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
   // first line is documentation
   if(allTypes & isAnalogComponent)
     stream << "#";
+  else if (isVerilog)
+    stream << "//";
   else
     stream << "--";
   stream << " Qucs " << PACKAGE_VERSION << "  " << DocName << "\n";
@@ -1101,16 +1260,20 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
 //    stream << "library ieee;\nuse ieee.std_logic_1164.all;\n\n";
 
 
-  int countInit = 0;
+  int countInit = 0;  // counts the nodesets to give them unique names
   if(!giveNodeNames(&stream, countInit, Collect, ErrText, NumPorts))
     return -10;
 
   if(allTypes & isAnalogComponent)
     return NumPorts;
 
-  stream << "entity TestBench is\n"
-         << "end entity;\n"
-         << "use work.all;\n";
+  if (isVerilog) {
+    stream << "`timescale 1ps/100fs\n";
+  } else {
+    stream << "entity TestBench is\n"
+	   << "end entity;\n"
+	   << "use work.all;\n";
+  }
   return NumPorts;
 }
 
@@ -1119,49 +1282,66 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
 QString Schematic::createNetlist(QTextStream& stream, int NumPorts)
 {
   if(NumPorts >= 0) {
-    stream << "architecture Arch_TestBench of TestBench is\n"
-           << "  signal " << Signals.join(",\n         ")
-           << " : bit;\n"
-           << "begin\n";
+    if (isVerilog) {
+      stream << "module TestBench ();\n"
+	     << "  wire " << Signals.join(",\n       ")
+	     << ";\n\n";
+    } else {
+      stream << "architecture Arch_TestBench of TestBench is\n"
+	     << "  signal " << Signals.join(",\n         ")
+	     << " : bit;\n"
+	     << "begin\n";
+    }
 
-    if(Signals.findIndex("gnd") >= 0)
-      stream << "  gnd <= '0';\n";  // should appear only once
+    if(Signals.findIndex("gnd") >= 0) {
+      if (isVerilog) {
+	stream << "  assign gnd = 0;\n";
+      } else {
+	stream << "  gnd <= '0';\n";  // should appear only once
+      }
+    }
   }
   Signals.clear();  // was filled in "giveNodeNames()"
   StringList.clear();
 
   QString s, Time;
   for(Component *pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-    if(pc->isActive == COMP_IS_OPEN) continue;  // should it be simulated ?
-  
     if(NumPorts < 0) {
-      if(pc->isActive == COMP_IS_ACTIVE)
-        s = pc->NetList();
-      else
-        s = pc->getShortenNetlist();
+      s = pc->getNetlist();
     }
     else {
-      if(pc->Model.at(0) == '.') {  // simulation component ?
-        if(NumPorts > 0)  // truth table simulation ?
-          Time = QString::number((1 << NumPorts) - 1) + " ns";
-        else {
+      if(pc->Model == ".Digi" && pc->isActive) {  // simulation component ?
+        if(NumPorts > 0) { // truth table simulation ?
+	  if (isVerilog)
+	    Time = QString::number((1 << NumPorts));
+	  else
+	    Time = QString::number((1 << NumPorts) - 1) + " ns";
+        } else {
           Time = pc->Props.at(1)->Value;
-          if(!VHDL_Time(Time, pc->Name))  return Time;  // wrong time format
+	  if (isVerilog) {
+	    if(!Verilog_Time(Time, pc->Name)) return Time;
+	  } else {
+	    if(!VHDL_Time(Time, pc->Name)) return Time;  // wrong time format
+	  }
         }
       }
-      if(pc->isActive == COMP_IS_ACTIVE)
-        s = pc->VHDL_Code(NumPorts);
-      else
-        s = pc->getShortenVHDL();
+      if (isVerilog) {
+	s = pc->get_Verilog_Code(NumPorts);
+      } else {
+	s = pc->get_VHDL_Code(NumPorts);
+      }
       if(s.at(0) == '')  return s;   // return error
     }
 
-    if(!s.isEmpty())  // not inserted: subcircuit ports, disabled components
-      stream << s << "\n";
+    stream << s;
   }
 
-  if(NumPorts >= 0)
-    stream << "end architecture;\n";
+  if(NumPorts >= 0) {
+    if (isVerilog) {
+    } else {
+      stream << "end architecture;\n";
+    }
+  }
 
   return Time;
 }
